@@ -1,22 +1,10 @@
 /*
- *  Copyright (c) 2010 Lukáš Tvrdý lukast.dev@gmail.com
+ *  SPDX-FileCopyrightText: 2010 Lukáš Tvrdý lukast.dev @gmail.com
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#include <QTest>
+#include <simpletest.h>
 
 #include "kis_bcontrast_benchmark.h"
 #include "kis_benchmark_values.h"
@@ -37,6 +25,7 @@
 #include "kis_selection.h"
 #include <kis_iterator_ng.h>
 #include "krita_utils.h"
+#include <KisGlobalResourcesInterface.h>
 
 void KisBContrastBenchmark::initTestCase()
 {
@@ -68,7 +57,7 @@ void KisBContrastBenchmark::cleanupTestCase()
 void KisBContrastBenchmark::benchmarkFilter()
 {
     KisFilterSP filter = KisFilterRegistry::instance()->value("brightnesscontrast");
-    KisFilterConfigurationSP  kfc = filter->defaultConfiguration();
+    KisFilterConfigurationSP  kfc = filter->defaultConfiguration(KisGlobalResourcesInterface::instance());
 
     // Get the predefined configuration from a file
     QFile file(QString(FILES_DATA_DIR) + '/' + filter->id() + ".cfg");
@@ -97,4 +86,4 @@ void KisBContrastBenchmark::benchmarkFilter()
 
 
 
-QTEST_MAIN(KisBContrastBenchmark)
+SIMPLE_TEST_MAIN(KisBContrastBenchmark)
