@@ -14,7 +14,6 @@
 #include "KoPathShape.h"
 #include "KoSelection.h"
 #include "KoDocumentResourceManager.h"
-#include "KoShapePaintingContext.h"
 #include "KoShapeStroke.h"
 #include "KoCanvasBase.h"
 #include "kis_int_parse_spin_box.h"
@@ -131,8 +130,7 @@ void KoCreatePathTool::paintPath(KoPathShape& pathShape, QPainter &painter, cons
                          painter.transform());
     painter.save();
 
-    KoShapePaintingContext paintContext; //FIXME
-    pathShape.paint(painter, paintContext);
+    pathShape.paint(painter);
     painter.restore();
 
     if (pathShape.stroke()) {
@@ -386,6 +384,9 @@ void KoCreatePathTool::endPath()
 {
     Q_D(KoCreatePathTool);
 
+    if (!d->shape) {
+        return;
+    }
     d->addPathShape();
     repaintDecorations();
     endShape();
@@ -395,12 +396,13 @@ void KoCreatePathTool::endPathWithoutLastPoint()
 {
     Q_D(KoCreatePathTool);
 
-    if (d->shape) {
-        delete d->shape->removePoint(d->shape->pathPointIndex(d->activePoint));
-        d->addPathShape();
-
-        repaintDecorations();
+    if (!d->shape) {
+        return;
     }
+    delete d->shape->removePoint(d->shape->pathPointIndex(d->activePoint));
+    d->addPathShape();
+
+    repaintDecorations();
     endShape();
 }
 
@@ -408,10 +410,11 @@ void KoCreatePathTool::cancelPath()
 {
     Q_D(KoCreatePathTool);
 
-    if (d->shape) {
-        d->firstPoint = 0;
-        d->activePoint = 0;
+    if (!d->shape) {
+        return;
     }
+    d->firstPoint = 0;
+    d->activePoint = 0;
     d->cleanUp();
     repaintDecorations();
     endShape();
