@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2020 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2020 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KISCOLORFULBRUSH_H
@@ -46,7 +34,14 @@ public:
     void setHasColorAndTransparency(bool value);
     bool hasColorAndTransparency() const;
 
+    qreal estimatedSourceMidPoint() const;
+    qreal adjustedMidPoint() const;
+
+    bool autoAdjustMidPoint() const;
+    virtual void setAutoAdjustMidPoint(bool autoAdjustMidPoint);
+
 private:
+    bool m_autoAdjustMidPoint = false;
     quint8 m_adjustmentMidPoint = 127;
     qreal m_brightnessAdjustment = 0.0;
     qreal m_contrastAdjustment = 0.0;
