@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2004 Boudewijn Rempt <boud@valdyas.org>
- *  Copyright (c) 2005 Bart Coppens <kde@bartcoppens.be>
+ *  SPDX-FileCopyrightText: 2004 Boudewijn Rempt <boud@valdyas.org>
+ *  SPDX-FileCopyrightText: 2005 Bart Coppens <kde@bartcoppens.be>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "kis_pipebrush_parasite.h"
 
@@ -24,9 +12,21 @@ KisPipeBrushParasite::KisPipeBrushParasite(const QString& source)
     needsMovement = false;
     QRegExp basicSplitter(" ");
     QRegExp parasiteSplitter(":");
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    QStringList parasites = source.split(basicSplitter, Qt::SkipEmptyParts);
+#else
     QStringList parasites = source.split(basicSplitter, QString::SkipEmptyParts);
+#endif
+
     for (int i = 0; i < parasites.count(); i++) {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+        QStringList split = parasites.at(i).split(parasiteSplitter, Qt::SkipEmptyParts);
+#else
         QStringList split = parasites.at(i).split(parasiteSplitter, QString::SkipEmptyParts);
+#endif
+
         if (split.count() != 2) {
             warnImage << "Wrong count for this parasite key/value:" << parasites.at(i);
             continue;
