@@ -1,42 +1,30 @@
 /*
- *  Copyright (c) 2007 Boudewijn Rempt boud@valdyas.org
+ *  SPDX-FileCopyrightText: 2007 Boudewijn Rempt boud @valdyas.org
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_gbr_brush_test.h"
 
-#include <QTest>
+#include <simpletest.h>
 #include <QString>
 #include <QDir>
 #include <KoColor.h>
 #include <KoColorSpace.h>
 #include <KoColorSpaceRegistry.h>
-#include "testutil.h"
+#include <testutil.h>
 #include "../kis_gbr_brush.h"
 #include "kis_types.h"
 #include "kis_paint_device.h"
 #include "brushengine/kis_paint_information.h"
 #include <kis_fixed_paint_device.h>
 #include "kis_qimage_pyramid.h"
-
+#include <KisGlobalResourcesInterface.h>
 
 void KisGbrBrushTest::testMaskGenerationSingleColor()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "brush.gbr"));
-    brush->load();
+    brush->load(KisGlobalResourcesInterface::instance());
     Q_ASSERT(brush->valid());
     const KoColorSpace* cs = KoColorSpaceRegistry::instance()->rgb8();
 
@@ -64,7 +52,7 @@ void KisGbrBrushTest::testMaskGenerationSingleColor()
 void KisGbrBrushTest::testMaskGenerationDevColor()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "brush.gbr"));
-    brush->load();
+    brush->load(KisGlobalResourcesInterface::instance());
     Q_ASSERT(brush->valid());
     const KoColorSpace* cs = KoColorSpaceRegistry::instance()->rgb8();
 
@@ -97,7 +85,7 @@ void KisGbrBrushTest::testMaskGenerationDevColor()
 void KisGbrBrushTest::testImageGeneration()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "testing_brush_512_bars.gbr"));
-    bool res = brush->load();
+    bool res = brush->load(KisGlobalResourcesInterface::instance());
     Q_UNUSED(res);
     Q_ASSERT(res);
     QVERIFY(!brush->brushTipImage().isNull());
@@ -127,24 +115,25 @@ void KisGbrBrushTest::testImageGeneration()
     }
 }
 
-#include "KisSharedQImagePyramid.h"
+#include "kis_qimage_pyramid.h"
 
 void KisGbrBrushTest::benchmarkPyramidCreation()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "testing_brush_512_bars.gbr"));
-    brush->load();
+    brush->load(KisGlobalResourcesInterface::instance());
     QVERIFY(!brush->brushTipImage().isNull());
 
     QBENCHMARK {
-        KisSharedQImagePyramid sharedPyramid;
-        QVERIFY(sharedPyramid.pyramid(brush.data())); // avoid compiler elimination of unused code!
+        KisQImagePyramid pyramid(brush->brushTipImage());
+        qreal temp = 0.0;
+        QVERIFY(!pyramid.getClosest(QTransform(), &temp).isNull()); // avoid compiler elimination of unused code!
     }
 }
 
 void KisGbrBrushTest::benchmarkScaling()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "testing_brush_512_bars.gbr"));
-    brush->load();
+    brush->load(KisGlobalResourcesInterface::instance());
     QVERIFY(!brush->brushTipImage().isNull());
     qsrand(1);
 
@@ -168,7 +157,7 @@ void KisGbrBrushTest::benchmarkScaling()
 void KisGbrBrushTest::benchmarkRotation()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "testing_brush_512_bars.gbr"));
-    brush->load();
+    brush->load(KisGlobalResourcesInterface::instance());
     QVERIFY(!brush->brushTipImage().isNull());
     qsrand(1);
 
@@ -184,7 +173,7 @@ void KisGbrBrushTest::benchmarkRotation()
 void KisGbrBrushTest::benchmarkMaskScaling()
 {
     QScopedPointer<KisGbrBrush> brush(new KisGbrBrush(QString(FILES_DATA_DIR) + '/' + "testing_brush_512_bars.gbr"));
-    brush->load();
+    brush->load(KisGlobalResourcesInterface::instance());
     QVERIFY(!brush->brushTipImage().isNull());
     qsrand(1);
 
@@ -299,4 +288,4 @@ void KisGbrBrushTest::testQPainterTransformationBorder()
     }
 }
 
-QTEST_MAIN(KisGbrBrushTest)
+SIMPLE_TEST_MAIN(KisGbrBrushTest)
