@@ -1,20 +1,8 @@
 /*
- *  Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>
- *  Copyright (c) 2015 Boudewijn Rempt <boud@valdyas.org>
+ *  SPDX-FileCopyrightText: 2012 Daniel Nicoletti <dantti12@gmail.com>
+ *  SPDX-FileCopyrightText: 2015 Boudewijn Rempt <boud@valdyas.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KisColord.h"
@@ -157,13 +145,13 @@ QByteArray KisColord::deviceProfile(const QString &id, int p)
 
 void KisColord::serviceOwnerChanged(const QString &serviceName, const QString &oldOwner, const QString &newOwner)
 {
-    Q_UNUSED(serviceName)
+    Q_UNUSED(serviceName);
     if (newOwner.isEmpty() || oldOwner != newOwner) {
         // colord has quit or restarted
         qDeleteAll(m_devices);
         m_devices.clear();
     }
-    emit changed();
+    Q_EMIT changed();
 }
 
 void KisColord::gotDevices(QDBusPendingCallWatcher *call)
@@ -178,7 +166,7 @@ void KisColord::gotDevices(QDBusPendingCallWatcher *call)
         Q_FOREACH (const QDBusObjectPath &device, devices) {
             deviceAdded(device, false);
         }
-        emit changed();
+        Q_EMIT changed();
     }
     //dbgKrita << "gotDevices" << m_devices.count();
     call->deleteLater();
@@ -209,7 +197,7 @@ void KisColord::deviceChanged(const QDBusObjectPath &objectPath)
 
     //dbgKrita << "deviceChanged" << dev->id << "with" << profiles.size() << "profiles";
 
-    emit changed(dev->id);
+    Q_EMIT changed(dev->id);
 }
 
 void KisColord::deviceAdded(const QDBusObjectPath &objectPath, bool emitChanged)
@@ -247,7 +235,7 @@ void KisColord::deviceAdded(const QDBusObjectPath &objectPath, bool emitChanged)
 //             << "with" << profiles.size() << "profiles";
 
     if (emitChanged) {
-        emit changed();
+        Q_EMIT changed();
     }
 }
 
@@ -256,7 +244,7 @@ void KisColord::deviceRemoved(const QDBusObjectPath &objectPath)
     if (m_devices.contains(objectPath)) {
         delete m_devices.take(objectPath);
     }
-    emit changed();
+    Q_EMIT changed();
 }
 
 void KisColord::addProfilesToDevice(Device *dev, QList<QDBusObjectPath> profiles) const
