@@ -5,6 +5,7 @@
  */
 
 #include "kis_command_utils.h"
+#include "kis_assert.h"
 
 namespace KisCommandUtils
 {
@@ -197,4 +198,17 @@ namespace KisCommandUtils
         KUndo2Command::undo();
     }
 
+    void redoAndMergeIntoAccumulatingCommand(KUndo2Command *cmd, QScopedPointer<KUndo2Command> &accumulatingCommand)
+    {
+        cmd->redo();
+        if (accumulatingCommand) {
+            const bool isMerged = accumulatingCommand->mergeWith(cmd);
+            KIS_SAFE_ASSERT_RECOVER_NOOP(isMerged);
+            delete cmd;
+        } else {
+            accumulatingCommand.reset(cmd);
+        }
+    }
+
+
 }
