@@ -67,6 +67,7 @@ class KisKActionCollection;
 
 #include "kundo2magicstring.h"
 #include "kundo2commandextradata.h"
+#include "KisCumulativeUndoData.h"
 
 
 /**
@@ -99,7 +100,7 @@ public:
     void setText(const KUndo2MagicString &text);
 
     virtual int id() const;
-    virtual int timedId();
+    virtual int timedId() const;
     virtual void setTimedID(int timedID);
     virtual bool mergeWith(const KUndo2Command *other);
     virtual bool timedMergeWith(KUndo2Command *other);
@@ -109,14 +110,16 @@ public:
     int childCount() const;
     const KUndo2Command *child(int index) const;
 
-    bool hasParent();
-    virtual void setTime();
-    virtual QTime time();
-    virtual void setEndTime();
-    virtual QTime endTime();
+    bool hasParent() const;
+    void setTime();
+    virtual void setTime(const QTime &time);
+    virtual QTime time() const;
+    void setEndTime();
+    virtual void setEndTime(const QTime &time);
+    virtual QTime endTime() const;
 
-    virtual QVector<KUndo2Command*> mergeCommandsVector();
-    virtual bool isMerged();
+    virtual QVector<KUndo2Command*> mergeCommandsVector() const;
+    virtual bool isMerged() const;
     virtual void undoMergedCommands();
     virtual void redoMergedCommands();
 
@@ -193,14 +196,10 @@ public:
     const KUndo2Command *command(int index) const;
 
     void setUseCumulativeUndoRedo(bool value);
-    bool useCumulativeUndoRedo();
-    void setTimeT1(double value);
-    double timeT1();
-    void setTimeT2(double value);
-    double timeT2();
-    int strokesN();
-    void setStrokesN(int value);
+    bool useCumulativeUndoRedo() const;
 
+    void setCumulativeUndoData(const KisCumulativeUndoData &data);
+    KisCumulativeUndoData cumulativeUndoData();
 
 public Q_SLOTS:
     void setClean();
@@ -231,11 +230,7 @@ private:
     KUndo2Group *m_group;
     int m_undo_limit;
     bool m_useCumulativeUndoRedo;
-    double m_timeT1;
-    double m_timeT2;
-    int m_strokesN;
-    int m_lastMergedSetCount;
-    int m_lastMergedIndex;
+    KisCumulativeUndoData m_cumulativeUndoData;
 
     // also from QUndoStackPrivate
     void setIndex(int idx, bool clean);
