@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2006, 2010 Boudewijn Rempt <boud@valdyas.org>
-   Copyright (C) 2006, 2010 Thomas Zander <zander@kde.org>
-   Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
+   SPDX-FileCopyrightText: 2006, 2010 Boudewijn Rempt <boud@valdyas.org>
+   SPDX-FileCopyrightText: 2006, 2010 Thomas Zander <zander@kde.org>
+   SPDX-FileCopyrightText: 2006 Thorsten Zachmann <zachmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KOCANVASBASE_H
@@ -123,7 +110,7 @@ public:
     /**
      * @brief selectedShapesProxy() is a special interface for keeping a persistent connections
      * to selectionChanged() and selectionContentChanged() signals. While shapeManager() can change
-     * throughout the life time of the cavas, selectedShapesProxy() is guaranteed to stay the same.
+     * throughout the life time of the canvas, selectedShapesProxy() is guaranteed to stay the same.
      * @return persistent KoSelectedShapesProxy object
      */
     virtual KoSelectedShapesProxy *selectedShapesProxy() const = 0;
@@ -145,7 +132,8 @@ public:
      * Return the viewConverter for this view.
      * @return the viewConverter for this view.
      */
-    virtual KoViewConverter *viewConverter() const = 0;
+    virtual const KoViewConverter *viewConverter() const = 0;
+    virtual KoViewConverter *viewConverter() = 0;
 
     /**
      * Convert a coordinate in pixels to pt.
