@@ -41,9 +41,7 @@ void KoCanvasControllerWidget::Private::setDocumentOffset()
     // the canvas must add to the update rect in its paint event, to
     // compensate.
 
-    const QPoint pt(q->horizontalScrollBar()->value(), q->verticalScrollBar()->value());
-    if (q->documentOffset() == pt) return;
-
+    QPoint pt(q->horizontalScrollBar()->value(), q->verticalScrollBar()->value());
     q->proxyObject->emitMoveDocumentOffset(pt);
 
     QWidget *canvasWidget = canvas->canvasWidget();
