@@ -26,7 +26,7 @@ public:
     ~KoHatchBackground() override;
 
     // reimplemented
-    void paint(QPainter &painter, KoShapePaintingContext &context, const QPainterPath &fillPath) const override;
+    void paint(QPainter &painter, const QPainterPath &fillPath) const override;
 
 private:
     class Private;
