@@ -197,18 +197,18 @@ void KoShapeFactoryBase::getDeferredPlugin()
     QMutexLocker(&d->pluginLoadingMutex);
     if (d->deferredFactory) return;
 
-    const QList<QPluginLoader *> offers = KoJsonTrader::instance()->query("Krita/Deferred", QString());
+    const QList<KoJsonTrader::Plugin> offers =
+        KoJsonTrader::instance()->query("Krita/Deferred", QString());
     Q_ASSERT(offers.size() > 0);
 
-    Q_FOREACH (QPluginLoader *pluginLoader, offers) {
-        KPluginFactory *factory = qobject_cast<KPluginFactory *>(pluginLoader->instance());
+    Q_FOREACH (const KoJsonTrader::Plugin &pluginLoader, offers) {
+        KPluginFactory *factory = qobject_cast<KPluginFactory *>(pluginLoader.instance());
         KoDeferredShapeFactoryBase *plugin = factory->create<KoDeferredShapeFactoryBase>(this, QVariantList());
 
         if (plugin && plugin->deferredPluginName() == d->deferredPluginName) {
             d->deferredFactory = plugin;
         }
     }
-    qDeleteAll(offers);
 }
 
 void KoShapeFactoryBase::pruneDocumentResourceManager(QObject *)
