@@ -19,7 +19,6 @@ class KoShapeLayer;
 class KoShape;
 class KoShapeControllerBase;
 class KoLoadingShapeUpdater;
-class KoImageCollection;
 class KoSharedLoadingData;
 class KoDocumentResourceManager;
 class KoSectionModel;
@@ -107,9 +106,6 @@ public:
      */
     void shapeLoaded(KoShape *shape);
 
-    /// Returns the image collection for loading images
-    KoImageCollection *imageCollection();
-
     /// Get current z-index
     int zIndex();
 
