@@ -1,8 +1,5 @@
 /*
- *  This file is part of Calligra tests
- *
  *  SPDX-FileCopyrightText: 2006-2010 Thomas Zander <zander@kde.org>
- *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #ifndef MOCKSHAPES_H
@@ -135,7 +132,10 @@ public:
     KoToolProxy * toolProxy() const override {
         return 0;
     }
-    KoViewConverter *viewConverter() const override {
+    const KoViewConverter *viewConverter() const override {
+        return 0;
+    }
+    KoViewConverter *viewConverter() override {
         return 0;
     }
     QWidget* canvasWidget() override {
