@@ -1,8 +1,5 @@
 /*
- *  This file is part of Calligra tests
- *
  *  SPDX-FileCopyrightText: 2006-2010 Thomas Zander <zander@kde.org>
- *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
@@ -12,8 +9,9 @@
 #include "KoShapeContainer.h"
 #include "KoShapeManager.h"
 
-#include <sdk/tests/testflake.h>
 #include <MockShapes.h>
+#include <testflake.h>
+
 
 #include <simpletest.h>
 
@@ -81,13 +79,13 @@ void TestShapePainting::testPaintHiddenShape()
 
     MockShape *shape = new MockShape();
     MockContainer *fourth = new MockContainer();
-    MockContainer *thirth = new MockContainer();
+    MockContainer *third = new MockContainer();
     MockContainer *second = new MockContainer();
 
 
     top->addShape(second);
-    second->addShape(thirth);
-    thirth->addShape(fourth);
+    second->addShape(third);
+    third->addShape(fourth);
     fourth->addShape(shape);
 
     second->setVisible(false);
@@ -103,7 +101,7 @@ void TestShapePainting::testPaintHiddenShape()
 
     QCOMPARE(top->paintedCount, 1);
     QCOMPARE(second->paintedCount, 0);
-    QCOMPARE(thirth->paintedCount, 0);
+    QCOMPARE(third->paintedCount, 0);
     QCOMPARE(fourth->paintedCount, 0);
     QCOMPARE(shape->paintedCount, 0);
 }
