@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006,2008 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2006,2007 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2007,2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2007 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2006, 2008 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006, 2007 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2007, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007 Boudewijn Rempt <boud@valdyas.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOPATHTOOLHANDLE_H
@@ -86,14 +73,4 @@ protected:
     int m_handleId;
 };
 
-class ConnectionHandle : public ParameterHandle
-{
-public:
-    ConnectionHandle(KoPathTool *tool, KoParameterShape *parameterShape, int handleId);
-
-    // XXX: Later: create a paint even to distinguish a connection
-    // handle  from another handle type
-    KoInteractionStrategy *handleMousePress(KoPointerEvent *event) override;
-};
-
 #endif // KOPATHTOOLHANDLE_H
