@@ -8,8 +8,6 @@
 
 #include "KoZoomTool.h"
 
-#include <QStandardPaths>
-
 #include "KoZoomStrategy.h"
 #include "KoZoomToolWidget.h"
 #include "KoPointerEvent.h"
@@ -19,8 +17,9 @@
 #include <FlakeDebug.h>
 
 KoZoomTool::KoZoomTool(KoCanvasBase *canvas)
-        : KoInteractionTool(canvas),
-        m_zoomInMode(true)
+        : KoInteractionTool(canvas)
+        , m_controller(nullptr)
+        , m_zoomInMode(true)
 {
     QPixmap inPixmap, outPixmap;
     inPixmap.load(":/zoom_in_cursor.png");
