@@ -178,7 +178,7 @@ void KisAcyclicSignalConnector::forwardSlotDouble(double value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalDouble(value);
+    Q_EMIT forwardSignalDouble(value);
     unlock();
 }
 
@@ -187,7 +187,7 @@ void KisAcyclicSignalConnector::backwardSlotDouble(double value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalDouble(value);
+    Q_EMIT backwardSignalDouble(value);
     unlock();
 }
 
@@ -196,7 +196,7 @@ void KisAcyclicSignalConnector::forwardSlotInt(int value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalInt(value);
+    Q_EMIT forwardSignalInt(value);
     unlock();
 }
 
@@ -205,7 +205,7 @@ void KisAcyclicSignalConnector::backwardSlotInt(int value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalInt(value);
+    Q_EMIT backwardSignalInt(value);
     unlock();
 }
 
@@ -214,7 +214,7 @@ void KisAcyclicSignalConnector::forwardSlotBool(bool value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalBool(value);
+    Q_EMIT forwardSignalBool(value);
     unlock();
 }
 
@@ -223,7 +223,7 @@ void KisAcyclicSignalConnector::backwardSlotBool(bool value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalBool(value);
+    Q_EMIT backwardSignalBool(value);
     unlock();
 }
 
@@ -232,7 +232,7 @@ void KisAcyclicSignalConnector::forwardSlotVoid()
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalVoid();
+    Q_EMIT forwardSignalVoid();
     unlock();
 }
 
@@ -241,7 +241,7 @@ void KisAcyclicSignalConnector::backwardSlotVoid()
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalVoid();
+    Q_EMIT backwardSignalVoid();
     unlock();
 }
 
@@ -250,7 +250,7 @@ void KisAcyclicSignalConnector::forwardSlotVariant(const QVariant &value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalVariant(value);
+    Q_EMIT forwardSignalVariant(value);
     unlock();
 }
 
@@ -259,7 +259,7 @@ void KisAcyclicSignalConnector::backwardSlotVariant(const QVariant &value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalVariant(value);
+    Q_EMIT backwardSignalVariant(value);
     unlock();
 }
 
@@ -268,7 +268,7 @@ void KisAcyclicSignalConnector::forwardSlotResourcePair(int key, const QVariant
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalResourcePair(key, resource);
+    Q_EMIT forwardSignalResourcePair(key, resource);
     unlock();
 }
 
@@ -277,7 +277,7 @@ void KisAcyclicSignalConnector::backwardSlotResourcePair(int key, const QVariant
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalResourcePair(key, resource);
+    Q_EMIT backwardSignalResourcePair(key, resource);
     unlock();
 }
 
@@ -286,7 +286,7 @@ void KisAcyclicSignalConnector::forwardSlotKoColor(const KoColor &value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit forwardSignalKoColor(value);
+    Q_EMIT forwardSignalKoColor(value);
     unlock();
 }
 
@@ -295,6 +295,6 @@ void KisAcyclicSignalConnector::backwardSlotKoColor(const KoColor &value)
     if (m_signalsBlocked) return;
 
     lock();
-    emit backwardSignalKoColor(value);
+    Q_EMIT backwardSignalKoColor(value);
     unlock();
 }
