@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2007,2010 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2007, 2010 Cyrille Berger <cberger@cberger.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <brushengine/kis_paint_information.h>
@@ -457,6 +445,11 @@ qreal KisPaintInformation::drawingSpeed() const
     return d->speed;
 }
 
+void KisPaintInformation::setCurrentTime(qreal time) const {
+
+    d->time =  time;
+}
+
 qreal KisPaintInformation::rotation() const
 {
     return d->rotation;
@@ -501,6 +494,7 @@ KisRandomSourceSP KisPaintInformation::randomSource() const
 {
     if (!d->randomSource) {
         qWarning() << "Accessing uninitialized random source!";
+        qDebug().noquote() << kisBacktrace();
         d->randomSource = new KisRandomSource();
     }
 
