@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2016 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2016 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __KIS_STANDARD_UNIFORM_PROPERTIES_FACTORY_H
@@ -23,7 +11,7 @@
 
 #include "kis_uniform_paintop_property.h"
 
-class KisPaintopSettingsUpdateProxy;
+class KisPaintOpPresetUpdateProxy;
 
 namespace KisStandardUniformPropertiesFactory
 {
@@ -39,7 +27,7 @@ static const KoID spacing("spacing", ki18n("Spacing"));
      */
 KisUniformPaintOpPropertySP createProperty(const KoID &id,
                                            KisPaintOpSettingsRestrictedSP settings,
-                                           KisPaintopSettingsUpdateProxy *updateProxy);
+                                           KisPaintOpPresetUpdateProxy *updateProxy);
 
 /**
      * Factory for creating standard uniform properties. Right now
@@ -47,7 +35,7 @@ KisUniformPaintOpPropertySP createProperty(const KoID &id,
      */
 KisUniformPaintOpPropertySP createProperty(const QString &id,
                                            KisPaintOpSettingsRestrictedSP settings,
-                                           KisPaintopSettingsUpdateProxy *updateProxy);
+                                           KisPaintOpPresetUpdateProxy *updateProxy);
 }
 
 #endif /* __KIS_STANDARD_UNIFORM_PROPERTIES_FACTORY_H */
