@@ -80,26 +80,16 @@ int KisSavedCommand::id() const
 
 bool KisSavedCommand::mergeWith(const KUndo2Command* command)
 {
-    const KisSavedCommand *other =
-        dynamic_cast<const KisSavedCommand*>(command);
-
-    if (other) {
-        command = other->m_command.data();
-    }
-
-    return m_command->mergeWith(command);
+    return unwrap(command, [this] (const KUndo2Command *cmd) {
+        return m_command->mergeWith(cmd);
+    });
 }
 
 bool KisSavedCommand::canAnnihilateWith(const KUndo2Command *command) const
 {
-    const KisSavedCommand *other =
-        dynamic_cast<const KisSavedCommand*>(command);
-
-    if (other) {
-        command = other->m_command.data();
-    }
-
-    return m_command->canAnnihilateWith(command);
+    return unwrap(command, [this] (const KUndo2Command *cmd) {
+        return m_command->canAnnihilateWith(cmd);
+    });
 }
 
 void KisSavedCommand::addCommands(KisStrokeId id, bool undo)
@@ -107,7 +97,7 @@ void KisSavedCommand::addCommands(KisStrokeId id, bool undo)
     strokesFacade()->
         addJob(id, new KisStrokeStrategyUndoCommandBased::Data(m_command, undo));
 }
-int KisSavedCommand::timedId()
+int KisSavedCommand::timedId() const
 {
     return m_command->timedId();
 }
@@ -118,31 +108,36 @@ void KisSavedCommand::setTimedID(int timedID)
 
 bool KisSavedCommand::timedMergeWith(KUndo2Command *other)
 {
+    /// Since we are saving the actual command inside another
+    /// command, so we cannot unwrap the command here. Otherwise
+    /// the shared pointer in `other` will destroy the merged
+    /// command some time later.
+
     return m_command->timedMergeWith(other);
 }
-QVector<KUndo2Command*> KisSavedCommand::mergeCommandsVector()
+QVector<KUndo2Command*> KisSavedCommand::mergeCommandsVector() const
 {
     return m_command->mergeCommandsVector();
 }
-void KisSavedCommand::setTime()
+void KisSavedCommand::setTime(const QTime &time)
 {
-    m_command->setTime();
+    m_command->setTime(time);
 }
 
-QTime KisSavedCommand::time()
+QTime KisSavedCommand::time() const
 {
     return m_command->time();
 }
-void KisSavedCommand::setEndTime()
+void KisSavedCommand::setEndTime(const QTime &time)
 {
-    m_command->setEndTime();
+    m_command->setEndTime(time);
 }
 
-QTime KisSavedCommand::endTime()
+QTime KisSavedCommand::endTime() const
 {
     return m_command->endTime();
 }
-bool KisSavedCommand::isMerged()
+bool KisSavedCommand::isMerged() const
 {
     return m_command->isMerged();
 }
