@@ -25,8 +25,18 @@ public:
 
     KisFilterConfigurationSP clone() const override;
 
+    void setProperty(const QString &name, const QVariant &value) override;
+
     KoColorTransformation *colorTransformation(const KoColorSpace *cs, const KisColorTransformationFilter *filter) const;
 
+    /**
+     * @brief Manually invalidate the cache. By default @ref setProperty
+     *        invalidates the cache but this method can be used in subclasses
+     *        when setProperty is not used to set options. This forces the
+     *        regeneration of the color transforms.
+     */
+    void invalidateColorTransformationCache();
+
 private:
     struct Private;
     Private* const d;
