@@ -40,7 +40,7 @@ struct Q_DECL_HIDDEN KisCloneLayer::Private
 
     KisLayerSP copyFrom;
     KisNodeUuidInfo copyFromInfo;
-    CopyLayerType type;
+    CopyLayerType type {COPY_PROJECTION};
 };
 
 KisCloneLayer::KisCloneLayer(KisLayerSP from, KisImageWSP image, const QString &name, quint8 opacity)
@@ -102,6 +102,7 @@ KisLayerSP KisCloneLayer::reincarnateAsPaintLayer() const
 void KisCloneLayer::setImage(KisImageWSP image)
 {
     m_d->fallback->setDefaultBounds(new KisDefaultBounds(image));
+    m_d->offset.setDefaultBounds(new KisDefaultBounds(image));
     KisLayer::setImage(image);
 }
 
@@ -134,7 +135,12 @@ KisPaintDeviceSP KisCloneLayer::original() const
 
 bool KisCloneLayer::needProjection() const
 {
-return m_d->offset.x() || m_d->offset.y();
+    return m_d->offset->x() || m_d->offset->y();
+}
+
+const KoColorSpace *KisCloneLayer::colorSpace() const
+{
+    return m_d->copyFrom ? m_d->copyFrom->colorSpace() : m_d->fallback->colorSpace();
 }
 
 void KisCloneLayer::copyOriginalToProjection(const KisPaintDeviceSP original,
@@ -142,12 +148,12 @@ void KisCloneLayer::copyOriginalToProjection(const KisPaintDeviceSP original,
         const QRect& rect) const
 {
     QRect copyRect = rect;
-    copyRect.translate(-m_d->offset.x(), -m_d->offset.y());
+    copyRect.translate(-m_d->offset->x(), -m_d->offset->y());
 
     KisPainter::copyAreaOptimized(rect.topLeft(), original, projection, copyRect);
 }
 
-void KisCloneLayer::setDirtyOriginal(const QRect &rect)
+void KisCloneLayer::setDirtyOriginal(const QRect &rect, bool dontInvalidateFrames)
 {
     /**
      * The original will be updated when the clone becomes visible
@@ -161,7 +167,11 @@ void KisCloneLayer::setDirtyOriginal(const QRect &rect)
      *        "copyOriginalToProjection" coordinate system. Now
      *        everything is done in "original()" space.
      */
-    KisLayer::setDirty(rect);
+    if (!dontInvalidateFrames) {
+        KisLayer::setDirty(rect);
+    } else {
+        KisLayer::setDirtyDontResetAnimationCache(rect);
+    }
 }
 
 void KisCloneLayer::notifyParentVisibilityChanged(bool value)
@@ -170,7 +180,13 @@ void KisCloneLayer::notifyParentVisibilityChanged(bool value)
     if (!imageSP) {
         return;
     }
-    KisLayer::setDirty(imageSP->bounds());
+    /**
+     * Trigger a full update when the layer is finally
+     * getting transitively-visible
+     */
+    if (value && visible(true)) {
+        KisLayer::setDirty(imageSP->bounds());
+    }
     KisLayer::notifyParentVisibilityChanged(value);
 }
 
@@ -198,19 +214,19 @@ QRect KisCloneLayer::needRectOnSourceForMasks(const QRect &rc) const
 
 qint32 KisCloneLayer::x() const
 {
-    return m_d->offset.x();
+    return m_d->offset->x();
 }
 qint32 KisCloneLayer::y() const
 {
-    return m_d->offset.y();
+    return m_d->offset->y();
 }
 void KisCloneLayer::setX(qint32 x)
 {
-    m_d->offset.setX(x);
+    m_d->offset->setX(x);
 }
 void KisCloneLayer::setY(qint32 y)
 {
-    m_d->offset.setY(y);
+    m_d->offset->setY(y);
 }
 
 QRect KisCloneLayer::extent() const
@@ -234,8 +250,8 @@ QRect KisCloneLayer::accessRect(const QRect &rect, PositionToFilthy pos) const
     QRect resultRect = rect;
 
     if(pos & (N_FILTHY_PROJECTION | N_FILTHY)) {
-        if (m_d->offset.x() || m_d->offset.y()) {
-            resultRect |= rect.translated(-m_d->offset.x(), -m_d->offset.y());
+        if (m_d->offset->x() || m_d->offset->y()) {
+            resultRect |= rect.translated(-m_d->offset->x(), -m_d->offset->y());
         }
 
         /**
@@ -251,7 +267,7 @@ QRect KisCloneLayer::accessRect(const QRect &rect, PositionToFilthy pos) const
 
 QRect KisCloneLayer::outgoingChangeRect(const QRect &rect) const
 {
-    return rect.translated(m_d->offset.x(), m_d->offset.y());
+    return rect.translated(m_d->offset->x(), m_d->offset->y());
 }
 
 bool KisCloneLayer::accept(KisNodeVisitor & v)
@@ -320,6 +336,6 @@ KisBaseNode::PropertyList KisCloneLayer::sectionModelProperties() const
 void KisCloneLayer::syncLodCache()
 {
     KisLayer::syncLodCache();
-    m_d->offset.syncLodOffset();
+    m_d->offset.syncLodCache();
 }
 
