@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2004 Boudewijn Rempt (boud@valdyas.org)
- *  Copyright (c) 2004-2006 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2004 Boudewijn Rempt (boud@valdyas.org)
+ *  SPDX-FileCopyrightText: 2004-2006 Cyrille Berger <cberger@cberger.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #ifndef _KIS_CONFIG_WIDGET_H_
 #define _KIS_CONFIG_WIDGET_H_
@@ -25,12 +13,16 @@
 #include "kis_signal_compressor.h"
 #include <kis_properties_configuration.h>
 
+class KoCanvasResourcesInterface;
+using KoCanvasResourcesInterfaceSP = QSharedPointer<KoCanvasResourcesInterface>;
+
+
 class KisViewManager;
 
 /**
  * Empty base class. Configurable resources like filters, paintops etc.
  * can build their own configuration widgets that inherit this class.
- * The configuration widget should emit sigConfigurationItemChanged
+ * The configuration widget should Q_EMIT sigConfigurationItemChanged
  * when it wants a preview updated; there is a timer that
  * waits a little time to see if there are more changes coming
  * and then emits sigConfigurationUpdated.
@@ -63,6 +55,9 @@ public:
      */
     virtual void setView(KisViewManager *view);
 
+    virtual void setCanvasResourcesInterface(KoCanvasResourcesInterfaceSP canvasResourcesInterface);
+    virtual KoCanvasResourcesInterfaceSP canvasResourcesInterface() const;
+
 Q_SIGNALS:
 
     /**
@@ -71,7 +66,7 @@ Q_SIGNALS:
     void sigConfigurationUpdated();
 
     /**
-     * Subclasses should emit this signal whenever the preview should be
+     * Subclasses should Q_EMIT this signal whenever the preview should be
      * be recalculated. This kicks of a timer, so it's perfectly fine
      * to connect this to the changed signals of the widgets in your configuration
      * widget.
@@ -86,6 +81,7 @@ private Q_SLOTS:
 
 private:
     KisSignalCompressor m_compressor;
+    KoCanvasResourcesInterfaceSP m_canvasResourcesInterface;
 };
 
 
