@@ -33,6 +33,7 @@
 #include "KoColorSpace.h"
 #include <KoChannelInfo.h>
 #include "kis_types.h"
+#include "kis_default_bounds.h"
 
 #include "kis_selection.h"
 
@@ -133,7 +134,7 @@ void KisConvolutionPainter::applyMatrix(const KisConvolutionKernelSP kernel, con
      * because the paint device has its own special
      * iterators, which do everything for us.
      */
-    if (src->defaultBounds()->wrapAroundMode()) {
+    if (src->defaultBounds()->wrapAroundMode() && src->supportsWraproundMode()) {
         borderOp = BORDER_IGNORE;
     }
 
@@ -143,7 +144,7 @@ void KisConvolutionPainter::applyMatrix(const KisConvolutionKernelSP kernel, con
         /**
          * We don't use defaultBounds->topLevelWrapRect(), because
          * the main purpose of this wrapping is "getting expected
-         * results when applying to the the layer". If a mask is bigger
+         * results when applying to the layer". If a mask is bigger
          * than the image, then it should be wrapped around the mask
          * instead.
          */
@@ -158,7 +159,7 @@ void KisConvolutionPainter::applyMatrix(const KisConvolutionKernelSP kernel, con
         /**
          * FIXME: Implementation can return empty destination device
          * on faults and has no way to report this. This will cause a crash
-         * on sequential convolutions inside iteratiors.
+         * on sequential convolutions inside iterators.
          *
          * o implementation should do it's work or assert otherwise
          *   (or report the issue somehow)
