@@ -1,21 +1,9 @@
 /*
- *  Copyright (c) 2004 Michael Thaler <michael.thaler@physik.tu-muenchen.de>
- *  Copyright (c) 2005 C. Boemann <cbo@boemann.dk>
- *  Copyright (c) 2013 Juan Palacios <jpalaciosdev@gmail.com>
+ *  SPDX-FileCopyrightText: 2004 Michael Thaler <michael.thaler@physik.tu-muenchen.de>
+ *  SPDX-FileCopyrightText: 2005 C. Boemann <cbo@boemann.dk>
+ *  SPDX-FileCopyrightText: 2013 Juan Palacios <jpalaciosdev@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KIS_FILTER_STRATEGY_H_
@@ -26,6 +14,7 @@
 #include "KoGenericRegistry.h"
 #include "KoID.h"
 #include "kritaimage_export.h"
+#include <QSize>
 
 class KRITAIMAGE_EXPORT KisFilterStrategy
 {
@@ -60,8 +49,8 @@ public:
     }
 
 protected:
-    qreal supportVal;
-    qint32 intSupportVal;
+    qreal supportVal {0.0};
+    qint32 intSupportVal {0};
     KoID m_id;
 };
 
@@ -200,6 +189,11 @@ public:
      */
     QString formattedDescriptions() const;
 
+    /**
+     * Try to select an appropriate image filtering strategy based on original and desired parameters.
+     */
+    KisFilterStrategy* autoFilterStrategy(QSize originalSize, QSize desiredSize) const;
+
 private:
 
     KisFilterStrategyRegistry(const KisFilterStrategyRegistry&);
