@@ -32,8 +32,8 @@ public:
     void setScale(qreal scaleX, qreal scaleY) override;
 
     bool shouldVectorize() const override;
-    KisBrushMaskApplicatorBase* applicator() override;
-    void resetMaskApplicator(bool forceScalar);
+    KisBrushMaskApplicatorBase *applicator() const override;
+    void setMaskScalarApplicator();
 
 private:
     struct Private;
