@@ -372,6 +372,14 @@ public:
                                 KoColorConversionTransformation::Intent renderingIntent,
                                 KoColorConversionTransformation::ConversionFlags conversionFlags);
 
+    /**
+     * Unify layers color space
+     *
+     * If any of the layers have color space different from the image color space,
+     * convert them into the image color space.
+     */
+    void unifyLayersColorSpace();
+
     /**
      * Convert layer and all its child layers to dstColorSpace
      */
