@@ -45,7 +45,7 @@ void KisMacroBasedUndoStore::addCommand(KUndo2Command *cmd)
     cmd->redo();
     m_d->command->addCommand(toQShared(cmd));
 
-    emit historyStateChanged();
+    Q_EMIT historyStateChanged();
 }
 
 void KisMacroBasedUndoStore::beginMacro(const KUndo2MagicString& macroName)
