@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2006 Cyrille Berger <cberger@cberger.net>
- *  Copyright (c) 2010 Marc Pegon <pe.marc@free.fr>
+ *  SPDX-FileCopyrightText: 2006 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2010 Marc Pegon <pe.marc@free.fr>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KIS_PERSPECTIVETRANSFORM_WORKER_H
@@ -32,8 +20,8 @@
 class KRITAIMAGE_EXPORT KisPerspectiveTransformWorker
 {
 public:
-    KisPerspectiveTransformWorker(KisPaintDeviceSP dev, QPointF center, double aX, double aY, double distance, KoUpdaterPtr progress);
-    KisPerspectiveTransformWorker(KisPaintDeviceSP dev, const QTransform &transform, KoUpdaterPtr progress);
+    KisPerspectiveTransformWorker(KisPaintDeviceSP dev, QPointF center, double aX, double aY, double distance, bool cropDst, KoUpdaterPtr progress);
+    KisPerspectiveTransformWorker(KisPaintDeviceSP dev, const QTransform &transform, bool cropDst, KoUpdaterPtr progress);
 
     ~KisPerspectiveTransformWorker();
 
@@ -52,6 +40,9 @@ public:
     QTransform forwardTransform() const;
     QTransform backwardTransform() const;
 
+    bool forceSubPixelTranslation() const;
+    void setForceSubPixelTranslation(bool value);
+
 private:
     void init(const QTransform &transform);
 
@@ -72,6 +63,8 @@ private:
     QTransform m_forwardTransform;
     bool m_isIdentity;
     bool m_isTranslating;
+    bool m_cropDst;
+    bool m_forceSubPixelTranslation {false};
 };
 
 #endif
