@@ -245,6 +245,12 @@ KisPaintDeviceSP KisProjectionLeaf::projection()
     return m_d->node->projection();
 }
 
+KisPaintDeviceSP KisProjectionLeaf::lazyDestinationForSubtreeComposition()
+{
+    const KisGroupLayer *group = qobject_cast<const KisGroupLayer*>(m_d->node.data());
+    return group ? group->lazyDestinationForSubtreeComposition() : nullptr;
+}
+
 bool KisProjectionLeaf::isRoot() const
 {
     return (bool)!m_d->node->parent();
@@ -298,7 +304,7 @@ quint8 KisProjectionLeaf::opacity() const
     if (m_d->checkParentPassThrough()) {
         quint8 parentOpacity = m_d->node->parent()->projectionLeaf()->opacity();
 
-        resultOpacity = KritaUtils::mergeOpacity(resultOpacity, parentOpacity);
+        resultOpacity = KritaUtils::mergeOpacityU8(resultOpacity, parentOpacity);
     }
 
     return resultOpacity;
