@@ -14,12 +14,14 @@
 #include "kis_abstract_projection_plane.h"
 #include "kis_transform_mask_params_interface.h"
 
-KisRecalculateTransformMaskJob::KisRecalculateTransformMaskJob(KisTransformMaskSP mask)
+KisRecalculateTransformMaskJob::KisRecalculateTransformMaskJob(KisTransformMaskSP mask, const QRect &extraUpdateRect)
     : m_mask(mask)
+    , m_extraUpdateRect(extraUpdateRect)
 {
     setExclusive(true);
 }
 
+
 bool KisRecalculateTransformMaskJob::overrides(const KisSpontaneousJob *_otherJob)
 {
     const KisRecalculateTransformMaskJob *otherJob =
@@ -36,6 +38,7 @@ void KisRecalculateTransformMaskJob::run()
      */
     if (!m_mask->parent()) return;
     if (!m_mask->visible()) return;
+    if (m_mask->staticImageCacheIsValid()) return;
 
     const QRect oldMaskExtent = m_mask->extent();
     m_mask->recalculateStaticImage();
@@ -60,6 +63,8 @@ void KisRecalculateTransformMaskJob::run()
     if (m_mask->transformParams()->isHidden()) {
         QRect updateRect = m_mask->extent() | oldMaskExtent;
 
+        updateRect |= m_extraUpdateRect;
+
         if (layer->original()) {
             updateRect |= layer->original()->defaultBounds()->bounds();
         }
@@ -71,7 +76,7 @@ void KisRecalculateTransformMaskJob::run()
         }
     } else {
         /**
-         * When we call requestProjectionUpdateNoFilthy() on a layer,
+         * When we call NoFilthy update on a layer,
          * its masks' change rect is not counted, because it is considered
          * to be N_ABOVE_FILTHY. Therefore, we should expand the dirty
          * rect manually to get the correct update
@@ -79,9 +84,12 @@ void KisRecalculateTransformMaskJob::run()
         QRect updateRect = oldMaskExtent |
             layer->projectionPlane()->changeRect(layer->extent(), KisLayer::N_FILTHY);
 
-        if (!m_mask->isAnimated()) {
-            image->requestProjectionUpdateNoFilthy(layer, updateRect, image->bounds(), false); // Should there be a case where this is flushed?
-        }
+        updateRect |= m_extraUpdateRect;
+
+        // Should there be a case where this is flushed?
+        image->requestProjectionUpdate(layer.data(), {updateRect},
+                                       KisProjectionUpdateFlag::NoFilthy |
+                                           KisProjectionUpdateFlag::DontInvalidateFrames);
     }
 }
 
