@@ -401,9 +401,13 @@ void KisTransformMask::recalculateStaticImage()
      * updateProjection() is assuming that the requestedRect takes
      * into account all the change rects of all the masks. Usually,
      * this work is done by the walkers.
+     *
+     * NOTE: we should use layer's exact bounds, not its original
+     * paint device's exact bounds; it is necessary because the layer
+     * may have onion skins, which are a part of layer's bounds.
      */
     QRect requestedRect =
-        parentLayer->changeRect(parentLayer->original()->exactBounds());
+        parentLayer->changeRect(parentLayer->exactBounds());
 
 
     QRect bounds;
@@ -434,14 +438,15 @@ void KisTransformMask::recalculateStaticImage()
      * the layer and after that a special update call (no-filthy) will
      * be issued to pass the changed further through the stack.
      */
-    parentLayer->updateProjection(requestedRect, this);
+    parentLayer->updateProjection(requestedRect, this, KisRenderPassFlag::NoTransformMaskUpdates);
     m_d->recalculatingStaticImage = false;
 }
 
 QRect KisTransformMask::decorateRect(KisPaintDeviceSP &src,
                                      KisPaintDeviceSP &dst,
                                      const QRect & rc,
-                                     PositionToFilthy maskPos) const
+                                     PositionToFilthy maskPos,
+                                     KisRenderPassFlags flags) const
 {
     Q_ASSERT_X(src != dst, "KisTransformMask::decorateRect",
                "src must be != dst, because we can't create transactions "
@@ -481,7 +486,12 @@ QRect KisTransformMask::decorateRect(KisPaintDeviceSP &src,
     if (!m_d->staticCache.isCacheOverridden() &&
         !m_d->recalculatingStaticImage &&
         (maskPos == N_FILTHY || maskPos == N_ABOVE_FILTHY ||
-         !m_d->staticCache.isCacheValid(params))) {
+         !m_d->staticCache.isCacheValid(params)) &&
+
+        /// clone layers may fetch data outside image bounds,
+        /// that should never cause async refresh, since it will
+        /// cause an infinite loop
+        !flags.testFlag(KisRenderPassFlag::NoTransformMaskUpdates)) {
 
         if (m_d->testingInterface) {
             m_d->testingInterface->notifyDecorateRectTriggeredStaticImageUpdate();
@@ -768,7 +778,7 @@ void KisTransformMask::threadSafeForceStaticImageUpdate(const QRect &extraUpdate
     if (!extraUpdateRect.isEmpty()) {
         m_d->forcedStaticUpdateExtraUpdateRect.addRect(extraUpdateRect);
     }
-    emit sigInternalForceStaticImageUpdate();
+    Q_EMIT sigInternalForceStaticImageUpdate();
 }
 
 void KisTransformMask::slotInternalForceStaticImageUpdate()
