@@ -19,7 +19,7 @@ KisUndoAdapter::~KisUndoAdapter()
 
 void KisUndoAdapter::emitSelectionChanged()
 {
-    emit selectionChanged();
+    Q_EMIT selectionChanged();
 }
 
 
