@@ -138,66 +138,26 @@ void KisUpdateScheduler::progressUpdate()
     }
 }
 
-void KisUpdateScheduler::updateProjection(KisNodeSP node, const QVector<QRect> &rects, const QRect &cropRect)
+void KisUpdateScheduler::updateProjection(KisNodeSP node, const QVector<QRect> &rects, const QRect &cropRect, KisProjectionUpdateFlags flags)
 {
-    m_d->updatesQueue.addUpdateJob(node, rects, cropRect, currentLevelOfDetail());
+    m_d->updatesQueue.addUpdateJob(node, rects, cropRect, currentLevelOfDetail(), flags);
+    processQueues();
+}
+
+void KisUpdateScheduler::fullRefreshAsync(KisNodeSP root, const QVector<QRect>& rects, const QRect &cropRect, KisProjectionUpdateFlags flags)
+{
+    m_d->updatesQueue.addFullRefreshJob(root, rects, cropRect, currentLevelOfDetail(), flags);
     processQueues();
 }
 
 void KisUpdateScheduler::updateProjection(KisNodeSP node, const QRect &rc, const QRect &cropRect)
 {
-    m_d->updatesQueue.addUpdateJob(node, rc, cropRect, currentLevelOfDetail());
-    processQueues();
+    updateProjection(node, {rc}, cropRect, KisProjectionUpdateFlag::None);
 }
 
-void KisUpdateScheduler::updateProjectionNoFilthy(KisNodeSP node, const QVector<QRect>& rects, const QRect &cropRect)
+void KisUpdateScheduler::fullRefreshAsync(KisNodeSP root, const QRect &rc, const QRect &cropRect)
 {
-    m_d->updatesQueue.addUpdateNoFilthyJob(node, rects, cropRect, currentLevelOfDetail());
-    processQueues();
-}
-
-void KisUpdateScheduler::updateProjectionNoFilthy(KisNodeSP node, const QRect& rc, const QRect &cropRect)
-{
-    m_d->updatesQueue.addUpdateNoFilthyJob(node, rc, cropRect, currentLevelOfDetail());
-    processQueues();
-}
-
-void KisUpdateScheduler::fullRefreshAsync(KisNodeSP root, const QVector<QRect>& rects, const QRect &cropRect)
-{
-    m_d->updatesQueue.addFullRefreshJob(root, rects, cropRect, currentLevelOfDetail());
-    processQueues();
-}
-
-void KisUpdateScheduler::fullRefreshAsyncNoFilthy(KisNodeSP root, const QVector<QRect> &rects, const QRect &cropRect)
-{
-    m_d->updatesQueue.addFullRefreshNoFilthyJob(root, rects, cropRect, currentLevelOfDetail());
-    processQueues();
-}
-
-void KisUpdateScheduler::fullRefresh(KisNodeSP root, const QRect& rc, const QRect &cropRect)
-{
-    KisBaseRectsWalkerSP walker = new KisFullRefreshWalker(cropRect);
-    walker->collectRects(root, rc);
-
-    bool needLock = true;
-
-    if(m_d->processingBlocked) {
-        warnImage << "WARNING: Calling synchronous fullRefresh under a scheduler lock held";
-        warnImage << "We will not assert for now, but please port caller's to strokes";
-        warnImage << "to avoid this warning";
-        needLock = false;
-    }
-
-    if(needLock) immediateLockForReadOnly();
-    m_d->updaterContext.lock();
-
-    Q_ASSERT(m_d->updaterContext.isJobAllowed(walker));
-    m_d->updaterContext.addMergeJob(walker);
-    m_d->updaterContext.unlock();
-
-    m_d->updaterContext.waitForDone();
-
-    if(needLock) unlock(true);
+    fullRefreshAsync(root, {rc}, cropRect, KisProjectionUpdateFlag::None);
 }
 
 void KisUpdateScheduler::addSpontaneousJob(KisSpontaneousJob *spontaneousJob)
