@@ -15,6 +15,7 @@
 #include "kis_stroke_strategy_factory.h"
 #include "kis_strokes_queue_undo_result.h"
 #include "KisLodPreferences.h"
+#include "KisProjectionUpdateFlags.h"
 
 class QRect;
 class KoProgressProxy;
@@ -72,7 +73,7 @@ public:
      * Waits until all the running jobs are finished.
      *
      * If some other thread adds jobs in parallel, then you may
-     * wait forever. If you you don't want it, consider lock() instead.
+     * wait forever. If you don't want it, consider lock() instead.
      *
      * \see lock()
      */
@@ -83,7 +84,7 @@ public:
      * To unblock processing you should use unlock().
      *
      * If some other thread adds jobs in parallel, then you may
-     * wait forever. If you you don't want it, consider lock() instead.
+     * wait forever. If you don't want it, consider lock() instead.
      *
      * \see unlock(), lock()
      */
@@ -124,13 +125,15 @@ public:
      */
     void unblockUpdates();
 
-    void updateProjection(KisNodeSP node, const QVector<QRect> &rects, const QRect &cropRect);
+    void updateProjection(KisNodeSP node, const QVector<QRect> &rects, const QRect &cropRect, KisProjectionUpdateFlags flags);
+    void fullRefreshAsync(KisNodeSP root, const QVector<QRect>& rects, const QRect &cropRect, KisProjectionUpdateFlags flags);
+
+    // simplified override for testing purposes
     void updateProjection(KisNodeSP node, const QRect &rc, const QRect &cropRect);
-    void updateProjectionNoFilthy(KisNodeSP node, const QVector<QRect>& rects, const QRect &cropRect);
-    void updateProjectionNoFilthy(KisNodeSP node, const QRect& rc, const QRect &cropRect);
-    void fullRefreshAsync(KisNodeSP root, const QVector<QRect>& rc, const QRect &cropRect);
-    void fullRefreshAsyncNoFilthy(KisNodeSP root, const QVector<QRect>& rects, const QRect &cropRect);
-    void fullRefresh(KisNodeSP root, const QRect& rc, const QRect &cropRect);
+
+    // simplified override for testing purposes
+    void fullRefreshAsync(KisNodeSP root, const QRect &rc, const QRect &cropRect);
+
     void addSpontaneousJob(KisSpontaneousJob *spontaneousJob);
 
     bool hasUpdatesRunning() const;
@@ -177,10 +180,20 @@ public:
     /**
      * Sets a callback that is called by the scheduler in the
      * beginning of every stroke that declared the necessity
-     * of the redo state clearence.
+     * of the redo state clearance.
      */
     void setPurgeRedoStateCallback(const std::function<void()> &callback);
 
+    /**
+     * Sets a callback that is called bu the scheduler when it
+     * thinks that Lod0 tiles **in the GUI** should be refetched
+     * by the GUI. Such situation happens in cases when a Lod0
+     * stroke has been cancelled, after its LodN buddy has managed
+     * to do some manipulations on the canvas. Without this call
+     * the GUI will still contain LodN tiles active.
+     */
+    void setPostSyncLod0GUIPlaneRequestForResumeCallback(const std::function<void()> &callback);
+
     KisPostExecutionUndoAdapter* lodNPostExecutionUndoAdapter() const;
 
 
