@@ -8,6 +8,7 @@
 #define __KIS_WRAPPED_RANDOM_ACCESSOR_H
 
 #include "tiles3/kis_random_accessor.h"
+#include "KisWraparoundAxis.h"
 
 
 class KisWrappedRandomAccessor : public KisRandomAccessor2
@@ -17,7 +18,8 @@ public:
                              qint32 offsetX, qint32 offsetY,
                              bool writable,
                              KisIteratorCompleteListener *completeListener,
-                             const QRect &wrapRect);
+                             const QRect &wrapRect,
+                             const WrapAroundAxis wrapAroundModeAxis);
 
     void moveTo(qint32 x, qint32 y) override;
     qint32 numContiguousColumns(qint32 x) const override;
@@ -30,6 +32,7 @@ public:
 private:
     QRect m_wrapRect;
     QPoint m_currentPos;
+    WrapAroundAxis m_wrapAxis;
 };
 
 #endif /* __KIS_WRAPPED_RANDOM_ACCESSOR_H */
