@@ -48,7 +48,7 @@ private:
                          KisMultipleProjection *dst,
                          const QRect &applyRect,
                          const psd_layer_effects_context *context,
-                         const psd_layer_effects_shadow_base *shadow, KisResourcesInterfaceSP resourcesIntrerface,
+                         const psd_layer_effects_shadow_base *shadow, KisResourcesInterfaceSP resourcesInterface,
                          KisLayerStyleFilterEnvironment *env) const;
 
 private:
