@@ -1,3 +1,7 @@
+/*
+ *  SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #include "KisSelectionBasedProcessingHelper.h"
 
 #include "kis_paint_device.h"
@@ -32,7 +36,7 @@ KUndo2Command *KisSelectionBasedProcessingHelper::createInitCommand(Functor func
         {
         }
 
-        KUndo2Command* paint() {
+        KUndo2Command* paint() override {
             m_cutSelection->pixelSelection()->makeCloneFromRough(m_selection->pixelSelection(), m_selection->selectedRect());
 
             KisTransaction t(m_selection->pixelSelection());
