@@ -144,7 +144,7 @@ void KisFixedPaintDeviceTest::testBltFixedOpacity()
     QPoint errpoint;
 
     if (!TestUtil::compareQImages(errpoint, checkResult, result, 1)) {
-        checkResult.save("kis_fixed_paint_device_test_test_blt_fixed_opactiy_expected.png");
+        checkResult.save("kis_fixed_paint_device_test_test_blt_fixed_opacity_expected.png");
         result.save("kis_fixed_paint_device_test_test_blt_fixed_opacity_result.png");
         QFAIL(QString("Failed to create identical image, first different pixel: %1,%2 \n").arg(errpoint.x()).arg(errpoint.y()).toLatin1());
     }
