@@ -10,7 +10,7 @@
 #include <simpletest.h>
 
 #include "kis_node.h"
-#include <sdk/tests/testing_nodes.h>
+#include <testing_nodes.h>
 
 class TestNode : public TestUtil::DefaultNode
 {
