@@ -15,6 +15,7 @@
 #include <KoColorSpaceRegistry.h>
 #include <KoCompositeOp.h>
 #include "kis_image.h"
+#include "kis_default_bounds.h"
 #include "kis_paint_layer.h"
 #include "kis_paint_device.h"
 #include "kis_fixed_paint_device.h"
@@ -368,7 +369,7 @@ void KisPixelSelectionTest::testOutlineCacheTransactions()
 }
 
 #include "kis_paint_device_debug_utils.h"
-#include <sdk/tests/testing_timed_default_bounds.h>
+#include <testing_timed_default_bounds.h>
 
 bool compareRect(KisPixelSelectionSP psel, const QRect &rc)
 {
