@@ -1,20 +1,7 @@
     /*
- * Copyright (c) 2016 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2016 Boudewijn Rempt <boud@valdyas.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef KISMIMEDATABASE_H
 #define KISMIMEDATABASE_H
@@ -34,7 +21,7 @@ class KRITAPLUGIN_EXPORT KisMimeDatabase
 public:
 
     /// Find the mimetype for the given filename. The filename must include a suffix.
-    static QString mimeTypeForFile(const QString &file);
+    static QString mimeTypeForFile(const QString &file, bool checkExistingFiles = true);
     /// Find the mimetype for a given extension. The extension may have the form "*.xxx" or "xxx"
     static QString mimeTypeForSuffix(const QString &suffix);
     /// Find the mimetype through analyzing the contents. This does not work for Krita's
