@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2017 Wolthera van Hövell tot Westerflier <griffinvalley@gmail.com>
+ *  SPDX-FileCopyrightText: 2017 Wolthera van Hövell tot Westerflier <griffinvalley@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "FilterLayer.h"
 #include <kis_adjustment_layer.h>
@@ -24,7 +12,7 @@
 #include <kis_selection.h>
 
 FilterLayer::FilterLayer(KisImageSP image, QString name, Filter &filter, Selection &selection, QObject *parent) :
-    Node(image, new KisAdjustmentLayer(image, name, filter.filterConfig(), selection.selection()), parent)
+    Node(image, new KisAdjustmentLayer(image, name, filter.filterConfig()->cloneWithResourcesSnapshot(), selection.selection()), parent)
 {
 
 }
@@ -51,7 +39,7 @@ void FilterLayer::setFilter(Filter &filter)
     KisAdjustmentLayer *layer = dynamic_cast<KisAdjustmentLayer*>(this->node().data());
     //getting the default configuration here avoids trouble with versioning.
     if (layer) {
-        layer->setFilter(filter.filterConfig());
+        layer->setFilter(filter.filterConfig()->cloneWithResourcesSnapshot());
     }
 }
 
