@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2.1 of the License, or
- *  (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "kis_meta_data_type_info.h"
@@ -22,7 +10,7 @@
 
 struct KRITAMETADATA_EXPORT KisMetaData::TypeInfo::Private {
     Private() : embeddedTypeInfo(0), structureSchema(0), parser(0) {}
-    PropertyType propertyType;
+    PropertyType propertyType { KisMetaData::TypeInfo::BooleanType };
     const TypeInfo* embeddedTypeInfo;
     QList< Choice> choices;
     Schema* structureSchema;
