@@ -1,26 +1,14 @@
 /*
- *  Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
- *  Copyright (c) 2006-2007 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2005 Boudewijn Rempt <boud@valdyas.org>
+ *  SPDX-FileCopyrightText: 2006-2007 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2021 L. E. Segovia <amy@amyspark.me>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #ifndef KOCOLORSPACE_H
 #define KOCOLORSPACE_H
 
-#include <limits.h>
+#include <climits>
 
 #include <QImage>
 #include <QHash>
@@ -32,6 +20,7 @@
 #include "KoColorConversionTransformation.h"
 #include "KoColorProofingConversionTransformation.h"
 #include "KoCompositeOp.h"
+#include "KisDitherOp.h"
 #include <KoID.h>
 #include "kritapigment_export.h"
 
@@ -96,7 +85,7 @@ protected:
 public:
 
     /// Should be called by real color spaces
-    KoColorSpace(const QString &id, const QString &name, KoMixColorsOp* mixColorsOp, KoConvolutionOp* convolutionOp);
+    KoColorSpace(const QString &id, const QString &name, KoMixColorsOp *mixColorsOp, KoConvolutionOp *convolutionOp);
 
     virtual bool operator==(const KoColorSpace& rhs) const;
 protected:
@@ -131,6 +120,11 @@ public:
      */
     virtual quint32 channelCount() const = 0;
 
+    /**
+     * Position of the alpha channel in a pixel
+     */
+    virtual quint32 alphaPos() const = 0;
+
     /**
      * The total number of color channels (excludes alpha) for a single
      * pixel in this color model.
@@ -238,8 +232,10 @@ public:
 
     /**
      * Tests if the colorspace offers the specific composite op.
+     * @param srcSpace optional source color space. Some color spaces prefer blitting in source
+     *        color space. If already known, additional composite ops may be available.
      */
-    virtual bool hasCompositeOp(const QString & id) const;
+    virtual bool hasCompositeOp(const QString & id, const KoColorSpace *srcSpace = nullptr) const;
 
     /**
      * Returns the list of user-visible composite ops supported by this colorspace.
@@ -248,9 +244,12 @@ public:
 
     /**
      * Retrieve a single composite op from the ones this colorspace offers.
-     * If the requeste composite op does not exist, COMPOSITE_OVER is returned.
+     * If the requested composite op does not exist, COMPOSITE_OVER is returned.
+     * @param srcSpace optional source color space. Some color spaces prefer blitting in source
+     *        color space. If already known, additional composite ops may be available.
+     *        _Note_: if given, the returned op is only safe to use with this exact source color space!
      */
-    const KoCompositeOp * compositeOp(const QString & id) const;
+    const KoCompositeOp * compositeOp(const QString & id, const KoColorSpace *srcSpace = nullptr) const;
 
     /**
      * add a composite op to this colorspace.
@@ -263,7 +262,6 @@ public:
      */
     virtual bool hasHighDynamicRange() const = 0;
 
-
 //========== Display profiles =============================================//
 
     /**
@@ -274,6 +272,14 @@ public:
 
 //================= Conversion functions ==================================//
 
+    /**
+     * Fills the provided buffer with fully transparent color in this
+     * color space.
+     *
+     * Not all color spaces support conversion from QColor (e.g. InputClass
+     * spaces), so for them we need to generate this color separately.
+     */
+    virtual void transparentColor(quint8 *dst, quint32 nPixels) const;
 
     /**
      * The fromQColor methods take a given color defined as an RGB QColor
@@ -282,9 +288,8 @@ public:
      *
      * @param color the QColor that will be used to fill dst
      * @param dst a pointer to a pixel
-     * @param profile the optional profile that describes the color values of QColor
      */
-    virtual void fromQColor(const QColor& color, quint8 *dst, const KoColorProfile * profile = 0) const = 0;
+    virtual void fromQColor(const QColor& color, quint8 *dst) const = 0;
 
     /**
      * The toQColor methods take a byte array that is at least pixelSize() long
@@ -293,9 +298,18 @@ public:
      *
      * @param src a pointer to the source pixel
      * @param c the QColor that will be filled with the color at src
-     * @param profile the optional profile that describes the color in c, for instance the monitor profile
      */
-    virtual void toQColor(const quint8 *src, QColor *c, const KoColorProfile * profile = 0) const = 0;
+    virtual void toQColor(const quint8 *src, QColor *c) const = 0;
+
+    /**
+     * The toQColor16 methods take a byte array that is at least pixelSize() long
+     * and converts the contents to a 16 bit QColor, using the given profile as a source
+     * profile and the optional profile as a destination profile.
+     *
+     * @param src a pointer to the source pixel
+     * @param c the QColor that will be filled with the color at src
+     */
+    virtual void toQColor16(const quint8 *src, QColor *c) const = 0;
 
     /**
      * Convert the pixels in data to (8-bit BGRA) QImage using the specified profiles.
@@ -357,6 +371,13 @@ public:
                                                                   KoColorConversionTransformation::Intent renderingIntent,
                                                                   KoColorConversionTransformation::ConversionFlags conversionFlags) const;
 
+    /**
+     * Retrieve the elevate-to-normalized floating point dithering op.
+     */
+    virtual const KisDitherOp *ditherOp(const QString &depth, DitherType type) const;
+
+    virtual void addDitherOp(KisDitherOp *op);
+
     /**
      * Convert a byte array of srcLen pixels *src to the specified color space
      * and put the converted bytes into the prepared byte array *dst.
@@ -392,6 +413,34 @@ public:
                                quint32 numPixels,
                                KoColorConversionTransformation *proofingTransform) const;
 
+    /**
+     * Convert @p nPixels pixels in @p src into their human-visible
+     * visual representation. The channel is shown as grayscale.
+     *
+     * Both buffers are in the same color space.
+     *
+     * @param src source buffer in (*this) color space
+     * @param dst destination buffer in the same color space as @p src
+     * @param nPixels length of the buffers in number of pixels
+     * @param pixelSize stride of each pixel in the destination buffer
+     * @param selectedChannelIndex Index of the selected channel.
+     */
+    virtual void convertChannelToVisualRepresentation(const quint8 *src, quint8 *dst, quint32 nPixels, const qint32 selectedChannelIndex) const = 0;
+
+    /**
+     * Convert @p nPixels pixels in @p src into their human-visible
+     * visual representation. The channels are shown as if other channels were null (or, if Lab, L = 1.0, *a = *b = 0.0).
+     *
+     * Both buffers are in the same color space.
+     *
+     * @param src source buffer in (*this) color space
+     * @param dst destination buffer in the same color space as @p src
+     * @param nPixels length of the buffers in number of pixels
+     * @param pixelSize stride of each pixel in the destination buffer
+     * @param selectedChannels Bitmap of selected channels
+     */
+    virtual void convertChannelToVisualRepresentation(const quint8 *src, quint8 *dst, quint32 nPixels, const QBitArray selectedChannels) const = 0;
+
 //============================== Manipulation functions ==========================//
 
 
@@ -417,6 +466,17 @@ public:
     virtual void setOpacity(quint8 * pixels, quint8 alpha, qint32 nPixels) const = 0;
     virtual void setOpacity(quint8 * pixels, qreal alpha, qint32 nPixels) const = 0;
 
+
+    /**
+    * Copy the opacity of a run of pixels.
+    *
+    * src -- pixels to get opacity from.  This is in the source colorspace.
+    * dst -- pixels in Alpha8 colorspace to be assigned the opacity of src pixel
+    * nPixels -- the number of pixels
+    *
+    */
+    virtual void copyOpacityU8(quint8* src, quint8* dst, qint32 nPixels) const = 0;
+
     /**
      * Multiply the alpha channel of the given run of pixels by the given value.
      *
@@ -453,6 +513,44 @@ public:
      */
     virtual void applyInverseNormedFloatMask(quint8 * pixels, const float * alpha, qint32 nPixels) const = 0;
 
+    /**
+     * Fills \p pixels with specified \p brushColor and then applies inverted brush
+     * mask specified in \p alpha.
+     */
+    virtual void fillInverseAlphaNormedFloatMaskWithColor(quint8 * pixels, const float * alpha, const quint8 *brushColor, qint32 nPixels) const = 0;
+
+    /**
+     * Fills \p dst with specified \p brushColor and then applies inverted brush
+     * mask specified in \p brush. Premultiplied red channel of the brush is
+     * used as an alpha channel for destination pixels.
+     *
+     * The equation is:
+     *
+     *     dstC = colorC;
+     *     dstA = qAlpha(brush) * (255 - qRed(brush)) / 255;
+     */
+    virtual void fillGrayBrushWithColor(quint8 *dst, const QRgb *brush, quint8 *brushColor, qint32 nPixels) const = 0;
+
+    /**
+     * Fills \p dst with specified \p brushColor and then applies inverted brush
+     * mask specified in \p brush. Inverted red channel of the brush is used
+     * as lightness of the destination. Alpha channel of the brush is used as
+     * alpha of the destination.
+     *
+     * The equation is:
+     *
+     *     dstL_hsl = preserveLightness(colorL_hsl, lightFactor);
+     *     dstA = qAlpha(brush);
+     *
+     * For details on preserveLightness() formula,
+     * see KoColorSpacePreserveLightnessUtils.h
+     */
+    virtual void fillGrayBrushWithColorAndLightnessOverlay(quint8 *dst, const QRgb *brush, quint8 *brushColor, qint32 nPixels) const;
+    // Same as above, but with contrast adjusted by strength.  Strength == 1 -> full contrast.  Allows softer lightness adjustments.
+    virtual void fillGrayBrushWithColorAndLightnessWithStrength(quint8* dst, const QRgb* brush, quint8* brushColor, qreal strength, qint32 nPixels) const;
+    // Same as above, but applies lightness adjustment to \p dst in-place
+    virtual void modulateLightnessByGrayBrush(quint8* dst, const QRgb *brush, qreal strength, qint32 nPixels) const;
+
     /**
      * Create an adjustment object for adjusting the brightness and contrast
      * transferValues is a 256 bins array with values from 0 to 0xFFFF
@@ -489,6 +587,9 @@ public:
      * Get the difference between 2 colors, normalized in the range (0,255). Only completely
      * opaque and completely transparent are taken into account when computing the difference;
      * other transparency levels are not regarded when finding the difference.
+     *
+     * Completely transparent pixels are treated as if they are completely
+     * different from any non-transparent pixels.
      */
     virtual quint8 difference(const quint8* src1, const quint8* src2) const = 0;
 
@@ -496,6 +597,10 @@ public:
      * Get the difference between 2 colors, normalized in the range (0,255). This function
      * takes the Alpha channel of the pixel into account. Alpha channel has the same
      * weight as Lightness channel.
+     *
+     * Completely transparent pixels are treated as if their color channels are
+     * the same as ones of the other pixel. In other words, only alpha channel
+     * difference is compared.
      */
     virtual quint8 differenceA(const quint8* src1, const quint8* src2) const = 0;
 
@@ -514,6 +619,11 @@ public:
      */
     virtual quint8 intensity8(const quint8 * src) const = 0;
 
+    /**
+     * Calculate the intensity of the given pixel, scaled down to the range 0-1
+     */
+    virtual qreal intensityF(const quint8 * src) const = 0;
+
     /*
      *increase luminosity by step
      */
@@ -540,7 +650,13 @@ public:
      * @param srcSpace the colorspace of the source pixels that will be composited onto "us"
      * @param params the information needed for blitting e.g. the source and destination pixel data,
      *        the opacity and flow, ...
-     * @param op the composition operator to use, e.g. COPY_OVER
+     * @param op the composition operator instance to use, e.g. COPY_OVER.
+     *        This operator must belong to this (dst) color space, UNLESS preferCompositionInSourceColorSpace()
+     *        returns true. In this case, the operator should be from the source color space. Besides avoiding
+     *        recurring lookups via ::compositeOp(), this is necessary if this color space does not implement
+     *        the desired composite op, but srcPace does.
+     *        Use ::compositeOp() with valid srcSpace to get the appropriate op.
+     *
      * @param renderingIntent the rendering intent
      * @param conversionFlags the conversion flags.
      *
@@ -551,7 +667,7 @@ public:
 
     /**
      * Serialize this color following Create's swatch color specification available
-     * at http://create.freedesktop.org/wiki/index.php/Swatches_-_colour_file_format
+     * at https://web.archive.org/web/20110826002520/http://create.freedesktop.org/wiki/Swatches_-_color_file_format/Draft
      *
      * This function doesn't create the \<color /\> element but rather the \<CMYK /\>,
      * \<sRGB /\>, \<RGB /\> ... elements. It is assumed that colorElt is the \<color /\>
@@ -566,7 +682,7 @@ public:
 
     /**
      * Unserialize a color following Create's swatch color specification available
-     * at http://create.freedesktop.org/wiki/index.php/Swatches_-_colour_file_format
+     * at https://web.archive.org/web/20110826002520/http://create.freedesktop.org/wiki/Swatches_-_color_file_format/Draft
      *
      * @param pixel buffer where the color will be unserialized
      * @param elt the element to unserialize (\<CMYK /\>, \<sRGB /\>, \<RGB /\>)
@@ -589,12 +705,6 @@ protected:
     const KoColorConversionTransformation* toRgbA16Converter() const;
     const KoColorConversionTransformation* fromRgbA16Converter() const;
 
-    /**
-     * Returns the thread-local conversion cache. If it doesn't exist
-     * yet, it is created. If it is currently too small, it is resized.
-     */
-    QVector<quint8> * threadLocalConversionCache(quint32 size) const;
-
     /**
      * This function defines the behavior of the bitBlt function
      * when the composition of pixels in different colorspaces is
