@@ -1,21 +1,8 @@
 /*
- *  Copyright (c) 2003 Patrick Julien  <freak@codepimps.org>
- *  Copyright (c) 2004,2010 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2003 Patrick Julien <freak@codepimps.org>
+ *  SPDX-FileCopyrightText: 2004, 2010 Cyrille Berger <cberger@cberger.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KOCOLORSPACEREGISTRY_H
@@ -30,6 +17,7 @@
 #include <KoColorSpace.h>
 #include <KoColorSpaceFactory.h>
 #include <KoConfig.h>
+#include <KoColorProfileConstants.h>
 
 class KoColorProfile;
 class KoColorConversionSystem;
@@ -245,6 +233,39 @@ public:
 #endif
     const KoColorSpace *alpha32f();
 
+    /**
+     * Convenience method to get a GRAYA 8 bit colorspace. If a profile is not specified,
+     * the default profile defined in the GRAY colorspace will be used
+     * @param profile the profile name
+     * @return an 8 bit graya colorspace with the default profile or 0.
+     */
+    const KoColorSpace *graya8(const QString &profile = QString());
+
+    /**
+     * Convenience method to get a GRAYA 8 bit colorspace. If a profile is not specified,
+     * the default profile defined in the GRAY colorspace will be used
+     * @param profile the profile
+     * @return an 8 bit graya colorspace with the default profile or 0.
+     */
+    const KoColorSpace *graya8(const KoColorProfile *profile);
+
+    /**
+     * Convenience method to get a GRAYA 16 bit colorspace. If a profile is not specified,
+     * the default profile defined in the GRAY colorspace will be used
+     * @param the profile
+     * @return an 8 bit graya colorspace with the default profile or 0.
+     */
+    const KoColorSpace *graya16(const QString &profile = QString());
+
+    /**
+     * Convenience method to get a GRAYA 16 bit colorspace. If a profile is not specified,
+     * the default profile defined in the GRAY colorspace will be used
+     * @param the profile
+     * @return an 8 bit graya colorspace with the default profile or 0.
+     */
+    const KoColorSpace *graya16(const KoColorProfile *profile);
+
+
     /**
      * Convenience method to get an RGBA 8bit colorspace. If a profile is not specified,
      * an sRGB profile will be used.
@@ -313,6 +334,18 @@ public:
      */
     const KoColorProfile *p709SRGBProfile() const;
 
+    /**
+     * @brief profileFor tries to find the profile that matches these characteristics, if no
+     * such profile is found, it attempts to generate one.
+     * @param colorants a double of xy (for xyY) values, this expects the first two as the white point,
+     * then the red, green and blue. If there's only a whitepoint and primaries type is undefined,
+     * a grayscale profile will be returned.
+     * @param colorPrimaries the color primaries type as defined in KoColorProfile.
+     * @param transferFunction the transfer function, as defined in KoColorProfile.
+     * @return a profile that matches these characteristics.
+     */
+    const KoColorProfile *profileFor(const QVector<double> &colorants, ColorPrimaries colorPrimaries, TransferCharacteristics transferFunction) const;
+
     /**
      * @return the list of available color models
      */
