@@ -1,20 +1,7 @@
 /*
- *  Copyright (c) 2005 Adrian Page <adrian@pagenet.plus.com>
+ *  SPDX-FileCopyrightText: 2005 Adrian Page <adrian@pagenet.plus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "KoCompositeOpRegistry.h"
@@ -29,9 +16,14 @@
 #include "KoColorSpace.h"
 
 #include "kis_assert.h"
+#include "DebugPigment.h"
 
 Q_GLOBAL_STATIC(KoCompositeOpRegistry, registry)
 
+static KoID koidCompositeOverStatic() {
+    static const KoID compositeOver(COMPOSITE_OVER, i18nc("Blending mode - Normal", "Normal"));
+    return compositeOver;
+}
 
 KoCompositeOpRegistry::KoCompositeOpRegistry()
 {
@@ -99,7 +91,7 @@ KoCompositeOpRegistry::KoCompositeOpRegistry()
     m_map.insert(m_categories[3], KoID(COMPOSITE_FOG_LIGHTEN_IFS_ILLUSIONS,  i18nc("Blending mode - Fog Lighten (IFS Illusions)", "Fog Lighten (IFS Illusions)")));
     m_map.insert(m_categories[3], KoID(COMPOSITE_EASY_DODGE       ,  i18nc("Blending mode - Easy Dodge", "Easy Dodge")));
     m_map.insert(m_categories[3], KoID(COMPOSITE_LUMINOSITY_SAI       ,  i18nc("Blending mode - Luminosity/Shine (SAI)", "Luminosity/Shine (SAI)")));
-    
+
     m_map.insert(m_categories[4], KoID(COMPOSITE_MOD              ,  i18nc("Blending mode - Modulo", "Modulo")));
     m_map.insert(m_categories[4], KoID(COMPOSITE_MOD_CON          ,  i18nc("Blending mode - Modulo - Continuous", "Modulo - Continuous")));
     m_map.insert(m_categories[4], KoID(COMPOSITE_DIVISIVE_MOD     ,  i18nc("Blending mode - Divisive Modulo", "Divisive Modulo")));
@@ -114,14 +106,17 @@ KoCompositeOpRegistry::KoCompositeOpRegistry()
     m_map.insert(m_categories[5], KoID(COMPOSITE_ARC_TANGENT          ,  i18nc("Blending mode - Arcus Tangent", "Arcus Tangent")));
     m_map.insert(m_categories[5], KoID(COMPOSITE_NEGATION             ,  i18nc("Blending mode - Negation", "Negation")));
 
-    m_map.insert(m_categories[6], KoID(COMPOSITE_OVER            ,  i18nc("Blending mode - Normal", "Normal")));
+    m_map.insert(m_categories[6], koidCompositeOverStatic());
     m_map.insert(m_categories[6], KoID(COMPOSITE_BEHIND          ,  i18nc("Blending mode - Behind", "Behind")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_GREATER         ,  i18nc("Blending mode - Greater", "Greater")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_OVERLAY         ,  i18nc("Blending mode - Overlay", "Overlay")));
+    m_map.insert(m_categories[6], KoID(COMPOSITE_LAMBERT_LIGHTING, i18nc("Blending mode - Lambert Lighting (Linear)", "Lambert Lighting (Linear)")));
+    m_map.insert(m_categories[6], KoID(COMPOSITE_LAMBERT_LIGHTING_GAMMA_2_2, i18nc("Blending mode - Lambert Lighting (Gamma 2.2)", "Lambert Lighting (Gamma 2.2)")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_ERASE           ,  i18nc("Blending mode - Erase", "Erase")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_ALPHA_DARKEN    ,  i18nc("Blending mode - Alpha Darken", "Alpha Darken")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_HARD_MIX        ,  i18nc("Blending mode - Hard Mix", "Hard Mix")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_HARD_MIX_PHOTOSHOP,  i18nc("Blending mode - Hard Mix (Photoshop)", "Hard Mix (Photoshop)")));
+    m_map.insert(m_categories[6], KoID(COMPOSITE_HARD_MIX_SOFTER_PHOTOSHOP,  i18nc("Blending mode - Hard Mix Softer (Photoshop)", "Hard Mix Softer (Photoshop)")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_GRAIN_MERGE     ,  i18nc("Blending mode - Grain Merge", "Grain Merge")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_GRAIN_EXTRACT   ,  i18nc("Blending mode - Grain Extract", "Grain Extract")));
     m_map.insert(m_categories[6], KoID(COMPOSITE_PARALLEL        ,  i18nc("Blending mode - Parallel", "Parallel")));
@@ -200,7 +195,7 @@ const KoCompositeOpRegistry& KoCompositeOpRegistry::instance()
 
 KoID KoCompositeOpRegistry::getDefaultCompositeOp() const
 {
-    return KoID(COMPOSITE_OVER, i18n("Normal"));
+    return koidCompositeOverStatic();
 }
 
 KoID KoCompositeOpRegistry::getKoID(const QString& compositeOpID) const
@@ -209,6 +204,24 @@ KoID KoCompositeOpRegistry::getKoID(const QString& compositeOpID) const
     return (itr != m_map.end()) ? *itr : KoID();
 }
 
+QString KoCompositeOpRegistry::getCompositeOpDisplayName(const QString& compositeOpID) const
+{
+    // In and Out are created in lcms2engine but not registered in KoCompositeOpRegistry.
+    // FIXME: Change these to use i18nc with context?
+    if (compositeOpID == COMPOSITE_IN) {
+        return i18n("In");
+    } else if (compositeOpID == COMPOSITE_OUT) {
+        return i18n("Out");
+    }
+
+    const QString name = getKoID(compositeOpID).name();
+    if (name.isNull()) {
+        warnPigment << "Got null display name for composite op" << compositeOpID;
+        return compositeOpID;
+    }
+    return name;
+}
+
 KoCompositeOpRegistry::KoIDMap KoCompositeOpRegistry::getCompositeOps() const
 {
     return m_map;
@@ -265,6 +278,17 @@ KoCompositeOpRegistry::KoIDList KoCompositeOpRegistry::getCategories() const
     return m_categories;
 }
 
+QString  KoCompositeOpRegistry::getCategoryDisplayName(const QString& categoryID) const
+{
+    KoIDList::const_iterator itr = std::find(m_categories.begin(), m_categories.end(), KoID(categoryID));
+    const QString name = (itr != m_categories.end()) ? itr->name() : QString();
+    if (name.isNull()) {
+        warnPigment << "Got null display name for composite op category" << categoryID;
+        return categoryID;
+    }
+    return name;
+}
+
 KoCompositeOpRegistry::KoIDList KoCompositeOpRegistry::getCompositeOps(const KoID& category, const KoColorSpace* colorSpace) const
 {
     qint32                  num = m_map.count(category);
