@@ -1,21 +1,8 @@
 /*
- *  Copyright (c) 2006-2007 Cyrille Berger <cberger@cberger.net>
- *  Copyright (c) 2016,2017,2020 L. E. Segovia <amy@amyspark.me>
+ *  SPDX-FileCopyrightText: 2006-2007 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2016, 2017, 2020 L. E. Segovia <amy@amyspark.me>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef _KO_LAB_COLORSPACE_TRAITS_H_
@@ -23,11 +10,11 @@
 
 #include <KoLabColorSpaceMaths.h>
 
-/** 
+/**
  * LAB traits, it provides some convenient functions to
  * access LAB channels through an explicit API.
  *
- * Use this class in conjonction with KoColorSpace::toLabA16 and
+ * Use this class in conjunction with KoColorSpace::toLabA16 and
  * KoColorSpace::fromLabA16 data.
  *
  * Example:
@@ -108,10 +95,11 @@ struct KoLabTraits : public KoColorSpaceTrait<_channels_type_, 4, 3> {
             return QString("Error");
         }
     }
-    inline static void normalisedChannelsValue(const quint8 *pixel, QVector<float> &channels)
+    inline static void normalisedChannelsValue(const quint8 *pixel, QVector<float> &v)
     {
-        Q_ASSERT((int)channels.count() >= (int)parent::channels_nb);
+        Q_ASSERT((int)v.count() >= (int)parent::channels_nb);
         channels_type c;
+        float *channels = v.data();
         for (uint i = 0; i < parent::channels_nb; i++) {
             c = parent::nativeArray(pixel)[i];
             switch (i) {
