@@ -31,9 +31,9 @@ public:
 
     virtual KoColorSpace* clone() const;
 
-    void fromQColor(const QColor& color, quint8 *dst, const KoColorProfile * profile = 0) const override;
+    void fromQColor(const QColor& color, quint8 *dst) const override;
 
-    void toQColor(const quint8 *src, QColor *c, const KoColorProfile * profile = 0) const override;
+    void toQColor(const quint8 *src, QColor *c) const override;
     
     void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const override;
     QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const override;
