@@ -1,10 +1,9 @@
 /*  This file is part of the KDE project
-    SPDX-FileCopyrightText: 2005 Boudewijn Rempt <boud@valdyas.org>
-    SPDX-FileCopyrightText: 2016 L. E. Segovia <amy@amyspark.me>
-    SPDX-FileCopyrightText: 2018 Michael Zhou <simerixh@gmail.com>
-
-    SPDX-License-Identifier: LGPL-2.1-or-later
-
+ *
+ *  SPDX-FileCopyrightText: 2005..2022 Halla Rempt <halla@valdyas.org>
+ *  SPDX-FileCopyrightText: 2016 L. E. Segovia <amy@amyspark.me>
+ *  SPDX-FileCopyrightText: 2018 Michael Zhou <simerixh@gmail.com>
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef KISSWATCHGROUP_H
@@ -14,11 +13,14 @@
 
 #include "kritapigment_export.h"
 
+#include <QSharedPointer>
 #include <QVector>
 #include <QList>
 #include <QMap>
 #include <QScopedPointer>
 
+#include <KisPropagateConstWrapper.h>
+
 /**
  * @brief The KisSwatchGroup class stores a matrix of color swatches
  * swatches can accessed using (x, y) coordinates.
@@ -39,18 +41,17 @@ public /* struct */:
     };
 
 public:
-    KisSwatchGroup();
+
+    static int DEFAULT_COLUMN_COUNT;
+    static int DEFAULT_ROW_COUNT;
+
     ~KisSwatchGroup();
     KisSwatchGroup(const KisSwatchGroup &rhs);
-    KisSwatchGroup &operator =(const KisSwatchGroup &rhs);
+    KisSwatchGroup &operator=(const KisSwatchGroup &rhs);
 
-public /* methods */:
     void setName(const QString &name);
     QString name() const;
 
-    void setColumnCount(int columnCount);
-    int columnCount() const;
-
     void setRowCount(int newRowCount);
     int rowCount() const;
 
@@ -63,24 +64,17 @@ public /* methods */:
     QList<SwatchInfo> infoList() const;
 
     /**
-     * @brief checkEntry
+     * @brief checkSwatch
      * checks if position @p column and @p row has a valid entry
      * both @p column and @p row start from 0
      * @param column
      * @param row
      * @return true if there is a valid entry at position (column, row)
      */
-    bool checkEntry(int column, int row) const;
+    bool checkSwatchExists(int column, int row) const;
+
     /**
-     * @brief setEntry
-     * sets the entry at position (@p column, @p row) to be @p e
-     * @param e
-     * @param column
-     * @param row
-     */
-    void setEntry(const KisSwatch &e, int column, int row);
-    /**
-     * @brief getEntry
+     * @brief getSwatch
      * used to get the swatch entry at position (@p column, @p row)
      * there is an assertion to make sure that this position isn't empty,
      * so checkEntry(int, int) must be used before this method to ensure
@@ -89,15 +83,43 @@ public /* methods */:
      * @param row
      * @return the swatch entry at position (column, row)
      */
-    KisSwatch getEntry(int column, int row) const;
+    KisSwatch getSwatch(int column, int row) const;
+
+private:
+
+    friend class KoColorSet;
+    friend struct AddSwatchCommand;
+    friend struct RemoveGroupCommand;
+    friend struct RemoveSwatchCommand;
+    friend struct AddGroupCommand;
+    friend struct ClearCommand;
+    friend struct SetColumnCountCommand;
+    friend class TestKisSwatchGroup;
+    friend class TestKoColorSet;
+
+    // Hidden, you're supposed to go through KoColorSet or KisPaletteModel
+    KisSwatchGroup();
+
+    friend class KisPaletteEditor; // Ew, gross! Refactor this when you understand what the PaletteEditor does...
+
     /**
-     * @brief removeEntry
+     * @brief setSwatch
+     * sets the entry at position (@p column, @p row) to be @p e
+     * @param e
+     * @param column
+     * @param row
+     */
+    void setSwatch(const KisSwatch &e, int column, int row);
+
+    /**
+     * @brief removeSwatch
      * removes the entry at position (@p column, @p row)
      * @param column
      * @param row
      * @return true if these is an entry at (column, row)
      */
-    bool removeEntry(int column, int row);
+    bool removeSwatch(int column, int row);
+
     /**
      * @brief addEntry
      * adds the entry e to the right of the rightmost entry in the last row
@@ -107,13 +129,29 @@ public /* methods */:
      * when column is set to 0, resize number of columns to default
      * @param e
      */
-    void addEntry(const KisSwatch &e);
+    QPair<int, int> addSwatch(const KisSwatch &e);
 
     void clear();
 
-private /* member variables */:
+
+    void setColumnCount(int columnCount);
+    int columnCount() const;
+
+    /**
+     * The usage of propagate_const makes all 'const' methods of the
+     * class reentrant. Which is necessary for, e.g., palettize filter.
+     */
     struct Private;
-    QScopedPointer<Private> d;
+    std::experimental::propagate_const<std::unique_ptr<Private>> d;
 };
 
+inline QDebug operator<<(QDebug dbg, const KisSwatchGroup group)
+{
+    dbg.nospace() << "[Group] Name: " << group.name();
+    return dbg.space();
+}
+
+typedef QSharedPointer<KisSwatchGroup> KisSwatchGroupSP;
+
+
 #endif // KISSWATCHGROUP_H
