@@ -52,7 +52,7 @@ public:
     /**
      * Call this to start the application.
      *
-     * Parses command line arguments and creates the initial main windowss and docs
+     * Parses command line arguments and creates the initial main windows and docs
      * from them (or an empty doc if no cmd-line argument is specified ).
      *
      * You must call this method directly before calling QApplication::exec.
@@ -88,6 +88,8 @@ public:
     void initializeGlobals(const KisApplicationArguments &args);
     void processPostponedSynchronizationEvents();
 
+    /// @return true if Krita has been acquired through an app store
+    bool isStoreApplication();
 
 public Q_SLOTS:
 
