@@ -38,4 +38,4 @@ private:
 };
 
 
-#endif // KOAUTOSAVERECOVERYDIALOG_H
+#endif // KISAUTOSAVERECOVERYDIALOG_H
