@@ -134,7 +134,7 @@ void KisTemplatesPane::openFile(const QModelIndex& index)
         cfgGrp.writePathEntry("FullTemplateName", item->data(Qt::UserRole + 1).toString());
         cfgGrp.writeEntry("LastReturnType", "Template");
         cfgGrp.writeEntry("AlwaysUseTemplate", d->m_alwaysUseTemplate);
-        emit openUrl(QUrl::fromLocalFile(item->data(Qt::UserRole + 1).toString()));
+        Q_EMIT openUrl(QUrl::fromLocalFile(item->data(Qt::UserRole + 1).toString()));
     }
 }
 
@@ -156,7 +156,7 @@ void KisTemplatesPane::alwaysUseClicked()
     KConfigGroup cfgGrp( KSharedConfig::openConfig(), "TemplateChooserDialog");
     cfgGrp.writeEntry("AlwaysUseTemplate", d->m_alwaysUseTemplate);
     cfgGrp.sync();
-    emit alwaysUseChanged(this, d->m_alwaysUseTemplate);
+    Q_EMIT alwaysUseChanged(this, d->m_alwaysUseTemplate);
 }
 
 void KisTemplatesPane::changeAlwaysUseTemplate(KisTemplatesPane* sender, const QString& alwaysUse)
