@@ -18,10 +18,6 @@ namespace KisAnimationRender {
 
     KRITAUI_EXPORT void render(KisDocument *doc, KisViewManager* viewManager, KisAnimationRenderingOptions encoderOptions);
 
-    QString getNameForFrame(const QString &basename, const QString &extension, int sequenceStart, int frame);
-
-    QStringList getNamesForFrames(const QString &basename, const QString &extension, int sequenceStart, const QList<int> &frames);
-
     bool mustHaveEvenDimensions(const QString &mimeType, KisAnimationRenderingOptions::RenderMode renderMode);
     bool hasEvenDimensions(int width, int height);
 
