@@ -31,7 +31,7 @@
 #include "KisWraparoundAxis.h"
 
 class KoToolProxy;
-class KoColorProfile;
+class KisDisplayConfig;
 
 
 class KisViewManager;
@@ -48,6 +48,7 @@ class KoViewConverter;
 class KisAbstractCanvasWidget;
 class KisPopupPalette;
 
+
 /**
  * KisCanvas2 is not an actual widget class, but rather an adapter for
  * the widget it contains, which may be either a QPainter based
@@ -133,8 +134,6 @@ public: // KoCanvasBase implementation
 
     KoToolProxy* toolProxy() const override;
 
-    const KoColorProfile* monitorProfile();
-
     // FIXME:
     // Temporary! Either get the current layer and image from the
     // resource provider, or use this, which gets them from the
@@ -328,7 +327,7 @@ private:
     void updateCanvasWidgetImpl(const QRect &rc = QRect());
     void setCanvasWidget(KisAbstractCanvasWidget *widget);
     void resetCanvas(bool useOpenGL);
-    void setDisplayProfile(const KoColorProfile *profile);
+    void setDisplayConfig(const KisDisplayConfig &config);
 
     void notifyLevelOfDetailChange();
 
