@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2007, 2010 Adrian Page <adrian@pagenet.plus.com>
+ * SPDX-FileCopyrightText: 2007, 2010 Adrian Page <adrian@pagenet.plus.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_canvas_widget_base.h"
@@ -30,7 +18,7 @@
 #include <KoCanvasController.h>
 #include <KoShape.h>
 #include <KoSelection.h>
-#include <KoShapePaintingContext.h>
+
 
 #include "kis_coordinates_converter.h"
 #include "kis_canvas_decoration.h"
@@ -100,7 +88,7 @@ void KisCanvasWidgetBase::drawDecorations(QPainter & gc, const QRect &updateWidg
 
     // This option does not do anything anymore with Qt4.6, so don't re-enable it since it seems to break display
     // https://lists.qt-project.org/pipermail/qt-interest-old/2009-December/017078.html
-    // gc.setRenderHint(QPainter::HighQualityAntialiasing);
+    // gc.setRenderHint(QPainter::Antialiasing);
 
     gc.setRenderHint(QPainter::SmoothPixmapTransform);
 
@@ -109,34 +97,8 @@ void KisCanvasWidgetBase::drawDecorations(QPainter & gc, const QRect &updateWidg
         gc.setTransform(m_d->coordinatesConverter->documentToWidgetTransform());
 
         // Paint the shapes (other than the layers)
-        m_d->canvas->globalShapeManager()->paint(gc, false);
+        m_d->canvas->globalShapeManager()->paint(gc);
 
-        // draw green selection outlines around text shapes that are edited, so the user sees where they end
-        gc.setPen( Qt::green );
-        Q_FOREACH (KoShape *shape, canvas()->shapeManager()->selection()->selectedShapes()) {
-            if (shape->shapeId() == "ArtisticText" || shape->shapeId() == "TextShapeID") {
-                gc.save();
-                gc.setTransform(shape->absoluteTransformation(), true);
-                gc.drawRect(QRectF(QPointF(), shape->size()));
-                gc.restore();
-            }
-        }
-
-        // Draw text shape over canvas while editing it, that's needs to show the text selection correctly
-        QString toolId = KoToolManager::instance()->activeToolId();
-        if (toolId == "ArtisticTextTool" || toolId == "TextTool") {
-            gc.save();
-            gc.setTransform(m_d->coordinatesConverter->documentToWidgetTransform());
-            gc.setPen(Qt::NoPen);
-            gc.setBrush(Qt::NoBrush);
-            Q_FOREACH (KoShape *shape, canvas()->shapeManager()->selection()->selectedShapes()) {
-                if (shape->shapeId() == "ArtisticText" || shape->shapeId() == "TextShapeID") {
-                    KoShapePaintingContext  paintContext(canvas(), false);
-                    KoShapeManager::renderSingleShape(shape, gc, paintContext);
-                }
-            }
-            gc.restore();
-        }
     }
 
     // ask the decorations to paint themselves
@@ -194,12 +156,22 @@ QList<KisCanvasDecorationSP > KisCanvasWidgetBase::decorations() const
 {
     return m_d->decorations;
 }
-
+void KisCanvasWidgetBase::notifyDecorationsWindowMinimized(bool minimized)
+{
+    Q_FOREACH (KisCanvasDecorationSP deco, m_d->decorations) {
+        deco->notifyWindowMinimized(minimized);
+    }
+}
 void KisCanvasWidgetBase::setWrapAroundViewingMode(bool value)
 {
     Q_UNUSED(value);
 }
 
+void KisCanvasWidgetBase::setWrapAroundViewingModeAxis(WrapAroundAxis value)
+{
+    Q_UNUSED(value);
+}
+
 QImage KisCanvasWidgetBase::createCheckersImage(qint32 checkSize)
 {
     KisConfig cfg(true);
@@ -259,7 +231,7 @@ KoToolProxy *KisCanvasWidgetBase::toolProxy() const
 
 QVariant KisCanvasWidgetBase::processInputMethodQuery(Qt::InputMethodQuery query) const
 {
-    if (query == Qt::ImMicroFocus) {
+    if (query == Qt::ImCursorRectangle) {
         QRectF rect = m_d->toolProxy->inputMethodQuery(query, *m_d->viewConverter).toRectF();
         return m_d->coordinatesConverter->flakeToWidget(rect);
     }
