@@ -20,12 +20,12 @@ class QPainter;
 class KoColorProfile;
 class KisCoordinatesConverter;
 class KisDisplayFilter;
+class KisDisplayConfig;
 
 #include <kis_types.h>
 #include "kis_ui_types.h"
 
 
-
 /**
  * KisPrescaledProjection is responsible for keeping around a
  * prescaled QImage representation that is always suitable for
@@ -98,7 +98,7 @@ public Q_SLOTS:
     /**
      * Set the current monitor profile
      */
-    void setMonitorProfile(const KoColorProfile *monitorProfile, KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::ConversionFlags conversionFlags);
+    void setDisplayConfig(const KisDisplayConfig &config);
 
     void setChannelFlags(const QBitArray &channelFlags);
 
