@@ -22,6 +22,7 @@
 #include "kis_tool_proxy.h"
 
 #include <kis_config.h>
+#include <kis_config_notifier.h>
 #include <kis_canvas2.h>
 #include <KisViewManager.h>
 #include <kis_image.h>
@@ -63,6 +64,9 @@ KisInputManager::KisInputManager(QObject *parent)
 {
     d->setupActions();
 
+    connect(KisConfigNotifier::instance(), SIGNAL(configChanged()), SLOT(slotConfigChanged()));
+    slotConfigChanged();
+
     connect(KoToolManager::instance(), SIGNAL(aboutToChangeTool(KoCanvasController*)), SLOT(slotAboutToChangeTool()));
     connect(KoToolManager::instance(), SIGNAL(changedTool(KoCanvasController*)), SLOT(slotToolChanged()));
     connect(&d->moveEventCompressor, SIGNAL(timeout()), SLOT(slotCompressedMoveEvent()));
@@ -120,6 +124,15 @@ void KisInputManager::deregisterPopupWidget()
     d->popupWidget = nullptr;
 }
 
+void KisInputManager::slotConfigChanged()
+{
+#ifdef Q_OS_WIN
+    d->ignoreHighFunctionKeys = KisConfig(true).ignoreHighFunctionKeys();
+    d->fixShortcutMatcherModifiersState();
+#endif
+}
+
+
 void KisInputManager::toggleTabletLogger()
 {
     KisTabletDebugger::instance()->toggleDebugging();
@@ -781,6 +794,14 @@ bool KisInputManager::eventFilterImpl(QEvent * event)
             retval = d->matcher.buttonReleased(Qt::LeftButton, touchEvent);
             d->previousPos = {0, 0};
             d->touchStrokeStarted = false; // stroke ended
+        } else if (!KisConfig(true).disableTouchOnCanvas() && !d->touchHasBlockedPressEvents
+                   && touchEvent->touchPoints().count() == 1) {
+            // If no stroke has been started while touch painting is enabled,
+            // the user tapped with one finger, but didn't make any motion that
+            // caused us to start a stroke. We produce a press and release in
+            // response so that the tool responds to their input.
+            d->matcher.buttonPressed(Qt::LeftButton, d->originatingTouchBeginEvent.data());
+            d->matcher.buttonReleased(Qt::LeftButton, touchEvent);
         }
 
         endTouch();
