@@ -1,38 +1,9 @@
 /*
- * Copyright (c) 2017 Alvin Wong <alvinhochun@gmail.com>
+ * SPDX-FileCopyrightText: 2017 Alvin Wong <alvinhochun@gmail.com>
  *
- * Redistribution and use in source and binary forms, with or without
- - modification, are permitted provided that the following conditions
- - are met:
- -
- - 1. Redistributions of source code must retain the above copyright
- -    notice, this list of conditions and the following disclaimer.
- - 2. Redistributions in binary form must reproduce the above copyright
- -    notice, this list of conditions and the following disclaimer in the
- -    documentation and/or other materials provided with the distribution.
- -
- - THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- - IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- - OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- - IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- - INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- - NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- - DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- - THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- - (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- - THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 
-// Get Windows 8 API prototypes and types
-#ifdef WINVER
-#  undef WINVER
-#endif
-#ifdef _WIN32_WINNT
-#  undef _WIN32_WINNT
-#endif
-#define WINVER 0x0602
-#define _WIN32_WINNT 0x0602
-
 #include "kis_tablet_support_win8.h"
 
 #include <QApplication>
@@ -299,7 +270,7 @@ struct PenPointerItem
     HANDLE deviceHandle;
     QPointer<QWidget> activeWidget; // Current widget receiving events
     qreal oneOverDpr; // 1 / devicePixelRatio of activeWidget
-    bool widgetIsCaptured; // Current widget is capturing a pen cown event
+    bool widgetIsCaptured; // Current widget is capturing a pen down event
     bool widgetIsIgnored; // Pen events should be ignored until pen up
     bool widgetAcceptsPenEvent; // Whether the widget accepts pen events
 
@@ -442,7 +413,7 @@ bool KisTabletSupportWin8::nativeEventFilter(const QByteArray &eventType, void *
         return true;
     }
 
-    Q_UNUSED(eventType)
+    Q_UNUSED(eventType);
     return false;
 }
 
