@@ -65,11 +65,16 @@ void KisAsyncActionFeedback::runVoidAction(std::function<void()> func)
     watcher.waitForFinished();
 }
 
-void KisAsyncActionFeedback::waitForMutex(QMutex *mutex)
+void KisAsyncActionFeedback::waitForMutexLikeImpl(std::unique_ptr<MutexLikeBase> &&mutex)
 {
-    while (!mutex->tryLock()) {
+    while (!mutex->try_lock()) {
         qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
     }
 
     mutex->unlock();
 }
+
+QString KisAsyncActionFeedback::DefaultWaitingMessageCallback::operator()() const
+{
+    return i18nc("progress dialog message when the user has to wait for the image to become unlocked", "Waiting for the action to complete...");
+}
