@@ -85,8 +85,7 @@ public:
                                       KisTimeSpan *clipRange = nullptr,
                                       bool useClipboardFallback = false) const;
 
-    KisPaintDeviceSP clipFromKritaLayers(const QRect &imageBounds,
-                                         const KoColorSpace *cs) const;
+    KisPaintDeviceSP clipFromKritaLayers(const KoColorSpace *cs) const;
 
     KisPaintDeviceSP clipFromBoardContents(const QMimeData *data,
                           const QRect &imageBounds,
