@@ -1,20 +1,8 @@
 /*
- *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
- *  Copyright (c) 2017 Scott Petrovic <scottpetrovic@gmail.com>
+ *  SPDX-FileCopyrightText: 2008 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2017 Scott Petrovic <scottpetrovic@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef _KIS_PAINTING_ASSISTANT_H_
@@ -97,7 +85,7 @@ private:
 
 /**
  * A KisPaintingAssistant is an object that assist the drawing on the canvas.
- * With this class you can implement virtual equivalent to ruler or compas.
+ * With this class you can implement virtual equivalent to ruler or compass.
  */
 class KRITAUI_EXPORT KisPaintingAssistant
 {
@@ -115,14 +103,52 @@ public:
      * Adjust the position given in parameter.
      * @param point the coordinates in point in the document reference
      * @param strokeBegin the coordinates of the beginning of the stroke
+     * @param snapToAny because now assistants can be composited out of multiple inside assistants.
+     *         snapToAny true means that you can use any of the inside assistant, while it being false
+     *         means you should use the last used one. The logic determining when it happens (first stroke etc.)
+     *         is in the decoration, so those two options are enough.
+     * @param moveThresholdPt the threshold for the "move" of the cursor measured in pt
+     *                        (usually equals to 2px in screen coordinates converted to pt)
      */
-    virtual QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin) = 0;
-    virtual void endStroke() {}
-    virtual void setAdjustedBrushPosition(const QPointF position) { Q_UNUSED(position) }
-    virtual void setFollowBrushPosition(bool follow) { Q_UNUSED(follow) }
-    virtual QPointF getEditorPosition() const = 0; // Returns editor widget position in document-space coordinates.
+    virtual QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, bool snapToAny, qreal moveThresholdPt) = 0;
+    virtual void adjustLine(QPointF& point, QPointF& strokeBegin) = 0;
+    virtual void endStroke();
+    virtual void setAdjustedBrushPosition(const QPointF position);
+    virtual void setFollowBrushPosition(bool follow);
+    virtual QPointF getDefaultEditorPosition() const = 0; // Returns standard editor widget position for this assistant
+    virtual QPointF getEditorPosition() const; // Returns editor widget position in document-space coordinates.
     virtual int numHandles() const = 0;
 
+    /**
+     * @brief canBeLocal
+     * @return if the assistant can be potentially a "local assistant" (limited to rectangular area) or not
+     */
+    virtual bool canBeLocal() const;
+    /**
+     * @brief isLocal
+     * @return if the assistant is limited to a rectangular area or not
+     */
+    bool isLocal() const;
+    /**
+     * @brief setLocal
+     * @param value set the indication if the assistant is limited to a rectangular area or not
+     */
+    void setLocal(bool value);
+
+    /**
+     * @brief isLocked
+     * @return if the assistant is locked (= cannot be moved, or edited in any way), or not
+     */
+    bool isLocked();
+    /**
+     * @brief setLocked
+     * @param value set the indication if the assistant is locked (= cannot be moved, or edited in any way) or not
+     */
+    void setLocked(bool value);
+
+    QPointF editorWidgetOffset();
+    void setEditorWidgetOffset(QPointF offset);
+
     void replaceHandle(KisPaintingAssistantHandleSP _handle, KisPaintingAssistantHandleSP _with);
     void addHandle(KisPaintingAssistantHandleSP handle, HandleType type);
 
@@ -135,7 +161,7 @@ public:
     QColor assistantCustomColor();
     void setAssistantGlobalColorCache(const QColor &color);
 
-    virtual void drawAssistant(QPainter& gc, const QRectF& updateRect, const KisCoordinatesConverter *converter, bool cached = true,KisCanvas2 *canvas=0, bool assistantVisible=true, bool previewVisible=true);
+    virtual void drawAssistant(QPainter& gc, const QRectF& updateRect, const KisCoordinatesConverter *converter, bool cached, KisCanvas2 *canvas=0, bool assistantVisible=true, bool previewVisible=true);
     void uncache();
     const QList<KisPaintingAssistantHandleSP>& handles() const;
     QList<KisPaintingAssistantHandleSP> handles();
@@ -148,7 +174,7 @@ public:
     void loadXml(KoStore *store, QMap<int, KisPaintingAssistantHandleSP> &handleMap, QString path);
     virtual bool loadCustomXml(QXmlStreamReader* xml);
 
-    void saveXmlList(QDomDocument& doc, QDomElement& ssistantsElement, int count);
+    void saveXmlList(QDomDocument& doc, QDomElement& assistantsElement, int count);
     void findPerspectiveAssistantHandleLocation();
     KisPaintingAssistantHandleSP oppHandleOne();
 
@@ -199,6 +225,10 @@ public:
      */
     void drawPath(QPainter& painter, const QPainterPath& path, bool drawActive=true);
     void drawPreview(QPainter& painter, const QPainterPath& path);
+    // draw a path in a red color, signalizing incorrect state
+    void drawError(QPainter& painter, const QPainterPath& path);
+    // draw a vanishing point marker
+    void drawX(QPainter& painter, const QPointF& pt);
     static double norm2(const QPointF& p);
 
 protected:
@@ -213,12 +243,53 @@ protected:
     QList<KisPaintingAssistantHandleSP> m_handles;
 
     QPointF pixelToView(const QPoint pixelCoords) const;
+    /**
+     * @brief Query the effective brush position to be used for preview lines.
+     * This is inteded to be used for painting the dynamic preview lines for assistants
+     * that feature them. Affected by setAdjustedBrushPosition() and setFollowBrushPosition().
+     * @return the effective brush (cursor) position in widget coordinates
+     */
+    QPointF effectiveBrushPosition(const KisCoordinatesConverter *converter, KisCanvas2 *canvas) const;
+
+    /**
+     * @brief firstLocalHandle
+     * Note: this doesn't guarantee it will be the topleft corner!
+     * For that, use getLocalRect().topLeft()
+     * The only purpose of those functions to exist is to be able to
+     * put getLocalRect() function in the KisPaintingAssistant
+     * instead of reimplementing it in every specific assistant.
+     * @return the first handle of the rectangle of the limited area
+     */
+    virtual KisPaintingAssistantHandleSP firstLocalHandle() const;
+    /**
+     * @brief secondLocalHandle
+     * Note: this doesn't guarantee it will be the bottomRight corner!
+     * For that, use getLocalRect().bottomRight()
+     * (and remember that for QRect bottomRight() works differently than for QRectF,
+     * so don't convert to QRect before accessing the corner)
+     * @return
+     */
+    virtual KisPaintingAssistantHandleSP secondLocalHandle() const;
+    /**
+     * @brief getLocalRect
+     * The function deals with local handles not being topLeft and bottomRight
+     * gracefully and returns a correct rectangle.
+     * Thanks to that the user can place handles in a "wrong" order or move them around
+     * but the local rectangle will still be correct.
+     * @return the rectangle of the area that the assistant is limited to
+     */
+    QRectF getLocalRect() const;
+
+
 public:
     /// clones the list of assistants
     /// the originally shared handles will still be shared
     /// the cloned assistants do not share any handle with the original assistants
     static QList<KisPaintingAssistantSP> cloneAssistantList(const QList<KisPaintingAssistantSP> &list);
 
+protected:
+    bool m_hasBeenInsideLocalRect {false};
+
 private:
     struct Private;
     Private* const d;
