@@ -36,6 +36,7 @@
 #include "KisView.h"
 #include "kis_selection_mask.h"
 #include <KisPart.h>
+#include <KisScreenMigrationTracker.h>
 
 static const unsigned int ANT_LENGTH = 4;
 static const unsigned int ANT_SPACE = 4;
@@ -45,19 +46,12 @@ KisSelectionDecoration::KisSelectionDecoration(QPointer<KisView>_view)
     : KisCanvasDecoration("selection", _view),
       m_signalCompressor(50 /*ms*/, KisSignalCompressor::FIRST_ACTIVE),
       m_offset(0),
-      m_mode(Ants)
+      m_mode(Ants),
+      m_migrationTracker(new KisScreenMigrationTracker(_view->mainWindow(), this))
 {
-    Q_ASSERT(view());
-    Q_ASSERT(view()->mainWindow());
-    Q_ASSERT(view()->mainWindow()->windowHandle());
-
-    m_window = view()->mainWindow()->windowHandle();
-    connect(m_window, SIGNAL(screenChanged(QScreen*)), this, SLOT(screenChanged(QScreen*)));
-
-    m_screen = m_window->screen();
-    connect(m_screen, SIGNAL(physicalDotsPerInchChanged(qreal)), this, SLOT(initializePens()));
-
-    initializePens();
+    connect(m_migrationTracker, &KisScreenMigrationTracker::sigScreenOrResolutionChanged,
+            this, &KisSelectionDecoration::initializePens);
+    initializePens(m_migrationTracker->currentScreen());
 
     connect(KisConfigNotifier::instance(), SIGNAL(configChanged()), SLOT(slotConfigChanged()));
     connect(KisImageConfigNotifier::instance(), SIGNAL(configChanged()), SLOT(slotConfigChanged()));
@@ -97,35 +91,16 @@ bool KisSelectionDecoration::selectionIsActive()
             selection->isVisible();
 }
 
-void KisSelectionDecoration::initializePens()
+void KisSelectionDecoration::initializePens(QScreen *screen)
 {
-    /**
-     * On MacOS in HiDPI mode devicePixelRatio is always fixed to 2.0,
-     * so we should use physical DPI for better guess of the screen
-     * detail level (which is divided by the pixel ratio in Qt).
-     */
-    const qreal dotsPerInch = m_screen->physicalDotsPerInch() * m_screen->devicePixelRatio();
-    int screenScale = 1;
-
-    if (dotsPerInch < 220) {
-        screenScale = 1;
-    }
-    else if (dotsPerInch < 300) {
-        screenScale = 2;
-    }
-    else if (dotsPerInch < 500) {
-        screenScale = 3;
-    }
-    else {
-        screenScale = 4;
-    }
-
     KisPaintingTweaks::initAntsPen(&m_antsPen, &m_outlinePen,
                                    ANT_LENGTH, ANT_SPACE);
 
-    if (screenScale > 1) {
-        m_antsPen.setWidth(screenScale);
-        m_outlinePen.setWidth(screenScale);
+    int penWidth = qRound(screen->devicePixelRatio());
+
+    if (penWidth > 1) {
+        m_antsPen.setWidth(penWidth);
+        m_outlinePen.setWidth(penWidth);
     }
     else {
         m_antsPen.setCosmetic(true);
@@ -160,6 +135,7 @@ void KisSelectionDecoration::selectionChanged()
             } else {
                 m_thumbnailImage = selection->thumbnailImage();
                 m_thumbnailImageTransform = selection->thumbnailImageTransform();
+                m_antsTimer->stop();
             }
             if (view() && view()->canvasBase()) {
                 view()->canvasBase()->updateCanvas();
@@ -191,16 +167,11 @@ void KisSelectionDecoration::slotConfigChanged()
     KisImageConfig imageConfig(true);
     KisConfig cfg(true);
 
+    m_opacity = imageConfig.selectionOutlineOpacity();
     m_maskColor = imageConfig.selectionOverlayMaskColor();
     m_antialiasSelectionOutline = cfg.antialiasSelectionOutline();
 }
 
-void KisSelectionDecoration::screenChanged(QScreen *screen)
-{
-    m_screen = screen;
-    initializePens();
-}
-
 void KisSelectionDecoration::antsAttackEvent()
 {
     KisSelectionSP selection = view()->selection();
@@ -229,7 +200,7 @@ void KisSelectionDecoration::drawDecoration(QPainter& gc, const QRectF& updateRe
 
     if (m_mode == Mask) {
         gc.setRenderHints(QPainter::SmoothPixmapTransform |
-                          QPainter::HighQualityAntialiasing, false);
+                          QPainter::Antialiasing, false);
 
         gc.setTransform(m_thumbnailImageTransform, true);
         gc.drawImage(QPoint(), m_thumbnailImage);
@@ -248,7 +219,9 @@ void KisSelectionDecoration::drawDecoration(QPainter& gc, const QRectF& updateRe
         gc.drawPath(p1 - p2);
 
     } else /* if (m_mode == Ants) */ {
-        gc.setRenderHints(QPainter::Antialiasing | QPainter::HighQualityAntialiasing, m_antialiasSelectionOutline);
+        gc.setRenderHints(QPainter::Antialiasing | QPainter::Antialiasing, m_antialiasSelectionOutline);
+
+        gc.setOpacity(m_opacity);
 
         // render selection outline in white
         gc.setPen(m_outlinePen);
@@ -272,7 +245,6 @@ void KisSelectionDecoration::notifyWindowMinimized(bool minimized)
     if(minimized) {
         m_antsTimer->stop();
     } else {
-        m_antsTimer->start();
+        selectionChanged();
     }
 }
-
