@@ -357,8 +357,14 @@ void KisStatusBar::slotCanvasRotationChanged()
     KisCanvas2 *canvas = m_viewManager->canvasBase();
     if (!canvas) return;
 
-    KisSignalsBlocker l(m_canvasAngleSelector);
-    m_canvasAngleSelector->setAngle(canvas->rotationAngle());
+    const qreal angleDiff = qAbs(m_canvasAngleSelector->angle()) -
+                            qAbs(canvas->rotationAngle());
+
+    // Only update the UI if the angle difference is big enough. This improves the performance.
+    if (qAbs(angleDiff) >= 0.01) {
+        KisSignalsBlocker l(m_canvasAngleSelector);
+        m_canvasAngleSelector->setAngle(canvas->rotationAngle());
+    }
 }
 
 void KisStatusBar::updateSelectionToolTip()
