@@ -9,9 +9,10 @@
 
 #include <simpletest.h>
 
-#include <sdk/tests/testutil.h>
-#include <sdk/tests/testui.h>
 #include "ui_manager_test.h"
+#include <testui.h>
+#include <testutil.h>
+
 
 class SelectionManagerTester : public TestUtil::UiManagerTest
 {
