@@ -1,31 +1,19 @@
 /*
- *  Copyright (c) 2018 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2018 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_shape_layer_test.h"
 
-#include <QTest>
+#include <simpletest.h>
 
 #include "kis_global.h"
 
 #include "kis_shape_layer.h"
 #include <KoPathShape.h>
 #include <KoColorBackground.h>
-#include "testutil.h"
+#include <testutil.h>
 
 #include <KisPart.h>
 #include <KisDocument.h>
@@ -37,7 +25,9 @@
 
 #include "kis_layer_utils.h"
 
-#include <sdk/tests/testutil.h>
+#include <testui.h>
+#include <testutil.h>
+
 
 void testMergeDownImpl(bool useImageTransformations)
 {
