@@ -84,6 +84,8 @@ protected:
     bool isOutlineVisible() const;
     void setOutlineVisible(bool visible);
 
+    bool isEraser() const;
+
     /// Add the tool-specific layout to the default option widget layout.
     void addOptionWidgetLayout(QLayout *layout);
 
@@ -118,6 +120,11 @@ private Q_SLOTS:
     void decreaseBrushSize();
     void showBrushSize();
 
+    void rotateBrushTipClockwise();
+    void rotateBrushTipClockwisePrecise();
+    void rotateBrushTipCounterClockwise();
+    void rotateBrushTipCounterClockwisePrecise();
+
 protected:
     quint8 m_opacity {OPACITY_OPAQUE_U8};
     bool m_paintOutline {false};
