@@ -16,6 +16,7 @@
 
 #include "kis_tool_polyline_base.h"
 #include "kis_canvas2.h"
+#include <kis_canvas_resource_provider.h>
 #include <KisViewManager.h>
 #include <kis_action.h>
 #include <kactioncollection.h>
@@ -33,13 +34,16 @@ KisToolPolylineBase::KisToolPolylineBase(KoCanvasBase * canvas,  KisToolPolyline
       m_type(type),
       m_closeSnappingActivated(false)
 {
+    KisCanvas2 *kritaCanvas = dynamic_cast<KisCanvas2*>(canvas);
+
+    connect(kritaCanvas->viewManager()->canvasResourceProvider(), SIGNAL(sigEffectiveCompositeOpChanged()), SLOT(resetCursorStyle()));
 }
 
 
 void KisToolPolylineBase::activate(const QSet<KoShape *> &shapes)
 {
     KisToolShape::activate(shapes);
-    connect(action("undo_polygon_selection"), SIGNAL(triggered()), SLOT(undoSelection()), Qt::UniqueConnection);
+    connect(action("undo_polygon_selection"), SIGNAL(triggered()), SLOT(undoSelectionOrCancel()), Qt::UniqueConnection);
 
     KisInputManager *inputManager = (static_cast<KisCanvas2*>(canvas()))->globalInputManager();
     if (inputManager) {
@@ -88,13 +92,13 @@ bool KisToolPolylineBase::eventFilter(QObject *obj, QEvent *event)
         event->type() == QEvent::MouseButtonDblClick) {
         QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
         if (mouseEvent->button() == Qt::RightButton) {
-            undoSelection();
+            undoSelectionOrCancel();
             return true;
         }
     } else if (event->type() == QEvent::TabletPress) {
         QTabletEvent *tabletEvent = static_cast<QTabletEvent*>(event);
         if (tabletEvent->button() == Qt::RightButton) {
-            undoSelection();
+            undoSelectionOrCancel();
             return true;
         }
     }
@@ -193,20 +197,33 @@ void KisToolPolylineBase::mouseMoveEvent(KoPointerEvent *event)
 
 void KisToolPolylineBase::undoSelection()
 {
-    if(m_dragging) {
-        //Update canvas for drag before undo
+    if (m_dragging) {
+        // Initialize with the dragging segment's rect
         QRectF updateRect = dragBoundingRect();
-        updateCanvasViewRect(updateRect);
 
-        //Update canvas for last segment
-        QRectF rect;
         if (m_points.size() > 1) {
-            rect = pixelToView(QRectF(m_points.last(), m_points.at(m_points.size()-2)).normalized());
-            rect.adjust(-PREVIEW_LINE_WIDTH, -PREVIEW_LINE_WIDTH, PREVIEW_LINE_WIDTH, PREVIEW_LINE_WIDTH);
-            updateCanvasViewRect(rect);
+            // Add the rect for the last segment
+            const QRectF lastSegmentRect =
+                pixelToView(QRectF(m_points.last(), m_points.at(m_points.size() - 2)).normalized())
+                .adjusted(-PREVIEW_LINE_WIDTH, -PREVIEW_LINE_WIDTH, PREVIEW_LINE_WIDTH, PREVIEW_LINE_WIDTH);
+            updateRect = updateRect.united(lastSegmentRect);
+
             m_points.pop_back();
         }
         m_dragStart = m_points.last();
+
+        // Add the new dragging segment's rect
+        updateRect = updateRect.united(dragBoundingRect());
+        updateCanvasViewRect(updateRect);
+    }
+}
+
+void KisToolPolylineBase::undoSelectionOrCancel()
+{
+    if (m_points.size() > 1) {
+        undoSelection();
+    } else {
+        cancelStroke();
     }
 }
 
