@@ -1,29 +1,18 @@
 /*
- * Copyright (C) 2018 Jouni Pentikäinen <joupent@gmail.com>
+ * SPDX-FileCopyrightText: 2018 Jouni Pentikäinen <joupent@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include <kis_signal_compressor.h>
 
 #include "KisSelectionPropertySlider.h"
 
+template class KisSelectionPropertySlider<KoShape *>;
+
 struct KisSelectionPropertySliderBase::Private
 {
-    KisSignalCompressor *signalCompressor;
+    KisSignalCompressor *signalCompressor {nullptr};
     QString normalPrefix;
     QString mixedPrefix;
 
@@ -49,7 +38,7 @@ void KisSelectionPropertySliderBase::setPrefixes(const QString &normalPrefix, co
     setPrefix(normalPrefix);
 }
 
-void KisSelectionPropertySliderBase::setInternalValue(int _value, bool blockUpdateSignal)
+void KisSelectionPropertySliderBase::setInternalValue(qreal _value, bool blockUpdateSignal)
 {
     static const qreal eps = 1e-3;
 
