@@ -1,4 +1,4 @@
-/* This file is part of the Calligra project
+/*
  * SPDX-FileCopyrightText: 2005 Thomas Zander <zander@kde.org>
  * SPDX-FileCopyrightText: 2005 C. Boemann <cbo@boemann.dk>
  * SPDX-FileCopyrightText: 2007 Boudewijn Rempt <boud@valdyas.org>
@@ -267,10 +267,11 @@ void KisCustomImageWidget::createImage()
     KisDocument *doc = createNewImage();
     if (doc) {
         doc->setModified(false);
-        emit m_openPane->documentSelected(doc);
+        Q_EMIT m_openPane->documentSelected(doc);
         m_openPane->accept();
+    } else {
+        newDialogConfirmationButtonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
     }
-    newDialogConfirmationButtonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
 }
 
 KisDocument* KisCustomImageWidget::createNewImage()
@@ -531,7 +532,7 @@ void KisCustomImageWidget::changeDocumentInfoLabel()
     int bitSize = 8 * cs->pixelSize(); //pixelsize is in bytes.
     layerSize = layerSize * cs->pixelSize();
     QString text = i18nc("arg1: width. arg2: height. arg3: colorspace name. arg4: size of a channel in bits. arg5: image size",
-                         "This document will be %1 pixels by %2 pixels in %3, which means the pixel size is %4 bit. A single paint layer will thus take up %5 of RAM.",
+                         "This document will be %1 pixels by %2 pixels in %3. The pixel size is %4 bit. A single paint layer will use %5 of RAM.",
                          width,
                          height,
                          cs->name(),
