@@ -552,6 +552,9 @@ void KisPaintOpPresetsEditor::resourceSelected(KoResourceSP resource)
     // get the preset image and pop it into the thumbnail area on the top of the brush editor
     QSize thumbSize = QSize(55, 55)*devicePixelRatioF();
     QImage thumbImage = resource->image();
+
+    m_d->uiWdgPaintOpPresetSettings.scratchPad->setPresetImage(thumbImage);
+
     QPixmap thumbnail;
     if (!thumbImage.isNull()) {
         thumbnail = QPixmap::fromImage(thumbImage.scaled(thumbSize, Qt::KeepAspectRatio, Qt::SmoothTransformation));
@@ -627,12 +630,6 @@ QString KisPaintOpPresetsEditor::currentPaintOpId() {
     return current_paintOpId;
 }
 
-void KisPaintOpPresetsEditor::setPresetImage(const QImage& image)
-{
-    m_d->uiWdgPaintOpPresetSettings.scratchPad->setPresetImage(image);
-    saveDialog->brushPresetThumbnailWidget->setPresetImage(image);
-}
-
 void KisPaintOpPresetsEditor::hideEvent(QHideEvent *event)
 {
     if (m_d->ignoreHideEvents) {
@@ -757,6 +754,8 @@ void KisPaintOpPresetsEditor::slotSaveBrushPreset() {
     // there is a dialog with save options, but we don't need to show it in this situation
 
     saveDialog->useNewBrushDialog(false); // this mostly just makes sure we keep the existing brush preset name when saving
+    const QImage thumbImage = m_d->resourceProvider->currentPreset() ? m_d->resourceProvider->currentPreset()->image() : QImage();
+    saveDialog->brushPresetThumbnailWidget->setPresetImage(thumbImage);
     saveDialog->saveScratchPadThumbnailArea(m_d->uiWdgPaintOpPresetSettings.scratchPad->cutoutOverlay());
     saveDialog->loadExistingThumbnail(); // This makes sure we use the existing preset icon when updating the existing brush preset
     saveDialog->showDialog();
@@ -768,6 +767,8 @@ void KisPaintOpPresetsEditor::slotSaveBrushPreset() {
 
 void KisPaintOpPresetsEditor::slotSaveNewBrushPreset() {
     saveDialog->useNewBrushDialog(true);
+    const QImage thumbImage = m_d->resourceProvider->currentPreset() ? m_d->resourceProvider->currentPreset()->image() : QImage();
+    saveDialog->brushPresetThumbnailWidget->setPresetImage(thumbImage);
     saveDialog->saveScratchPadThumbnailArea(m_d->uiWdgPaintOpPresetSettings.scratchPad->cutoutOverlay());
     saveDialog->showDialog();
 }
