@@ -17,10 +17,10 @@
 #include <brushengine/kis_paintop_preset.h>
 #include <kis_types.h>
 #include <kritaui_export.h>
+#include <KisDisplayConfig.h>
 
 class QColor;
 
-class KoColorProfile;
 class KoPointerEvent;
 
 class KisCanvasResourceProvider;
@@ -31,6 +31,7 @@ class KisScratchPadEventFilter;
 class KisPaintingInformationBuilder;
 class KisToolFreehandHelper;
 class KisNodeGraphListener;
+class KisScreenMigrationTracker;
 
 
 /**
@@ -126,9 +127,10 @@ public Q_SLOTS:
     QImage copyScratchpadImageData();
 
 private Q_SLOTS:
+    void slotScreenChanged(QScreen *screen);
     void setOnScreenResolution(qreal scaleX, qreal scaleY);
-    void setDisplayProfile(const KoColorProfile* colorProfile);
     void slotUpdateCanvas(const QRect &rect);
+    void slotConfigChanged();
 
 Q_SIGNALS:
     void colorSelected(const KoColor& color);
@@ -175,6 +177,7 @@ private:
     bool linkCanvasZoomLevel;
     KisPaintLayerSP m_paintLayer;
     const KoColorProfile* m_displayProfile;
+    KisDisplayConfig m_displayConfig;
     QCursor m_cursor;
     QCursor m_colorSamplerCursor;
     QRect m_cutoutOverlay;
@@ -197,6 +200,7 @@ private:
     int m_scaleBorderWidth;
 
     QImage m_presetImage;
+    QScopedPointer<KisScreenMigrationTracker> m_screenMigrationTracker;
 };
 
 #endif // KIS_SCRATCH_PAD_H
