@@ -767,7 +767,7 @@ void KoDialog::setDetailsWidgetVisible(bool visible)
     d->mSettingDetails = true;
     d->mDetailsVisible = visible;
     if (d->mDetailsVisible) {
-        emit aboutToShowDetails();
+        Q_EMIT aboutToShowDetails();
         setButtonText(Details, d->mDetailsButtonText + " <<");
         if (d->mDetailsWidget) {
             if (layout()) {
@@ -811,55 +811,55 @@ void KoDialog::delayedDestruct()
 void KoDialog::slotButtonClicked(int button)
 {
     Q_D(KoDialog);
-    emit buttonClicked(static_cast<KoDialog::ButtonCode>(button));
+    Q_EMIT buttonClicked(static_cast<KoDialog::ButtonCode>(button));
 
     switch (button) {
     case Ok:
-        emit okClicked();
+        Q_EMIT okClicked();
         accept();
         break;
     case Apply:
-        emit applyClicked();
+        Q_EMIT applyClicked();
         break;
     case Try:
-        emit tryClicked();
+        Q_EMIT tryClicked();
         break;
     case User3:
-        emit user3Clicked();
+        Q_EMIT user3Clicked();
         break;
     case User2:
-        emit user2Clicked();
+        Q_EMIT user2Clicked();
         break;
     case User1:
-        emit user1Clicked();
+        Q_EMIT user1Clicked();
         break;
     case Yes:
-        emit yesClicked();
+        Q_EMIT yesClicked();
         done(Yes);
         break;
     case No:
-        emit noClicked();
+        Q_EMIT noClicked();
         done(No);
         break;
     case Cancel:
-        emit cancelClicked();
+        Q_EMIT cancelClicked();
         reject();
         break;
     case Close:
-        emit closeClicked();
+        Q_EMIT closeClicked();
         done(Close); // KDE5: call reject() instead; more QDialog-like.
         break;
     case Help:
-        emit helpClicked();
+        Q_EMIT helpClicked();
         if (!d->mAnchor.isEmpty() || !d->mHelpApp.isEmpty()) {
             KHelpClient::invokeHelp(d->mAnchor, d->mHelpApp);
         }
         break;
     case Default:
-        emit defaultClicked();
+        Q_EMIT defaultClicked();
         break;
     case Reset:
-        emit resetClicked();
+        Q_EMIT resetClicked();
         break;
     case Details:
         setDetailsWidgetVisible(!d->mDetailsVisible);
@@ -924,10 +924,10 @@ QString KoDialog::helpLinkText() const
 
 void KoDialog::hideEvent(QHideEvent *event)
 {
-    emit hidden();
+    Q_EMIT hidden();
 
     if (!event->spontaneous()) {
-        emit finished();
+        Q_EMIT finished();
     }
 }
 
