@@ -21,8 +21,8 @@ public:
     enum Mode
     {
         ZOOM_CONSTANT = 0,  ///< zoom x %
-        ZOOM_WIDTH    = 1,  ///< zoom pagewidth
-        ZOOM_PAGE     = 2,  ///< zoom to pagesize
+        ZOOM_PAGE     = 1,  ///< zoom page
+        ZOOM_WIDTH    = 2,  ///< zoom pagewidth
         ZOOM_HEIGHT   = 16,  ///< zoom pageheight
         ZOOM_PIXELS   = 4   ///< zoom to actual pixels
     };
