@@ -94,42 +94,30 @@ void KisIntegerColorInput::update()
     m_intNumInput->blockSignals(true);
     m_colorSlider->blockSignals(true);
     switch (m_channelInfo->channelValueType()) {
-    case KoChannelInfo::UINT8:
-        if (m_usePercentage) {
-            m_intNumInput->setMaximum(100);
-            m_intNumInput->setValue(round(*(reinterpret_cast<quint8*>(data))*1.0 / 255.0 * 100.0));
-        } else {
-            m_intNumInput->setMaximum(0xFF);
-            m_intNumInput->setValue(*(reinterpret_cast<quint8*>(data)));
-        }
-        m_colorSlider->setValue(*(reinterpret_cast<quint8*>(data)));
+    case KoChannelInfo::UINT8: {
+        quint8 value = *(reinterpret_cast<quint8*>(data));
+        m_intNumInput->setValue(m_usePercentage ? round(value * 100.0 / 0xFF) : value);
+        m_colorSlider->setValue(value);
         *(reinterpret_cast<quint8*>(dataMin)) = 0x0;
         *(reinterpret_cast<quint8*>(dataMax)) = 0xFF;
         break;
-    case KoChannelInfo::UINT16:
-        if (m_usePercentage) {
-            m_intNumInput->setMaximum(100);
-            m_intNumInput->setValue(round(*(reinterpret_cast<quint16*>(data))*1.0 / 65535.0 * 100.0));
-        } else {
-            m_intNumInput->setMaximum(0xFFFF);
-            m_intNumInput->setValue(*(reinterpret_cast<quint16*>(data)));
         }
-        m_colorSlider->setValue(*(reinterpret_cast<quint16*>(data)));
+    case KoChannelInfo::UINT16: {
+        quint16 value = *(reinterpret_cast<quint16*>(data));
+        m_intNumInput->setValue(m_usePercentage ? round(value * 100.0 / 0xFFFF) : value);
+        m_colorSlider->setValue(value);
         *(reinterpret_cast<quint16*>(dataMin)) = 0x0;
         *(reinterpret_cast<quint16*>(dataMax)) = 0xFFFF;
         break;
-    case KoChannelInfo::UINT32:
-        if (m_usePercentage) {
-            m_intNumInput->setMaximum(100);
-            m_intNumInput->setValue(round(*(reinterpret_cast<quint32*>(data))*1.0 / 4294967295.0 * 100.0));
-        } else {
-            m_intNumInput->setMaximum(0xFFFF);
-            m_intNumInput->setValue(*(reinterpret_cast<quint32*>(data)));
-        }
-        m_colorSlider->setValue(*(reinterpret_cast<quint32*>(data)));
+    }
+    case KoChannelInfo::UINT32: {
+        quint32 value = *(reinterpret_cast<quint32*>(data));
+        m_intNumInput->setValue(m_usePercentage ? round(value * 100.0 / 0xFFFF'FFFF) : value);
+        m_colorSlider->setValue(value);
         *(reinterpret_cast<quint32*>(dataMin)) = 0x0;
-        *(reinterpret_cast<quint32*>(dataMax)) = 0xFFFFFFFF;
+        *(reinterpret_cast<quint32*>(dataMax)) = 0xFFFF'FFFF;
         break;
+    }
     default:
         Q_ASSERT(false);
     }
@@ -150,70 +138,53 @@ QWidget* KisIntegerColorInput::createInput()
         m_intNumInput->setSuffix("");
     }
 
-    switch (m_channelInfo->channelValueType()) {
-    case KoChannelInfo::UINT8:
-        if (m_usePercentage) {
-            m_intNumInput->setMaximum(100);
-        } else {
-            m_intNumInput->setMaximum(0xFF);
-        }
-        m_colorSlider->setMaximum(0xFF);
-        break;
-    case KoChannelInfo::UINT16:
-        if (m_usePercentage) {
-            m_intNumInput->setMaximum(100);
-        } else {
-            m_intNumInput->setMaximum(0xFFFF);
-        }
-        m_colorSlider->setMaximum(0xFFFF);
-        break;
-    case KoChannelInfo::UINT32:
-        if (m_usePercentage) {
-            m_intNumInput->setMaximum(100);
-        } else {
-            m_intNumInput->setMaximum(0xFFFFFFFF);
-        }
-        m_colorSlider->setMaximum(0xFFFFFFFF);
-        break;
-    default:
-        Q_ASSERT(false);
-    }
+    updateMaximums();
+
     connect(m_colorSlider, SIGNAL(valueChanged(int)), this, SLOT(onColorSliderChanged(int)));
     connect(m_intNumInput, SIGNAL(valueChanged(int)), this, SLOT(onNumInputChanged(int)));
     return m_intNumInput;
 }
 
+void KisIntegerColorInput::updateMaximums()
+{
+    m_intNumInput->clearFocus(); // make sure focus doesn't interfere with updating
+
+    Q_ASSERT(m_channelInfo->channelValueType() == KoChannelInfo::UINT8 ||
+             m_channelInfo->channelValueType() == KoChannelInfo::UINT16 ||
+             m_channelInfo->channelValueType() == KoChannelInfo::UINT32);
+
+    m_intNumInput->blockSignals(true); // prevent clamping from triggering a value update
+    m_intNumInput->setMaximum(m_usePercentage ? 100 : (1 << 8 * m_channelInfo->size()) - 1);
+    m_colorSlider->setMaximum((1 << 8 * m_channelInfo->size()) - 1);
+    m_intNumInput->blockSignals(false);
+}
+
 void KisIntegerColorInput::setPercentageWise(bool val)
 {
     m_usePercentage = val;
 
+    m_intNumInput->clearFocus(); // make sure focus doesn't interfere with updating
+
     if (m_usePercentage) {
         m_intNumInput->setSuffix(i18n("%"));
     } else {
         m_intNumInput->setSuffix("");
     }
+
+    updateMaximums();
 }
 
 void KisIntegerColorInput::onColorSliderChanged(int val)
 {
     m_intNumInput->blockSignals(true);
-    if (m_usePercentage) {
-        switch (m_channelInfo->channelValueType()) {
-        case KoChannelInfo::UINT8:
-            m_intNumInput->setValue(round((val*1.0) / 255.0 * 100.0));
-            break;
-        case KoChannelInfo::UINT16:
-            m_intNumInput->setValue(round((val*1.0) / 65535.0 * 100.0));
-            break;
-        case KoChannelInfo::UINT32:
-            m_intNumInput->setValue(round((val*1.0) / 4294967295.0 * 100.0));
-            break;
-        default:
-            Q_ASSERT(false);
-        }
-    } else {
-        m_intNumInput->setValue(val);
-    }
+
+    Q_ASSERT(m_channelInfo->channelValueType() == KoChannelInfo::UINT8 ||
+             m_channelInfo->channelValueType() == KoChannelInfo::UINT16 ||
+             m_channelInfo->channelValueType() == KoChannelInfo::UINT32);
+
+    m_intNumInput->setValue(m_usePercentage ? round(val * 100.0 / ((1 << 8 * m_channelInfo->size()) - 1))
+                                            : val);
+
     m_intNumInput->blockSignals(false);
     setValue(val);
 }
@@ -221,31 +192,17 @@ void KisIntegerColorInput::onColorSliderChanged(int val)
 void KisIntegerColorInput::onNumInputChanged(int val)
 {
     m_colorSlider->blockSignals(true);
-    if (m_usePercentage) {
-        switch (m_channelInfo->channelValueType()) {
-        case KoChannelInfo::UINT8:
-            m_colorSlider->setValue((val*1.0)/100.0 * 255.0);
-            m_colorSlider->blockSignals(false);
-            setValue((val*1.0)/100.0 * 255.0);
-            break;
-        case KoChannelInfo::UINT16:
-            m_colorSlider->setValue((val*1.0)/100.0 * 65535.0);
-            m_colorSlider->blockSignals(false);
-            setValue((val*1.0)/100.0 * 65535.0);
-            break;
-        case KoChannelInfo::UINT32:
-            m_colorSlider->setValue((val*1.0)/100.0 * 4294967295.0);
-            m_colorSlider->blockSignals(false);
-            setValue((val*1.0)/100.0 * 4294967295.0);
-            break;
-        default:
-            Q_ASSERT(false);
-        }
-    } else {
-        m_colorSlider->setValue(val);
-        m_colorSlider->blockSignals(false);
-        setValue(val);
-    }
+
+    Q_ASSERT(m_channelInfo->channelValueType() == KoChannelInfo::UINT8 ||
+             m_channelInfo->channelValueType() == KoChannelInfo::UINT16 ||
+             m_channelInfo->channelValueType() == KoChannelInfo::UINT32);
+
+    m_colorSlider->setValue(m_usePercentage ? val / 100.0 * ((1 << 8 * m_channelInfo->size()) - 1)
+                                            : val);
+
+    m_colorSlider->blockSignals(false);
+    setValue(m_usePercentage ? val / 100.0 * ((1 << 8 * m_channelInfo->size()) - 1)
+                             : val);
 }
 
 KisFloatColorInput::KisFloatColorInput(QWidget* parent, const KoChannelInfo* channelInfo, KoColor* color, KoColorDisplayRendererInterface *displayRenderer, bool usePercentage) :
@@ -277,6 +234,7 @@ QWidget* KisFloatColorInput::createInput()
     m_dblNumInput = new KisDoubleParseSpinBox(this);
     m_dblNumInput->setMinimum(0);
     m_dblNumInput->setMaximum(1.0);
+    m_dblNumInput->setSingleStep(0.01);
     connect(m_colorSlider, SIGNAL(valueChanged(int)), this, SLOT(sliderChanged(int)));
     connect(m_dblNumInput, SIGNAL(valueChanged(double)), this, SLOT(setValue(double)));
     m_dblNumInput->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
@@ -344,8 +302,12 @@ void KisFloatColorInput::update()
         Q_ASSERT(false);
     }
 
-    m_dblNumInput->setMinimum(m_minValue);
-    m_dblNumInput->setMaximum(m_maxValue);
+    if (m_minValue != m_dblNumInput->minimum()) {
+        m_dblNumInput->setMinimum(m_minValue);
+    }
+    if (m_maxValue != m_dblNumInput->maximum()) {
+        m_dblNumInput->setMaximum(m_maxValue);
+    }
 
     // ensure at least 3 significant digits are always shown
     int newPrecision = 2 + qMax(qreal(0.0), std::ceil(-std::log10(m_maxValue)));
@@ -453,25 +415,20 @@ KisHsvColorInput::KisHsvColorInput(QWidget *parent, KoColor *color)
     , m_mixMode(KisHsvColorSlider::MIX_MODE::HSV)
 {
 
-    QLabel *labels[3];
-    KisHsvColorSlider *sliders[3];
-    KisDoubleParseSpinBox *inputs[3];
-    const char *labelNames[3] = { "H:", "S:", "V:" };
+    const QStringList labelNames = QStringList({
+        i18nc("@label:slider Abbreviation for 'Hue'", "H:"),
+        i18nc("@label:slider Abbreviation for 'Saturation'", "S:"),
+        QString(/* x will get initialized later in setMixMode */) });
     qreal maxValues[3] = { 360, 100, 100 };
-    int labelWidth = 0;
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setContentsMargins(0,0,0,0);
+    QGridLayout *slidersLayout = new QGridLayout(this);
+    slidersLayout->setContentsMargins(0,0,0,0);
+    slidersLayout->setHorizontalSpacing(1); // less space around the sliders
 
     for (int i = 0; i < 3; i++) {
-        // Slider layout
-        QHBoxLayout *sliderLayout = new QHBoxLayout();
-        sliderLayout->setContentsMargins(0,0,0,0);
-        sliderLayout->setSpacing(1);
-
         // Label
-        QLabel *label = new QLabel(i18n(labelNames[i]), this);
-        sliderLayout->addWidget(label);
+        QLabel *label = new QLabel(labelNames[i], this);
+        slidersLayout->addWidget(label, i, 0);
 
         // Slider itself
         KisHsvColorSlider *slider = new KisHsvColorSlider(Qt::Horizontal, this);
@@ -479,7 +436,7 @@ KisHsvColorInput::KisHsvColorInput(QWidget *parent, KoColor *color)
         slider->setMinimum(0);
         slider->setMaximum(maxValues[i]);
         slider->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-        sliderLayout->addWidget(slider);
+        slidersLayout->addWidget(slider, i, 1);
 
         // Input box
         KisDoubleParseSpinBox *input = new KisDoubleParseSpinBox(this);
@@ -491,39 +448,31 @@ KisHsvColorInput::KisHsvColorInput(QWidget *parent, KoColor *color)
         input->setMaximumWidth(60);
 
         slider->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-        sliderLayout->addWidget(input);
+        slidersLayout->addWidget(input, i, 2);
 
-        mainLayout->addLayout(sliderLayout);
-
-        // Record max label width
-        labelWidth = qMax(labelWidth, label->sizeHint().width());
-
-        sliders[i] = slider;
-        inputs[i] = input;
-        labels[i] = label;
-    }
-
-    // Align the labels
-    for (int i = 0; i < 3; i++) {
-        labels[i]->setMinimumWidth(labelWidth);
+        switch (i) {
+        case 0:
+            m_hSlider = slider;
+            m_hInput = input;
+        case 1:
+            m_sSlider = slider;
+            m_sInput = input;
+        case 2:
+            m_xLabel = label; // Save the HSX label so we can update it
+            m_xSlider = slider;
+            m_xInput = input;
+        }
     }
 
     // Connect slots
-    connect(sliders[0], SIGNAL(valueChanged(int)), this, SLOT(hueSliderChanged(int)));
-    connect(inputs[0], SIGNAL(valueChanged(double)), this, SLOT(setHue(double)));
-    connect(sliders[1], SIGNAL(valueChanged(int)), this, SLOT(saturationSliderChanged(int)));
-    connect(inputs[1], SIGNAL(valueChanged(double)), this, SLOT(setSaturation(double)));
-    connect(sliders[2], SIGNAL(valueChanged(int)), this, SLOT(valueSliderChanged(int)));
-    connect(inputs[2], SIGNAL(valueChanged(double)), this, SLOT(setValue(double)));
+    connect(m_hSlider, SIGNAL(valueChanged(int)), this, SLOT(hueSliderChanged(int)));
+    connect(m_hInput, SIGNAL(valueChanged(double)), this, SLOT(setHue(double)));
+    connect(m_sSlider, SIGNAL(valueChanged(int)), this, SLOT(saturationSliderChanged(int)));
+    connect(m_sInput, SIGNAL(valueChanged(double)), this, SLOT(setSaturation(double)));
+    connect(m_xSlider, SIGNAL(valueChanged(int)), this, SLOT(valueSliderChanged(int)));
+    connect(m_xInput, SIGNAL(valueChanged(double)), this, SLOT(setValue(double)));
 
-    m_hSlider = sliders[0];
-    m_hSlider->setMixMode(KisHsvColorSlider::MIX_MODE::HSV);
-    m_sSlider = sliders[1];
-    m_xSlider = sliders[2];
-
-    m_hInput = inputs[0];
-    m_sInput = inputs[1];
-    m_xInput = inputs[2];
+    setMixMode(KisHsvColorSlider::MIX_MODE::HSV);
 
     // Set initial values
     QColor c = m_color->toQColor();
@@ -544,6 +493,23 @@ KisHsvColorInput::KisHsvColorInput(QWidget *parent, KoColor *color)
 }
 
 void KisHsvColorInput::setMixMode(KisHsvColorSlider::MIX_MODE mixMode) {
+
+    switch (mixMode) {
+	case KisHsvColorSlider::MIX_MODE::HSL:
+        m_xLabel->setText(i18nc("@label:slider Abbreviation for 'Lightness' of HSL color model", "L:"));
+		break;
+	case KisHsvColorSlider::MIX_MODE::HSY:
+        m_xLabel->setText(i18nc("@label:slider Abbreviation for 'Luma' of HSY color model", "Y:"));
+		break;
+	case KisHsvColorSlider::MIX_MODE::HSI:
+        m_xLabel->setText(i18nc("@label:slider Abbreviation for 'Intensity' of HSI color model", "I:"));
+		break;
+	default: // fallthrough
+	case KisHsvColorSlider::MIX_MODE::HSV:
+        m_xLabel->setText(i18nc("@label:slider Abbreviation for 'Value' of HSV color model", "V:"));
+		break;
+	}
+
 	QColor c = m_color->toQColor();
 	m_mixMode = mixMode;
 	getHsxF(c, &m_h, &m_s, &m_x);
@@ -581,13 +547,7 @@ void KisHsvColorInput::sendUpdate()
 
 void KisHsvColorInput::setHue(double x)
 {
-    if (x < 0) {
-        x = 0;
-    }
-
-    if (x > 360) {
-        x = 360;
-    }
+    x = qBound(0.0, x, 360.0);
 
     m_h = x / 360;
     sendUpdate();
@@ -595,13 +555,7 @@ void KisHsvColorInput::setHue(double x)
 
 void KisHsvColorInput::setSaturation(double x)
 {
-    if (x < 0) {
-        x = 0;
-    }
-
-    if (x > 100) {
-        x = 100;
-    }
+    x = qBound(0.0, x, 100.0);
 
     m_s = x / 100;
     sendUpdate();
@@ -609,13 +563,7 @@ void KisHsvColorInput::setSaturation(double x)
 
 void KisHsvColorInput::setValue(double x)
 {
-    if (x < 0) {
-        x = 0;
-    }
-
-    if (x > 100) {
-        x = 100;
-    }
+    x = qBound(0.0, x, 100.0);
 
     m_x = x / 100;
     sendUpdate();
