@@ -13,7 +13,7 @@
 #include <QMap>
 
 class QAction;
-class KActionCollection;
+class KisKActionCollection;
 
 
 /**
@@ -40,7 +40,7 @@ public:
      * WARNING: the collections are owned by the snapshot! Don't destroy
      *          the snapshot before you are done with the collections!
      */
-    QMap<QString, KActionCollection*> actionCollections();
+    QMap<QString, KisKActionCollection*> actionCollections();
 
 private:
     struct Private;
