@@ -3,17 +3,9 @@
  * Date  : 2005-01-01
  * Description :
  *
- * Copyright 2005 by Tom Albers <tomalbers@kde.nl>
+ * SPDX-FileCopyrightText: 2005 Tom Albers <tomalbers@kde.nl>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)* any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -96,20 +88,21 @@ QSize KisSqueezedComboBox::sizeHint() const
     QStyleOptionComboBox options;
     options.initFrom(this);
 
-    return style()->sizeFromContents(QStyle::CT_ComboBox, &options,
-                                     QSize(maxW, maxH), this).expandedTo(QApplication::globalStrut());
+    return style()->sizeFromContents(QStyle::CT_ComboBox, &options, QSize(maxW, maxH), this);
 }
 
 void KisSqueezedComboBox::insertSqueezedItem(const QString& newItem, int index, QVariant userData)
 {
     m_originalItems[index] = newItem;
     QComboBox::insertItem(index, squeezeText(newItem, this), userData);
+    setItemData(index, newItem, Qt::ToolTipRole);
 }
 
 void KisSqueezedComboBox::insertSqueezedItem(const QIcon &icon, const QString &newItem, int index, QVariant userData)
 {
     m_originalItems[index] = newItem;
     QComboBox::insertItem(index, icon, squeezeText(newItem, this), userData);
+    setItemData(index, newItem, Qt::ToolTipRole);
 }
 
 void KisSqueezedComboBox::addSqueezedItem(const QString& newItem, QVariant userData)
