@@ -8,6 +8,7 @@
     SPDX-FileCopyrightText: 2002 Ellis Whitehead <ellis@kde.org>
     SPDX-FileCopyrightText: 2003 Andras Mantia <amantia@kde.org>
     SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2022 Alvin Wong <alvin@alvinhc.com>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -23,6 +24,8 @@ class KConfigGroup;
 class KRecentFilesActionPrivate;
 
 class QIcon;
+class QStandardItemModel;
+class QStandardItem;
 
 /**
  *  @short Recent files action
@@ -37,7 +40,6 @@ class QIcon;
 class KRITAWIDGETUTILS_EXPORT KRecentFilesAction : public KSelectAction
 {
     Q_OBJECT
-    Q_PROPERTY(int maxItems READ maxItems WRITE setMaxItems)
     Q_DECLARE_PRIVATE(KRecentFilesAction)
 
 public:
@@ -93,67 +95,15 @@ public:
      */
     QAction *removeAction(QAction *action) override;
 
-public Q_SLOTS:
+private Q_SLOTS:
     /**
      * Clears the recent files list.
      * Note that there is also an action shown to the user for clearing the list.
      */
-    virtual void clear();
+    virtual void clearActionTriggered();
 
 public:
-    /**
-     *  Returns the maximum of items in the recent files list.
-     */
-    int maxItems() const;
-
-    /**
-     *  Sets the maximum of items in the recent files list.
-     *  The default for this value is 10 set in the constructor.
-     *
-     *  If this value is lesser than the number of items currently
-     *  in the recent files list the last items are deleted until
-     *  the number of items are equal to the new maximum.
-     */
-    void setMaxItems(int maxItems);
-
-    /**
-     *  Loads the recent files entries from a given KConfigGroup object.
-     *  You can provide the name of the group used to load the entries.
-     *  If the groupname is empty, entries are loaded from a group called 'RecentFiles'.
-     *  Local file entries that do not exist anymore are not restored.
-     *
-     */
-    void loadEntries(const KConfigGroup &config);
-
-    /**
-     *  Saves the current recent files entries to a given KConfigGroup object.
-     *  You can provide the name of the group used to load the entries.
-     *  If the groupname is empty, entries are saved to a group called 'RecentFiles'
-     *
-     */
-    void saveEntries(const KConfigGroup &config);
-
-    /**
-     *  Add URL to recent files list.
-     *
-     *  @param url The URL of the file
-     *  @param name The user visible pretty name that appears before the URL
-     */
-    void addUrl(const QUrl &url, const QString &name = QString());
-
-    /**
-     *  Remove an URL from the recent files list.
-     *
-     *  @param url The URL of the file
-     */
-    void removeUrl(const QUrl &url);
-
-    /**
-     *  Retrieve a list of all URLs in the recent files list.
-     */
-    QList<QUrl> urls() const;
-
-    void setUrlIcon(const QUrl &url, const QIcon &icon);
+    void setRecentFilesModel(const QStandardItemModel *model);
 
 Q_SIGNALS:
     /**
@@ -163,13 +113,6 @@ Q_SIGNALS:
      */
     void urlSelected(const QUrl &url);
 
-    /**
-     *  This signal gets emitted when the user clear list.
-     *  So when user stores url in specific config file it can saveEntry.
-     *  @since 4.3
-     */
-    void recentListCleared();
-
 private:
     //Internal
     void clearEntries();
@@ -178,9 +121,20 @@ private:
     using KSelectAction::addAction;
 
     KRecentFilesActionPrivate *d_ptr;
-    QList<QUrl> d_urls;
 
     Q_PRIVATE_SLOT(d_func(), void _k_urlSelected(QAction *))
+
+    void rebuildEntries();
+
+private Q_SLOTS:
+    void fileAdded(const QUrl &url);
+    void fileRemoved(const QUrl &url);
+    void listRenewed();
+
+    void modelItemChanged(QStandardItem *item);
+    void modelRowsInserted(const QModelIndex &parent, int first, int last);
+
+    void menuAboutToShow();
 };
 
 #endif
