@@ -155,7 +155,7 @@ public:
     void loadActionFiles();
     void loadCustomShortcuts(QString filename = QStringLiteral("kritashortcutsrc"));
 
-    // XXX: this adds a default item for the given name to the list of actioninfo objects!
+    // XXX: this adds a default item for the given name to the list of actionInfo objects!
     ActionInfoItem &actionInfo(const QString &name) {
         if (!actionInfoList.contains(name)) {
             dbgAction << "Tried to look up info for unknown action" << name;
@@ -255,7 +255,7 @@ void KisActionRegistry::settingsPageSaved()
    loadCustomShortcuts();
 
    // Announce UI should reload current shortcuts.
-   emit shortcutsUpdated();
+   Q_EMIT shortcutsUpdated();
 }
 
 
@@ -328,7 +328,7 @@ bool KisActionRegistry::propertizeAction(const QString &name, QAction * a)
         QString icon      = getChildContent(actionXml, "icon");
         QString text      = getChildContent_i18n("text");
         QString whatsthis = getChildContent_i18n("whatsThis");
-        // tooltip is set in updateShortcut() because shortcit gets appended to the tooltip
+        // tooltip is set in updateShortcut() because shortcut gets appended to the tooltip
         //QString toolTip   = getChildContent_i18n("toolTip");
         QString statusTip = getChildContent_i18n("statusTip");
         QString iconText  = getChildContent_i18n("iconText");
@@ -402,7 +402,7 @@ void KisActionRegistry::Private::loadActionFiles()
             QDomElement actionXml  = categoryTextNode.nextSiblingElement();
 
             if (actionXml.isNull()) {
-                qWarning() << actionDefinition << "does not contain any valid actios! (Or the text element was left empty...)";
+                qWarning() << actionDefinition << "does not contain any valid actions! (Or the text element was left empty...)";
             }
 
             // Loop over individual actions
