@@ -411,7 +411,7 @@ void KisKKeySequenceWidgetPrivate::doneRecording(bool validate)
         // The sequence had conflicts and the user said no to stealing it
         keySequence = oldKeySequence;
     } else {
-        emit q->keySequenceChanged(keySequence);
+        Q_EMIT q->keySequenceChanged(keySequence);
     }
 
     updateShortcutDisplay();
@@ -512,7 +512,7 @@ bool KisKKeySequenceWidgetPrivate::conflictWithLocalShortcuts(const QKeySequence
 
         // Announce that the user agreed to override the other shortcut
         Q_FOREACH (QAction *stealAction, stealActions) {
-            emit q->stealShortcut(
+            Q_EMIT q->stealShortcut(
                 keySequence,
                 stealAction);
         }
