@@ -468,6 +468,8 @@ void KisKMainWindow::savePropertiesInternal(KConfig *config, int number)
 
 void KisKMainWindow::saveMainWindowSettings(KConfigGroup &cg)
 {
+    if (!windowsLayoutSavingAllowed()) return;
+
     K_D(KisKMainWindow);
     //qDebug(200) << "KisKMainWindow::saveMainWindowSettings " << cg.name();
 
@@ -641,6 +643,11 @@ bool KisKMainWindow::settingsDirty() const
     return d->settingsDirty;
 }
 
+bool KisKMainWindow::windowsLayoutSavingAllowed() const
+{
+    return true;
+}
+
 void KisKMainWindow::setAutoSaveSettings(const QString &groupName, bool saveWindowSize)
 {
     setAutoSaveSettings(KConfigGroup(KSharedConfig::openConfig(), groupName), saveWindowSize);
