@@ -1,20 +1,8 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2000 Kurt Granroth <granroth@kde.org>
+   SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+   SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef kxmlguifactory_h
@@ -25,9 +13,9 @@
 #include <QObject>
 
 class QAction;
-class KXMLGUIFactoryPrivate;
-class KXMLGUIClient;
-class KXMLGUIBuilder;
+class KisKXMLGUIFactoryPrivate;
+class KisKXMLGUIClient;
+class KisKXMLGUIBuilder;
 
 class QDomAttr;
 class QDomDocument;
@@ -35,7 +23,7 @@ class QDomElement;
 class QDomNode;
 class QDomNamedNodeMap;
 
-namespace KXMLGUI
+namespace KisKXMLGUI
 {
 struct MergingIndex;
 struct ContainerNode;
@@ -44,40 +32,40 @@ class BuildHelper;
 }
 
 /**
- * KXMLGUIFactory, together with KXMLGUIClient objects, can be used to create
+ * KisKXMLGUIFactory, together with KisKXMLGUIClient objects, can be used to create
  * a GUI of container widgets (like menus, toolbars, etc.) and container items
  * (menu items, toolbar buttons, etc.) from an XML document and action objects.
  *
- * Each KXMLGUIClient represents a part of the GUI, composed from containers and
- * actions. KXMLGUIFactory takes care of building (with the help of a KXMLGUIBuilder)
+ * Each KisKXMLGUIClient represents a part of the GUI, composed from containers and
+ * actions. KisKXMLGUIFactory takes care of building (with the help of a KisKXMLGUIBuilder)
  * and merging the GUI from an unlimited number of clients.
  *
  * Each client provides XML through a QDomDocument and actions through a
- * KActionCollection . The XML document contains the rules for how to merge the
+ * KisKActionCollection . The XML document contains the rules for how to merge the
  * GUI.
  *
- * KXMLGUIFactory processes the DOM tree provided by a client and plugs in the client's actions,
+ * KisKXMLGUIFactory processes the DOM tree provided by a client and plugs in the client's actions,
  * according to the XML and the merging rules of previously inserted clients. Container widgets
- * are built via a KXMLGUIBuilder , which has to be provided with the KXMLGUIFactory constructor.
+ * are built via a KisKXMLGUIBuilder , which has to be provided with the KisKXMLGUIFactory constructor.
  */
-class KRITAWIDGETUTILS_EXPORT KXMLGUIFactory : public QObject
+class KRITAWIDGETUTILS_EXPORT KisKXMLGUIFactory : public QObject
 {
-    friend class KXMLGUI::BuildHelper;
+    friend class KisKXMLGUI::BuildHelper;
     Q_OBJECT
 public:
     /**
-     * Constructs a KXMLGUIFactory. The provided @p builder KXMLGUIBuilder will be called
+     * Constructs a KisKXMLGUIFactory. The provided @p builder KisKXMLGUIBuilder will be called
      * for creating and removing container widgets, when clients are added/removed from the GUI.
      *
-     * Note that the ownership of the given KXMLGUIBuilder object won't be transferred to this
-     * KXMLGUIFactory, so you have to take care of deleting it properly.
+     * Note that the ownership of the given KisKXMLGUIBuilder object won't be transferred to this
+     * KisKXMLGUIFactory, so you have to take care of deleting it properly.
      */
-    explicit KXMLGUIFactory(KXMLGUIBuilder *builder, QObject *parent = 0);
+    explicit KisKXMLGUIFactory(KisKXMLGUIBuilder *builder, QObject *parent = 0);
 
     /**
      * Destructor
      */
-    ~KXMLGUIFactory() override;
+    ~KisKXMLGUIFactory() override;
 
     // XXX move to somewhere else? (Simon)
     /// @internal
@@ -110,22 +98,22 @@ public:
      * plugin's UI is merged into the UI of your application, and not the other
      * way round.
      */
-    void addClient(KXMLGUIClient *client);
+    void addClient(KisKXMLGUIClient *client);
 
     /**
      * Removes the GUI described by the client, by unplugging all
      * provided actions and removing all owned containers (and storing
      * container state information in the given client)
      */
-    void removeClient(KXMLGUIClient *client);
+    void removeClient(KisKXMLGUIClient *client);
 
-    void plugActionList(KXMLGUIClient *client, const QString &name, const QList<QAction *> &actionList);
-    void unplugActionList(KXMLGUIClient *client, const QString &name);
+    void plugActionList(KisKXMLGUIClient *client, const QString &name, const QList<QAction *> &actionList);
+    void unplugActionList(KisKXMLGUIClient *client, const QString &name);
 
     /**
      * Returns a list of all clients currently added to this factory
      */
-    QList<KXMLGUIClient *> clients() const;
+    QList<KisKXMLGUIClient *> clients() const;
 
     /**
      * Use this method to get access to a container widget with the name specified with @p containerName
@@ -147,41 +135,41 @@ public:
      *
      * This method may return 0 if no container with the given name exists or is not owned by the client.
      */
-    QWidget *container(const QString &containerName, KXMLGUIClient *client, bool useTagName = false);
+    QWidget *container(const QString &containerName, KisKXMLGUIClient *client, bool useTagName = false);
 
     QList<QWidget *> containers(const QString &tagName);
 
     /**
-     * Use this method to free all memory allocated by the KXMLGUIFactory. This deletes the internal node
+     * Use this method to free all memory allocated by the KisKXMLGUIFactory. This deletes the internal node
      * tree and therefore resets the internal state of the class. Please note that the actual GUI is
      * NOT touched at all, meaning no containers are deleted nor any actions unplugged. That is
      * something you have to do on your own. So use this method only if you know what you are doing :-)
      *
-     * (also note that this will call KXMLGUIClient::setFactory( 0 ) for all inserted clients)
+     * (also note that this will call KisKXMLGUIClient::setFactory( 0 ) for all inserted clients)
      */
     void reset();
 
     /**
-     * Use this method to free all memory allocated by the KXMLGUIFactory for a specific container,
+     * Use this method to free all memory allocated by the KisKXMLGUIFactory for a specific container,
      * including all child containers and actions. This deletes the internal node subtree for the
      * specified container. The actual GUI is not touched, no containers are deleted or any actions
      * unplugged. Use this method only if you know what you are doing :-)
      *
-     * (also note that this will call KXMLGUIClient::setFactory( 0 ) for all clients of the
+     * (also note that this will call KisKXMLGUIClient::setFactory( 0 ) for all clients of the
      * container)
      */
     void resetContainer(const QString &containerName, bool useTagName = false);
 
 Q_SIGNALS:
-    void clientAdded(KXMLGUIClient *client);
-    void clientRemoved(KXMLGUIClient *client);
+    void clientAdded(KisKXMLGUIClient *client);
+    void clientRemoved(KisKXMLGUIClient *client);
 
     /**
      * Emitted when the factory is currently making changes to the GUI,
      * i.e. adding or removing clients.
      * makingChanges(true) is emitted before any change happens, and
      * makingChanges(false) is emitted after the change is done.
-     * This allows e.g. KMainWindow to know that the GUI is
+     * This allows e.g. KisKMainWindow to know that the GUI is
      * being changed programmatically and not by the user (so there is no reason to
      * save toolbar settings afterwards).
      * @since 4.1.3
@@ -189,11 +177,11 @@ Q_SIGNALS:
     void makingChanges(bool);
 
 private:
-    friend class KXMLGUIClient;
-    /// Internal, called by KXMLGUIClient destructor
-    void forgetClient(KXMLGUIClient *client);
+    friend class KisKXMLGUIClient;
+    /// Internal, called by KisKXMLGUIClient destructor
+    void forgetClient(KisKXMLGUIClient *client);
 
-    KXMLGUIFactoryPrivate *const d;
+    KisKXMLGUIFactoryPrivate *const d;
 };
 
 #endif
