@@ -38,21 +38,19 @@ KisPaintingAssistantSP InfiniteRulerAssistant::clone(QMap<KisPaintingAssistantHa
     return KisPaintingAssistantSP(new InfiniteRulerAssistant(*this, handleMap));
 }
 
-QPointF InfiniteRulerAssistant::project(const QPointF& pt, const QPointF& strokeBegin)
+QPointF InfiniteRulerAssistant::project(const QPointF& pt, const QPointF& strokeBegin, const bool checkForInitialMovement, qreal moveThresholdPt)
 {
     Q_ASSERT(isAssistantComplete());
     //code nicked from the perspective ruler.
-    qreal
-            dx = pt.x() - strokeBegin.x(),
-            dy = pt.y() - strokeBegin.y();
-        if (dx * dx + dy * dy < 4.0) {
-            // allow some movement before snapping
-            return strokeBegin;
-        }
-    //dbgKrita<<strokeBegin<< ", " <<*handles()[0];
+    qreal dx = pt.x() - strokeBegin.x();
+    qreal dy = pt.y() - strokeBegin.y();
+    if (checkForInitialMovement && KisAlgebra2D::norm(QPointF(dx, dy)) < moveThresholdPt) {
+        // allow some movement before snapping
+        return strokeBegin;
+    }
+
     QLineF snapLine = QLineF(*handles()[0], *handles()[1]);
     
-    
         dx = snapLine.dx();
         dy = snapLine.dy();
     const qreal
@@ -66,9 +64,16 @@ QPointF InfiniteRulerAssistant::project(const QPointF& pt, const QPointF& stroke
     //return pt;
 }
 
-QPointF InfiniteRulerAssistant::adjustPosition(const QPointF& pt, const QPointF& strokeBegin, const bool /*snapToAny*/)
+QPointF InfiniteRulerAssistant::adjustPosition(const QPointF& pt, const QPointF& strokeBegin, const bool /*snapToAny*/, qreal moveThresholdPt)
 {
-    return project(pt, strokeBegin);
+    return project(pt, strokeBegin, true, moveThresholdPt);
+}
+
+void InfiniteRulerAssistant::adjustLine(QPointF &point, QPointF &strokeBegin)
+{
+
+    point = project(point, strokeBegin, false, 0.0);
+    strokeBegin = project(strokeBegin, strokeBegin, false, 0.0);
 }
 
 void InfiniteRulerAssistant::drawSubdivisions(QPainter& gc, const KisCoordinatesConverter *converter) {
@@ -236,7 +241,7 @@ InfiniteRulerAssistant::ClippingResult InfiniteRulerAssistant::clipLineParametri
     return ClippingResult{tmin < tmax, tmin, tmax};
 }
 
-QPointF InfiniteRulerAssistant::getEditorPosition() const
+QPointF InfiniteRulerAssistant::getDefaultEditorPosition() const
 {
     return (*handles()[0]);
 }
