@@ -39,18 +39,10 @@ ParallelRulerAssistant::ParallelRulerAssistant(const ParallelRulerAssistant &rhs
 {
 }
 
-QPointF ParallelRulerAssistant::project(const QPointF& pt, const QPointF& strokeBegin, qreal moveThresholdPt)
+QPointF ParallelRulerAssistant::project(const QPointF& pt, const QPointF& strokeBegin, qreal /*moveThresholdPt*/)
 {
     Q_ASSERT(isAssistantComplete());
 
-    //code nicked from the perspective ruler.
-    qreal dx = pt.x() - strokeBegin.x();
-    qreal dy = pt.y() - strokeBegin.y();
-
-    if (KisAlgebra2D::norm(QPointF(dx, dy)) < moveThresholdPt) {
-        return strokeBegin; // allow some movement before snapping
-    }
-
     if (isLocal() && isAssistantComplete()) {
         if (getLocalRect().contains(pt)) {
             m_hasBeenInsideLocalRect = true;
@@ -64,8 +56,8 @@ QPointF ParallelRulerAssistant::project(const QPointF& pt, const QPointF& stroke
     QPointF translation = (*handles()[0]-strokeBegin)*-1.0;
     snapLine = snapLine.translated(translation);
 
-    dx = snapLine.dx();
-    dy = snapLine.dy();
+    qreal dx = snapLine.dx();
+    qreal dy = snapLine.dy();
 
     const qreal
             dx2 = dx * dx,
@@ -75,7 +67,6 @@ QPointF ParallelRulerAssistant::project(const QPointF& pt, const QPointF& stroke
               dx2 * snapLine.y1() + dy2 * pt.y() + dx * dy * (pt.x() - snapLine.x1()));
     r *= invsqrlen;
     return r;
-    //return pt;
 }
 
 QPointF ParallelRulerAssistant::adjustPosition(const QPointF& pt, const QPointF& strokeBegin, const bool /*snapToAny*/, qreal moveThresholdPt)
@@ -92,18 +83,6 @@ void ParallelRulerAssistant::drawAssistant(QPainter& gc, const QRectF& updateRec
 {
     gc.save();
     gc.resetTransform();
-    QPointF mousePos(0,0);
-
-    if (canvas){
-        //simplest, cheapest way to get the mouse-position//
-        mousePos= canvas->canvasWidget()->mapFromGlobal(QCursor::pos());
-    }
-    else {
-        //...of course, you need to have access to a canvas-widget for that.//
-        mousePos = QCursor::pos();//this'll give an offset//
-        dbgFile<<"canvas does not exist in ruler, you may have passed arguments incorrectly:"<<canvas;
-    }
-
 
     QTransform initialTransform = converter->documentToWidgetTransform();
     QRectF local = getLocalRect();
@@ -130,9 +109,7 @@ void ParallelRulerAssistant::drawAssistant(QPainter& gc, const QRectF& updateRec
         //don't draw if invalid.
         QLineF snapLine= QLineF(initialTransform.map(*handles()[0]), initialTransform.map(*handles()[1]));
 
-        if (m_followBrushPosition && m_adjustedPositionValid) {
-            mousePos = initialTransform.map(m_adjustedBrushPosition);
-        }
+        QPointF mousePos = effectiveBrushPosition(converter, canvas);
 
         QPointF translation = (initialTransform.map(*handles()[0])-mousePos)*-1.0;
         snapLine= snapLine.translated(translation);
