@@ -20,8 +20,9 @@ class RulerAssistant : public KisPaintingAssistant
 public:
     RulerAssistant();
     KisPaintingAssistantSP clone(QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap) const override;
-    QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, const bool snapToAny) override;
-    QPointF getEditorPosition() const override;
+    QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, const bool snapToAny, qreal moveThresholdPt) override;
+    void adjustLine(QPointF &point, QPointF& strokeBegin) override;
+    QPointF getDefaultEditorPosition() const override;
     int numHandles() const override { return 2; }
     bool isAssistantComplete() const override;
     void saveCustomXml(QXmlStreamWriter *xml) override;
