@@ -18,19 +18,69 @@
 #include <kis_canvas2.h>
 #include <kis_coordinates_converter.h>
 #include "kis_debug.h"
+#include "KisBezierUtils.h"
 
 #include <math.h>
 #include <limits>
 #include <algorithm>
 
+struct GoldenSearchParams
+{
+    GoldenSearchParams(qreal lbound
+                ,qreal ubound)
+        :lbound(lbound)
+        ,ubound(ubound)
+    {
+        samples = QVector<GoldenSearchPoint>(4);
+    }
+
+    struct GoldenSearchPoint {
+        GoldenSearchPoint(qreal xval)
+            : x(xval)
+        {
+        }
+
+        GoldenSearchPoint(){}
+
+        void inv_norm(qreal l, qreal u)
+        {
+            this->xnorm = this->x * (u - l) + l;
+        }
+
+        qreal fval;
+        qreal xnorm;
+        qreal x;
+    };
+
+
+    qreal lbound;
+    qreal ubound;
+    QVector<GoldenSearchPoint> samples;
+};
+
+
+struct SplineAssistant::Private {
+    Private();
+
+    QPointF prevStrokebegin;
+    qreal prev_t {0};
+};
+
+SplineAssistant::Private::Private()
+    : prevStrokebegin(0,0)
+{
+}
+
 SplineAssistant::SplineAssistant()
     : KisPaintingAssistant("spline", i18n("Spline assistant"))
+    , m_d(new Private)
 {
 }
 
 SplineAssistant::SplineAssistant(const SplineAssistant &rhs, QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap)
     : KisPaintingAssistant(rhs, handleMap)
     , m_canvas(rhs.m_canvas)
+    , m_d(new Private)
 {
 }
 
@@ -68,27 +118,104 @@ inline qreal D(qreal t, const QPointF& P0, const QPointF& P1, const QPointF& P2,
     return x_dist * x_dist + y_dist * y_dist;
 }
 
-QPointF SplineAssistant::project(const QPointF& pt) const
-{
-    Q_ASSERT(isAssistantComplete());
-    // minimize d(t), but keep t in the same neighbourhood as before (unless starting a new stroke)
-    // (this is a rather inefficient method)
-    qreal min_t = std::numeric_limits<qreal>::max();
-    qreal d_min_t = std::numeric_limits<qreal>::max();
 
-    for (qreal t = 0; t <= 1; t += 1e-3) {
-        qreal d_t = D(t, *handles()[0], *handles()[2], *handles()[3], *handles()[1], pt);
-        if (d_t < d_min_t) {
-            d_min_t = d_t;
-            min_t = t;
+inline qreal goldenSearch(const QPointF& pt
+                          , const QList<KisPaintingAssistantHandleSP> handles
+                          , qreal low
+                          , qreal high
+                          , qreal tolerance
+                          , uint max_iter)
+{
+    GoldenSearchParams ovalues = GoldenSearchParams(low,high);
+    QVector<GoldenSearchParams::GoldenSearchPoint> p = ovalues.samples;
+    qreal u = ovalues.ubound;
+    qreal l = ovalues.lbound;
+
+    const qreal ratio = 1 - 2/(1 + sqrt(5));
+    p[0].x = 0;
+    p[1].x = ratio;
+    p[2].x = 1 - p[1].x;
+    p[3].x = 1;
+
+    p[1].inv_norm(l,u);
+    p[2].inv_norm(l,u);
+
+    p[1].fval = D(p[1].xnorm, *handles[0], *handles[2], *handles[3], *handles[1], pt);
+    p[2].fval = D(p[2].xnorm, *handles[0], *handles[2], *handles[3], *handles[1], pt);
+
+    GoldenSearchParams::GoldenSearchPoint xtemp = GoldenSearchParams::GoldenSearchPoint(0);
+
+    uint i = 0; // used to force early exit
+    while ( qAbs(p[2].xnorm - p[1].xnorm) > tolerance && i < max_iter) {
+
+        if (p[1].fval < p[2].fval) {
+            xtemp = p[1];
+            p[3] = p[2];
+            p[1].x = p[0].x + (p[2].x - p[1].x);
+            p[2] = xtemp;
+
+            p[1].inv_norm(l,u);
+            p[1].fval = D(p[1].xnorm, *handles[0], *handles[2], *handles[3], *handles[1], pt);
+
+        } else {
+            xtemp = p[2];
+            p[0] = p[1];
+            p[2].x = p[1].x + (p[3].x - p[2].x);
+            p[1] = xtemp;
+
+            p[2].inv_norm(l,u);
+            p[2].fval = D(p[2].xnorm, *handles[0], *handles[2], *handles[3], *handles[1], pt);
+
         }
+        i++;
     }
-    return B(min_t, *handles()[0], *handles()[2], *handles()[3], *handles()[1]);
+    return (p[2].xnorm + p[1].xnorm) / 2;
 }
 
-QPointF SplineAssistant::adjustPosition(const QPointF& pt, const QPointF& /*strokeBegin*/, const bool /*snapToAny*/)
+
+QPointF SplineAssistant::project(const QPointF& pt, const QPointF& strokeBegin) const
 {
-    return project(pt);
+    Q_ASSERT(isAssistantComplete());
+
+    // minimize d(t), but keep t in the same neighbourhood as before (unless starting a new stroke)
+    bool stayClose = (m_d->prevStrokebegin == strokeBegin)? true : false;
+    qreal min_t;
+
+    QList<QPointF> refs;
+    QVector<int> hindex = {0,2,3,1}; // order handles as expected by KisBezierUtils
+    Q_FOREACH(int i, hindex) {
+        refs.append(*handles()[i]);
+    }
+
+    if (stayClose){
+        // Search in the vicinity of previous t value.
+        // This ensure unimodality for proper goldenSearch algorithm
+        qreal delta = 1/10.0;
+        qreal lbound = qBound(0.0,1.0, m_d->prev_t - delta);
+        qreal ubound = qBound(0.0,1.0, m_d->prev_t + delta);
+        min_t = goldenSearch(pt,handles(), lbound , ubound, 1e-6,1e+2);
+
+    } else {
+        min_t = KisBezierUtils::nearestPoint(refs,pt);
+    }
+
+    QPointF draw_pos = B(min_t, *handles()[0], *handles()[2], *handles()[3], *handles()[1]);
+
+    m_d->prev_t = min_t;
+    m_d->prevStrokebegin = strokeBegin;
+
+    return draw_pos;
+}
+
+QPointF SplineAssistant::adjustPosition(const QPointF& pt, const QPointF& strokeBegin, const bool /*snapToAny*/, qreal /*moveThresholdPt*/)
+{
+    return project(pt, strokeBegin);
+}
+
+void SplineAssistant::adjustLine(QPointF &point, QPointF &strokeBegin)
+{
+    point = QPointF();
+    strokeBegin = QPointF();
 }
 
 void SplineAssistant::drawAssistant(QPainter& gc, const QRectF& updateRect, const KisCoordinatesConverter* converter, bool cached, KisCanvas2* canvas, bool assistantVisible, bool previewVisible)
@@ -195,7 +322,7 @@ void SplineAssistant::drawCache(QPainter& gc, const KisCoordinatesConverter *con
 
 }
 
-QPointF SplineAssistant::getEditorPosition() const
+QPointF SplineAssistant::getDefaultEditorPosition() const
 {
     return B(0.5, *handles()[0], *handles()[2], *handles()[3], *handles()[1]);
 }
