@@ -25,8 +25,6 @@
 
 VanishingPointAssistant::VanishingPointAssistant()
     : KisPaintingAssistant("vanishing point", i18n("Vanishing Point assistant"))
-    , m_followBrushPosition(false)
-    , m_adjustedPositionValid(false)
 {
 }
 
@@ -34,9 +32,6 @@ VanishingPointAssistant::VanishingPointAssistant(const VanishingPointAssistant &
     : KisPaintingAssistant(rhs, handleMap)
     , m_canvas(rhs.m_canvas)
     , m_referenceLineDensity(rhs.m_referenceLineDensity)
-    , m_followBrushPosition(rhs.m_followBrushPosition)
-    , m_adjustedPositionValid(rhs.m_adjustedPositionValid)
-    , m_adjustedBrushPosition(rhs.m_adjustedBrushPosition)
 {
 }
 
@@ -45,36 +40,9 @@ KisPaintingAssistantSP VanishingPointAssistant::clone(QMap<KisPaintingAssistantH
     return KisPaintingAssistantSP(new VanishingPointAssistant(*this, handleMap));
 }
 
-void VanishingPointAssistant::setAdjustedBrushPosition(const QPointF position)
-{
-    m_adjustedBrushPosition = position;
-    m_adjustedPositionValid = true;
-}
-
-void VanishingPointAssistant::endStroke()
-{
-    // Brush stroke ended, guides should follow the brush position again.
-    m_followBrushPosition = false;
-    m_adjustedPositionValid = false;
-    m_hasBeenInsideLocalRect = false;
-}
-
-void VanishingPointAssistant::setFollowBrushPosition(bool follow)
-{
-    m_followBrushPosition = follow;
-}
-
-QPointF VanishingPointAssistant::project(const QPointF& pt, const QPointF& strokeBegin)
+QPointF VanishingPointAssistant::project(const QPointF& pt, const QPointF& strokeBegin, qreal /*moveThresholdPt*/)
 {
     //Q_ASSERT(handles().size() == 1 || handles().size() == 5);
-    //code nicked from the perspective ruler.
-    qreal dx = pt.x() - strokeBegin.x();
-    qreal dy = pt.y() - strokeBegin.y();
-
-    if (dx * dx + dy * dy < 4.0) {
-        // allow some movement before snapping
-        return strokeBegin;
-    }
 
     if (isLocal() && isAssistantComplete()) {
         if (getLocalRect().contains(pt)) {
@@ -88,8 +56,8 @@ QPointF VanishingPointAssistant::project(const QPointF& pt, const QPointF& strok
     QLineF snapLine = QLineF(*handles()[0], strokeBegin);
 
 
-    dx = snapLine.dx();
-    dy = snapLine.dy();
+    qreal dx = snapLine.dx();
+    qreal dy = snapLine.dy();
 
     const qreal dx2 = dx * dx;
     const qreal dy2 = dy * dy;
@@ -102,9 +70,14 @@ QPointF VanishingPointAssistant::project(const QPointF& pt, const QPointF& strok
     return r;
 }
 
-QPointF VanishingPointAssistant::adjustPosition(const QPointF& pt, const QPointF& strokeBegin, const bool /*snapToAny*/)
+QPointF VanishingPointAssistant::adjustPosition(const QPointF& pt, const QPointF& strokeBegin, const bool /*snapToAny*/, qreal moveThresholdPt)
 {
-    return project(pt, strokeBegin);
+    return project(pt, strokeBegin, moveThresholdPt);
+}
+
+void VanishingPointAssistant::adjustLine(QPointF &point, QPointF &strokeBegin)
+{
+    point = project(point, strokeBegin, 0.0);
 }
 
 void VanishingPointAssistant::drawAssistant(QPainter& gc, const QRectF& updateRect, const KisCoordinatesConverter* converter, bool cached, KisCanvas2* canvas, bool assistantVisible, bool previewVisible)
@@ -121,18 +94,6 @@ void VanishingPointAssistant::drawAssistant(QPainter& gc, const QRectF& updateRe
 
     gc.save();
     gc.resetTransform();
-    QPointF mousePos(0,0);
-
-    if (canvas) {
-        //simplest, cheapest way to get the mouse-position//
-        mousePos= canvas->canvasWidget()->mapFromGlobal(QCursor::pos());
-        m_canvas = canvas;
-    }
-    else {
-        //...of course, you need to have access to a canvas-widget for that.//
-        mousePos = QCursor::pos();//this'll give an offset//
-        dbgFile<<"canvas does not exist in ruler, you may have passed arguments incorrectly:"<<canvas;
-    }
 
     QRect viewport= gc.viewport();
 
@@ -147,10 +108,7 @@ void VanishingPointAssistant::drawAssistant(QPainter& gc, const QRectF& updateRe
 
             QTransform initialTransform = converter->documentToWidgetTransform();
             QPointF startPoint = initialTransform.map(*handles()[0]);
-
-            if (m_followBrushPosition && m_adjustedPositionValid) {
-                mousePos = initialTransform.map(m_adjustedBrushPosition);
-            }
+            QPointF mousePos = effectiveBrushPosition(converter, canvas);
 
             QLineF snapLine= QLineF(startPoint, mousePos);
 
@@ -170,7 +128,7 @@ void VanishingPointAssistant::drawAssistant(QPainter& gc, const QRectF& updateRe
 
 
     // editor specific controls display
-    if (canvas->paintingAssistantsDecoration()->isEditingAssistants()) {
+    if (canvas && canvas->paintingAssistantsDecoration()->isEditingAssistants()) {
 
         // draws a circle around the vanishing point node while editing
         QTransform initialTransform = converter->documentToWidgetTransform();
@@ -306,7 +264,7 @@ KisPaintingAssistantHandleSP VanishingPointAssistant::secondLocalHandle() const
     }
 }
 
-QPointF VanishingPointAssistant::getEditorPosition() const
+QPointF VanishingPointAssistant::getDefaultEditorPosition() const
 {
     int pointHandle = 0;
     if (handles().size() > pointHandle) {
