@@ -42,11 +42,9 @@ public:
     };
 
     KisPaintingAssistantSP clone(QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap) const override;
-    QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, bool snapToAny) override;
-    void setAdjustedBrushPosition(const QPointF position) override;
-    void setFollowBrushPosition(bool follow) override;
-    void endStroke() override;
-    QPointF getEditorPosition() const override;
+    QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, bool snapToAny, qreal moveThresholdPt) override;
+    void adjustLine(QPointF &point, QPointF& strokeBegin) override;
+    QPointF getDefaultEditorPosition() const override;
     int numHandles() const override { return isLocal() ? 3 : 1; }
 
     float referenceLineDensity();
@@ -68,20 +66,12 @@ protected:
 private:
 
 
-    QPointF project(const QPointF& pt, const QPointF& strokeBegin);
+    QPointF project(const QPointF& pt, const QPointF& strokeBegin, qreal moveThresholdPt);
     explicit VanishingPointAssistant(const VanishingPointAssistant &rhs, QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap);
 
     KisCanvas2 *m_canvas {nullptr};
 
     float m_referenceLineDensity {15.0};
-
-    // Needed to make sure that when we are in the middle of a brush stroke, the
-    // guides follow the brush position, not the cursor position.
-    bool m_followBrushPosition {false};
-    bool m_adjustedPositionValid {false};
-    QPointF m_adjustedBrushPosition;
-    bool m_hasBeenInsideLocalRect {false};
-
 };
 
 class VanishingPointAssistantFactory : public KisPaintingAssistantFactory
