@@ -134,17 +134,6 @@ public:
     {
     }
 
-    bool conserveColorInformation() const override {
-        return true;
-    }
-
-    bool conserveDynamicRange() const override {
-        return
-            dstColorDepthId() == Float16BitsColorDepthID.id() ||
-            dstColorDepthId() == Float32BitsColorDepthID.id() ||
-            dstColorDepthId() == Float64BitsColorDepthID.id();
-    }
-
     KoColorConversionTransformation* createColorTransformation(const KoColorSpace* srcColorSpace,
                                                                const KoColorSpace* dstColorSpace,
                                                                KoColorConversionTransformation::Intent renderingIntent,
@@ -174,14 +163,6 @@ public:
     {
     }
 
-    bool conserveColorInformation() const override {
-        return true;
-    }
-
-    bool conserveDynamicRange() const override {
-        return true;
-    }
-
     KoColorConversionTransformation* createColorTransformation(const KoColorSpace* srcColorSpace,
                                                                const KoColorSpace* dstColorSpace,
                                                                KoColorConversionTransformation::Intent renderingIntent,
@@ -212,17 +193,6 @@ public:
         KIS_SAFE_ASSERT_RECOVER_NOOP(srcColorDepthId() != dstColorDepthId());
     }
 
-    bool conserveColorInformation() const override {
-        return true;
-    }
-
-    bool conserveDynamicRange() const override {
-        return
-            srcColorDepthId() == Float16BitsColorDepthID.id() ||
-            srcColorDepthId() == Float32BitsColorDepthID.id() ||
-            srcColorDepthId() == Float64BitsColorDepthID.id();
-    }
-
     KoColorConversionTransformation* createColorTransformation(const KoColorSpace* srcColorSpace,
                                                                const KoColorSpace* dstColorSpace,
                                                                KoColorConversionTransformation::Intent renderingIntent,
