@@ -41,7 +41,7 @@ public:
 
     static QString colorSpaceId()
     {
-        return QString("RGBA16");
+        return QStringLiteral("RGBA16");
     }
 
     void fillGrayBrushWithColorAndLightnessOverlay(quint8 *dst, const QRgb *brush, quint8 *brushColor, qint32 nPixels) const override;
