@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include <kis_debug.h>
@@ -21,8 +9,7 @@
 #include <klocalizedstring.h>
 #include <KoCanvasResourceProvider.h>
 #include <KoResourceServerProvider.h>
-#include <KoResourceServerObserver.h>
-#include <KoResourceServerAdapter.h>
+#include <KoResourceServer.h>
 #include <KoCanvasBase.h>
 #include <kis_canvas2.h>
 #include <KoColor.h>
@@ -35,7 +22,7 @@
 #include <kis_node_selection_adapter.h>
 #include <kis_group_layer.h>
 #include <KisView.h>
-#include <KoResourceItemChooser.h>
+#include <KisResourceItemChooser.h>
 #include <kis_display_color_converter.h>
 
 #include <QWidget>
@@ -102,9 +89,11 @@ ArtisticColorSelectorDock::ArtisticColorSelectorDock()
 
     m_selectorUI->bnWheelPrefs->setIcon(KisIconUtils::loadIcon("wheel-sectors"));
     m_selectorUI->bnWheelPrefs->setPopupWidget(m_wheelPrefsUI);
+    m_selectorUI->bnWheelPrefs->setArrowVisible(false);
 
     m_selectorUI->bnDockerPrefs->setPopupWidget(m_preferencesUI);
-    m_selectorUI->bnDockerPrefs->setIcon(KisIconUtils::loadIcon("configure"));
+    m_selectorUI->bnDockerPrefs->setIcon(KisIconUtils::loadIcon("configure-thicker"));
+    m_selectorUI->bnDockerPrefs->setArrowVisible(false);
 
     //preferences
     m_hsxButtons->addButton(m_preferencesUI->bnHsy, KisColor::HSY);
@@ -229,8 +218,8 @@ void ArtisticColorSelectorDock::setViewManager(KisViewManager* kisview)
     m_selectorUI->colorSelector->setFgColor(m_resourceProvider->resourceManager()->foregroundColor());
     m_selectorUI->colorSelector->setBgColor(m_resourceProvider->resourceManager()->backgroundColor());
 
-    connect(m_resourceProvider, SIGNAL(sigGamutMaskChanged(KoGamutMask*)),
-            this, SLOT(slotGamutMaskSet(KoGamutMask*)), Qt::UniqueConnection);
+    connect(m_resourceProvider, SIGNAL(sigGamutMaskChanged(KoGamutMaskSP)),
+            this, SLOT(slotGamutMaskSet(KoGamutMaskSP)), Qt::UniqueConnection);
 
     connect(m_resourceProvider, SIGNAL(sigGamutMaskUnset()),
             this, SLOT(slotGamutMaskUnset()), Qt::UniqueConnection);
@@ -246,10 +235,10 @@ void ArtisticColorSelectorDock::setViewManager(KisViewManager* kisview)
 
 void ArtisticColorSelectorDock::slotCanvasResourceChanged(int key, const QVariant& value)
 {
-    if(key == KoCanvasResourceProvider::ForegroundColor)
+    if(key == KoCanvasResource::ForegroundColor)
         m_selectorUI->colorSelector->setFgColor(value.value<KoColor>());
 
-    if(key == KoCanvasResourceProvider::BackgroundColor)
+    if(key == KoCanvasResource::BackgroundColor)
         m_selectorUI->colorSelector->setBgColor(value.value<KoColor>());
 }
 
@@ -421,7 +410,7 @@ void ArtisticColorSelectorDock::unsetCanvas()
     m_selectorUI->colorSelector->setColorConverter(KisDisplayColorConverter::dumbConverterInstance());
 }
 
-void ArtisticColorSelectorDock::slotGamutMaskSet(KoGamutMask *mask)
+void ArtisticColorSelectorDock::slotGamutMaskSet(KoGamutMaskSP mask)
 {
     if (!mask) {
         return;
