@@ -13,14 +13,13 @@
 #include <KoCanvasObserverBase.h>
 #include <KisKineticScroller.h>
 
+#include "KisWidgetWithIdleTask.h"
 #include <kis_canvas2.h>
 
 class ChannelModel;
 class QTableView;
-class KisSignalCompressor;
-class KisIdleWatcher;
 
-class ChannelDockerDock : public QDockWidget, public KoCanvasObserverBase {
+class ChannelDockerDock : public KisWidgetWithIdleTask<QDockWidget>, public KoCanvasObserverBase {
     Q_OBJECT
 public:
     ChannelDockerDock();
@@ -28,19 +27,19 @@ public:
     QString observerName() override { return "ChannelDockerDock"; }
     void setCanvas(KoCanvasBase *canvas) override;
     void unsetCanvas() override;
-    void showEvent(QShowEvent *event) override;
 
 public Q_SLOTS:
     void startUpdateCanvasProjection();
     void slotScrollerStateChanged(QScroller::State state){KisKineticScroller::updateCursor(this, state);}
 
 private Q_SLOTS:
-    void updateChannelTable(void);
+    void updateImageThumbnails(const QVector<QImage> &channels, const KoColorSpace *cs);
+
+private:
+    KisIdleTasksManager::TaskGuard registerIdleTask(KisCanvas2 *canvas) override;
+    void clearCachedState() override;
 
 private:
-    KisIdleWatcher* m_imageIdleWatcher {nullptr};
-    KisSignalCompressor *m_compressor {nullptr};
-    QPointer<KisCanvas2> m_canvas;
     QTableView *m_channelTable {nullptr};
     ChannelModel *m_model {nullptr};
 };
