@@ -13,15 +13,14 @@
 #include <QPixmap>
 #include <QPointer>
 
-#include <QMutex>
-#include "kis_idle_watcher.h"
+#include "KisWidgetWithIdleTask.h"
 
 #include <kis_canvas2.h>
 
 class KisSignalCompressor;
 class KoCanvasBase;
 
-class OverviewWidget : public QWidget
+class OverviewWidget : public KisWidgetWithIdleTask<QWidget>
 {
     Q_OBJECT
 
@@ -30,11 +29,7 @@ public:
 
     ~OverviewWidget() override;
 
-    virtual void setCanvas(KoCanvasBase *canvas);
-    virtual void unsetCanvas()
-    {
-        m_canvas = 0;
-    }
+    void setCanvas(KisCanvas2 *canvas) override;
 
     inline bool isDragging() const
     {
@@ -43,7 +38,6 @@ public:
 
 public Q_SLOTS:
     void startUpdateCanvasProjection();
-    void generateThumbnail();
     void updateThumbnail(QImage pixmap);
     void slotThemeChanged();
 
@@ -53,7 +47,6 @@ Q_SIGNALS:
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
-    void showEvent(QShowEvent *event) override;
     void paintEvent(QPaintEvent *event) override;
 
     void mousePressEvent(QMouseEvent* event) override;
@@ -63,6 +56,8 @@ protected:
 
 private:
     void recalculatePreviewDimensions();
+    KisIdleTasksManager::TaskGuard registerIdleTask(KisCanvas2 *canvas) override;
+    void clearCachedState() override;
     ///
     /// \brief isPixelArt checks if the preview is bigger than the image itself
     ///
@@ -84,21 +79,14 @@ private:
     qreal m_previewScale {1.0};
     QPixmap m_oldPixmap;
     QPixmap m_pixmap;
-    QImage m_image;
-    QPointer<KisCanvas2> m_canvas;
-
 
     QPointF m_previewOrigin; // in the same coordinates space as m_previewSize
     QSize m_previewSize {QSize(100, 100)};
 
-
     bool m_dragging {false};
     QPointF m_lastPos {QPointF(0, 0)};
 
     QColor m_outlineColor;
-    KisIdleWatcher m_imageIdleWatcher;
-    KisStrokeId strokeId;
-    QMutex mutex;
 };
 
 
