@@ -23,7 +23,7 @@ public:
     ~RecorderDockerPlugin() override;
 
 private:
-    KisViewManager* m_view;
+    KisViewManager* m_view {nullptr};
 };
 
 #endif
