@@ -1,21 +1,9 @@
 /*
  *  dlg_rotateimage.h -- part of KimageShop^WKrayon^WKrita
  *
- *  Copyright (c) 2004 Michael Thaler <michael.thaler@physik.tu-muenchen.de>
+ *  SPDX-FileCopyrightText: 2004 Michael Thaler <michael.thaler@physik.tu-muenchen.de>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #ifndef DLG_ROTATEIMAGE
 #define DLG_ROTATEIMAGE
@@ -63,11 +51,13 @@ private Q_SLOTS:
     void okClicked();
     void resetPreview();
     void slotAngleValueChanged(double);
+    void slotRadioCCWToggled(bool toggled);
+    void slotRadioCWToggled(bool toggled);
 
 private:
 
     WdgRotateImage * m_page;
-    double m_oldAngle;
+    double m_oldAngle {0.0};
     bool m_lock;
 
 };
