@@ -1,21 +1,9 @@
 /*
  * This file is part of Krita
  *
- * Copyright (c) 2009 Edward Apap <schumifer@hotmail.com>
+ * SPDX-FileCopyrightText: 2009 Edward Apap <schumifer@hotmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 
@@ -54,9 +42,9 @@ KisConfigWidget * KisGaussianBlurFilter::createConfigurationWidget(QWidget* pare
     return new KisWdgGaussianBlur(usedForMasks, parent);
 }
 
-KisFilterConfigurationSP KisGaussianBlurFilter::factoryConfiguration() const
+KisFilterConfigurationSP KisGaussianBlurFilter::defaultConfiguration(KisResourcesInterfaceSP resourcesInterface) const
 {
-    KisFilterConfigurationSP config = new KisFilterConfiguration(id().id(), 1);
+    KisFilterConfigurationSP config = factoryConfiguration(resourcesInterface);
     config->setProperty("horizRadius", 5);
     config->setProperty("vertRadius", 5);
     config->setProperty("lockAspect", true);
@@ -66,21 +54,18 @@ KisFilterConfigurationSP KisGaussianBlurFilter::factoryConfiguration() const
 
 void KisGaussianBlurFilter::processImpl(KisPaintDeviceSP device,
                                         const QRect& rect,
-                                        const KisFilterConfigurationSP _config,
+                                        const KisFilterConfigurationSP config,
                                         KoUpdater* progressUpdater
                                         ) const
 {
     Q_ASSERT(device != 0);
 
-    KisFilterConfigurationSP config = _config ? _config : new KisFilterConfiguration(id().id(), 1);
+    KIS_SAFE_ASSERT_RECOVER_RETURN(config);
 
     KisLodTransformScalar t(device);
 
-    QVariant value;
-    config->getProperty("horizRadius", value);
-    float horizontalRadius = t.scale(value.toFloat());
-    config->getProperty("vertRadius", value);
-    float verticalRadius = t.scale(value.toFloat());
+    const qreal horizontalRadius = t.scale(config->getDouble("horizRadius", 5));
+    const qreal verticalRadius = t.scale(config->getDouble("vertRadius", 5));
 
     QBitArray channelFlags;
     if (config) {
