@@ -1,21 +1,9 @@
 /*
  * This file is part of Krita
  *
- * Copyright (c) 2009 Edward Apap <schumifer@hotmail.com>
+ * SPDX-FileCopyrightText: 2009 Edward Apap <schumifer@hotmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_wdg_gaussian_blur.h"
@@ -28,6 +16,7 @@
 #include <kis_selection.h>
 #include <kis_paint_device.h>
 #include <kis_processing_information.h>
+#include <KisGlobalResourcesInterface.h>
 
 #include "ui_wdg_gaussian_blur.h"
 
@@ -67,7 +56,7 @@ KisWdgGaussianBlur::~KisWdgGaussianBlur()
 
 KisPropertiesConfigurationSP KisWdgGaussianBlur::configuration() const
 {
-    KisFilterConfigurationSP config = new KisFilterConfiguration("gaussian blur", 1);
+    KisFilterConfigurationSP config = new KisFilterConfiguration("gaussian blur", 1, KisGlobalResourcesInterface::instance());
     config->setProperty("horizRadius", m_widget->horizontalRadius->value());
     config->setProperty("vertRadius", m_widget->verticalRadius->value());
     config->setProperty("lockAspect", m_widget->aspectButton->keepAspectRatio());
