@@ -1,19 +1,7 @@
 /*
-  a *  Copyright (c) 2005 Cyrille Berger <cberger@cberger.net>
+  a *  SPDX-FileCopyrightText: 2005 Cyrille Berger <cberger@cberger.net>
   *
-  *  This program is free software; you can redistribute it and/or modify
-  *  it under the terms of the GNU General Public License as published by
-  *  the Free Software Foundation; either version 2 of the License, or
-  *  (at your option) any later version.
-  *
-  *  This program is distributed in the hope that it will be useful,
-  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  *  GNU General Public License for more details.
-  *
-  *  You should have received a copy of the GNU General Public License
-  *  along with this program; if not, write to the Free Software
-  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  *  SPDX-License-Identifier: GPL-2.0-or-later
   */
 #ifndef KISSIMPLENOISEREDUCER_H
 #define KISSIMPLENOISEREDUCER_H
@@ -46,7 +34,7 @@ public:
     QRect neededRect(const QRect &rect, const KisFilterConfigurationSP _config, int lod) const override;
 
 protected:
-    KisFilterConfigurationSP  defaultConfiguration() const override;
+    KisFilterConfigurationSP  defaultConfiguration(KisResourcesInterfaceSP resourcesInterface) const override;
 };
 
 #endif
