@@ -1,21 +1,9 @@
 /*
  * This file is part of the KDE project
  *
- * Copyright (c) 2005 Cyrille Berger <cberger@cberger.net>
+ * SPDX-FileCopyrightText: 2005 Cyrille Berger <cberger@cberger.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "wavefilter.h"
@@ -110,12 +98,12 @@ KisFilterWave::KisFilterWave() : KisFilter(id(), FiltersCategoryOtherId, i18n("&
 {
     setColorSpaceIndependence(FULLY_INDEPENDENT);
     setSupportsPainting(false);
-    setSupportsAdjustmentLayers(false);
+    setSupportsAdjustmentLayers(true);
 }
 
-KisFilterConfigurationSP KisFilterWave::defaultConfiguration() const
+KisFilterConfigurationSP KisFilterWave::defaultConfiguration(KisResourcesInterfaceSP resourcesInterface) const
 {
-    KisFilterConfigurationSP config = factoryConfiguration();
+    KisFilterConfigurationSP config = factoryConfiguration(resourcesInterface);
     config->setProperty("horizontalwavelength", 50);
     config->setProperty("horizontalshift", 50);
     config->setProperty("horizontalamplitude", 4);
@@ -150,32 +138,33 @@ void KisFilterWave::processImpl(KisPaintDeviceSP device,
     int verticalamplitude = (config && config->getProperty("verticalamplitude", value)) ? value.toInt() : 4;
     int verticalshape = (config && config->getProperty("verticalshape", value)) ? value.toInt() : 0;
 
-    KisWaveCurve* horizontalcurve;
-    if (horizontalshape == 1)
-        horizontalcurve = new KisTriangleWaveCurve(horizontalamplitude, horizontalwavelength, horizontalshift);
-    else
-        horizontalcurve = new KisSinusoidalWaveCurve(horizontalamplitude, horizontalwavelength, horizontalshift);
-
-    KisWaveCurve* verticalcurve;
+    KisWaveCurve* verticalWave;
     if (verticalshape == 1)
-        verticalcurve = new KisTriangleWaveCurve(verticalamplitude, verticalwavelength, verticalshift);
+        verticalWave = new KisTriangleWaveCurve(verticalamplitude, verticalwavelength, verticalshift);
     else
-        verticalcurve = new KisSinusoidalWaveCurve(verticalamplitude, verticalwavelength, verticalshift);
+        verticalWave = new KisSinusoidalWaveCurve(verticalamplitude, verticalwavelength, verticalshift);
+
+    KisWaveCurve* horizontalWave;
+    if (horizontalshape == 1)
+        horizontalWave = new KisTriangleWaveCurve(horizontalamplitude, horizontalwavelength, horizontalshift);
+    else
+        horizontalWave = new KisSinusoidalWaveCurve(horizontalamplitude, horizontalwavelength, horizontalshift);
     
-    KisSequentialIteratorProgress dstIt(device, applyRect, progressUpdater);
-    KisRandomSubAccessorSP srcRSA = device->createRandomSubAccessor();
-    while (dstIt.nextPixel()) {
-        double xv = horizontalcurve->valueAt(dstIt.y(), dstIt.x());
-        double yv = verticalcurve->valueAt(dstIt.x(), dstIt.y());
-        srcRSA->moveTo(QPointF(xv, yv));
-        srcRSA->sampledOldRawData(dstIt.rawData());
+    KisSequentialIteratorProgress destination(device, applyRect, progressUpdater);
+    KisRandomSubAccessorSP source = device->createRandomSubAccessor();
+
+    while (destination.nextPixel()) {
+        double xv = horizontalWave->valueAt(destination.y(), destination.x());
+        double yv = verticalWave->valueAt(destination.x(), destination.y());
+        source->moveTo(QPointF(xv, yv));
+        source->sampledOldRawData(destination.rawData());
     }
 
-    delete horizontalcurve;
-    delete verticalcurve;
+    delete verticalWave;
+    delete horizontalWave;
 }
 
-QRect KisFilterWave::neededRect(const QRect& rect, const KisFilterConfigurationSP config, int lod) const
+QRect KisFilterWave::changedRect(const QRect &rect, const KisFilterConfigurationSP config, int lod) const
 {
     Q_UNUSED(lod);
 
@@ -185,4 +174,9 @@ QRect KisFilterWave::neededRect(const QRect& rect, const KisFilterConfigurationS
     return rect.adjusted(-horizontalamplitude, -verticalamplitude, horizontalamplitude, verticalamplitude);
 }
 
+QRect KisFilterWave::neededRect(const QRect& rect, const KisFilterConfigurationSP config, int lod) const
+{
+    return changedRect(rect, config, lod);
+}
+
 #include "wavefilter.moc"
