@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007,2010,2011 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2010 Carlos Licea <carlos@kdab.com>
- * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2007, 2010, 2011 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2010 Carlos Licea <carlos@kdab.com>
+ * SPDX-FileCopyrightText: 2010 Nokia Corporation and /or its subsidiary(-ies).
  *   Contact: Suresh Chande suresh.chande@nokia.com
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOENHANCEDPATHSHAPE_H
@@ -105,7 +92,7 @@ public:
 
     /// Sets if the shape is to be mirrored horizontally before applying any other transformations
     //NOTE: in the standard nothing is mentioned about the priorities of the transformations"
-    //it's assumed like this because of the behavior shwon in OOo
+    //it's assumed like this because of the behavior shown in OOo
     void setMirrorHorizontally(bool mirrorHorizontally);
 
     /// Sets if the shape is to be mirrored vertically before applying any other transformations
@@ -123,10 +110,6 @@ public:
     EnhancedPathParameter *parameter(const QString &text);
 
 protected:
-    // from KoShape
-    void saveOdf(KoShapeSavingContext &context) const override;
-    // from KoShape
-    bool loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context) override;
     //from KoShape
     void shapeChanged(ChangeType type, KoShape *shape = 0) override;
     // from KoParameterShape
