@@ -33,31 +33,31 @@ composite_one(rgba bot,rgba top)
     if( !FULLALPHA(bot) ) {
         alpha = 255 ^ scaletable[255-ALPHA(bot)][255-ALPHA(top)] ;
         /* This peculiar combination of ^ and - makes the GCC code
-     * generator for i386 particularly happy.
-     */
+         * generator for i386 particularly happy.
+         */
         tfrac = (256*ALPHA(top) - 1) / alpha ;
         /* Tfrac is the fraction of the coposited pixel's covered area
-     * that comes from the top pixel.
-     * For mathematical accuracy we ought to scale by 255 and
-     * subtract alpha/2, but this is faster, and never misses the
-     * true value by more than one 1/255. This effect is completely
-     * overshadowed by the linear interpolation in the first place.
-     * (I.e. gamma is ignored when combining intensities).
-     *   [In any case, complete fairness is not possible: if the
-     *    bottom pixel had alpha=170 and the top has alpha=102,
-     *    each should contribute equally to the color of the
-     *    resulting alpha=204 pixel, which is not possible in general]
-     * Subtracting one helps the topfrac never be 256, which would
-     * be bad.
-     * On the other hand it means that we would get tfrac=-1 if the
-     * top pixel is completely transparent, and we get a division
-     * by zero if _both_ pixels are fully transparent. These cases
-     * must be handled by all callers.
-     *    More snooping in the Gimp sources reveal that it uses
-     *    floating-point for its equivalent of tfrac when the
-     *    bottom layer has an alpha channel. (alphify() macro
-     *    in paint-funcs.c). What gives?
-     */
+         * that comes from the top pixel.
+         * For mathematical accuracy we ought to scale by 255 and
+         * subtract alpha/2, but this is faster, and never misses the
+         * true value by more than one 1/255. This effect is completely
+         * overshadowed by the linear interpolation in the first place.
+         * (I.e. gamma is ignored when combining intensities).
+         *   [In any case, complete fairness is not possible: if the
+         *    bottom pixel had alpha=170 and the top has alpha=102,
+         *    each should contribute equally to the color of the
+         *    resulting alpha=204 pixel, which is not possible in general]
+         * Subtracting one helps the topfrac never be 256, which would
+         * be bad.
+         * On the other hand it means that we would get tfrac=-1 if the
+         * top pixel is completely transparent, and we get a division
+         * by zero if _both_ pixels are fully transparent. These cases
+         * must be handled by all callers.
+         *    More snooping in the Gimp sources reveal that it uses
+         *    floating-point for its equivalent of tfrac when the
+         *    bottom layer has an alpha channel. (alphify() macro
+         *    in paint-funcs.c). What gives?
+         */
     }
     return (alpha << ALPHA_SHIFT)
             + ((uint32_t)scaletable[  tfrac  ][255&(top>>RED_SHIFT  )] << RED_SHIFT   )
@@ -119,7 +119,7 @@ merge_normal(struct Tile *bot, struct Tile *top)
     return bot ;
 }
 
-#define exotic_combinator static unsigned __ATTRIBUTE__((const))
+#define exotic_combinator static inline unsigned __ATTRIBUTE__((const))
 
 
 
@@ -179,13 +179,13 @@ ucombine_OVERLAY(uint8_t bot,uint8_t top)
     return scaletable[bot][bot] +
             2*scaletable[top][scaletable[bot][255-bot]] ;
     /* This strange formula is equivalent to
-   *   (1-top)*(bot^2) + top*(1-(1-top)^2)
-   * that is, the top value is used to interpolate between
-   * the self-multiply and the self-screen of the bottom.
-   */
+     *   (1-top)*(bot^2) + top*(1-(1-top)^2)
+     * that is, the top value is used to interpolate between
+     * the self-multiply and the self-screen of the bottom.
+     */
     /* Note: This is exactly what the "Soft light" effect also
-   * does, though with different code in the Gimp.
-   */
+     * does, though with different code in the Gimp.
+     */
 }
 
 exotic_combinator
@@ -208,8 +208,8 @@ ucombine_HARDLIGHT(uint8_t bot,uint8_t top)
     else
         return scaletable[bot][2*top];
     /* The code that implements "hardlight" in Gimp 2.2.10 has some
-   * rounding errors, but this is undoubtedly what is meant.
-   */
+     * rounding errors, but this is undoubtedly what is meant.
+     */
 }
 
 exotic_combinator
@@ -342,9 +342,9 @@ merge_exotic(struct Tile *bot, const struct Tile *top,
                         hsvBot.ch1 = (hsvTop.ch1*hsvBot.ch3 + hsvTop.ch3/2) / hsvTop.ch3;
                 } else if( mode == GIMP_COLOR_MODE ) {
                     /* GIMP_COLOR_MODE works in HSL space instead of HSV. We must
-             * transfer H and S, keeping the L = ch1+ch3 of the bottom pixel,
-             * but the S we transfer works differently from the S in HSV.
-             */
+                     * transfer H and S, keeping the L = ch1+ch3 of the bottom pixel,
+                     * but the S we transfer works differently from the S in HSV.
+                     */
                     unsigned L = hsvTop.ch1 + hsvTop.ch3 ;
                     unsigned sNum = hsvTop.ch3 - hsvTop.ch1 ;
                     unsigned sDenom = L < 256 ? L : 510-L ;
@@ -352,10 +352,10 @@ merge_exotic(struct Tile *bot, const struct Tile *top,
                     L = hsvBot.ch1 + hsvBot.ch3 ;
                     if( L < 256 ) {
                         /* Ideally we want to compute L/2 * (1-sNum/sDenom)
-               * But shuffle this a bit so we can use integer arithmetic.
-               * The "-1" in the rounding prevents us from ending up with
-               * ch1 > ch3.
-               */
+                         * But shuffle this a bit so we can use integer arithmetic.
+                         * The "-1" in the rounding prevents us from ending up with
+                         * ch1 > ch3.
+                         */
                         hsvBot.ch1 = (L*(sDenom-sNum)+sDenom-1)/(2*sDenom);
                         hsvBot.ch3 = L - hsvBot.ch1 ;
                     } else {
@@ -405,12 +405,12 @@ merge_exotic(struct Tile *bot, const struct Tile *top,
         else {
             rgba bp = bot->pixels[i] ;
             /* In a sane world, the alpha of the top pixel would simply be
-       * used to interpolate linearly between the bottom pixel's base
-       * color and the effect-computed color.
-       * But no! What the Gimp actually does is empirically
-       * described by the following (which borrows code from
-       * composite_one() that makes no theoretical sense here):
-       */
+             * used to interpolate linearly between the bottom pixel's base
+             * color and the effect-computed color.
+             * But no! What the Gimp actually does is empirically
+             * described by the following (which borrows code from
+             * composite_one() that makes no theoretical sense here):
+             */
             unsigned tfrac = ALPHA(top->pixels[i]) ;
             if( !FULLALPHA(bp) ) {
                 unsigned pseudotop = (tfrac < ALPHA(bp) ? tfrac : ALPHA(bp));
@@ -481,8 +481,8 @@ roundAlpha(struct Tile *tile)
  * The return value may be a shared tile.
  */
 static struct Tile *
-        flattenTopdown(struct FlattenSpec *spec, struct Tile *top,
-                       unsigned nlayers, const struct rect *where)
+flattenTopdown(struct FlattenSpec *spec, struct Tile *top,
+               unsigned nlayers, const struct rect *where)
 {
     struct Tile *tile = 0;
 
@@ -497,6 +497,7 @@ static struct Tile *
         if( !spec->layers[nlayers].isVisible )
             continue ;
 
+        freeTile(tile);
         tile = getLayerTile(&spec->layers[nlayers],where);
         if (tile == XCF_PTR_EMPTY) {
             return XCF_PTR_EMPTY;
@@ -528,8 +529,8 @@ static struct Tile *
                     else
                         tile_or |= tile->pixels[i] ;
                 /* If the tile only has pixels that will be covered by 'top' anyway,
-           * forget it anyway.
-           */
+                 * forget it anyway.
+                 */
                 if( ALPHA(tile_or) == 0 ) {
                     freeTile(tile);
                     break ; /* from the switch, which will continue the while */
@@ -539,6 +540,7 @@ static struct Tile *
             if( top->summary & TILESUMMARY_CRISP ) {
                 above = forkTile(top);
                 if(above == XCF_PTR_EMPTY) {
+                    freeTile(tile);
                     return XCF_PTR_EMPTY;
                 }
             } else {
@@ -554,17 +556,20 @@ static struct Tile *
             }
             below = flattenTopdown(spec, above, nlayers, where);
             if (below == XCF_PTR_EMPTY) {
+                freeTile(tile);
                 return XCF_PTR_EMPTY;
             }
             if( below->refcount > 1 ) {
                 if (below != top) {
+                    freeTile(tile);
                     return XCF_PTR_EMPTY;
                 }
                 /* This can only happen if 'below' is a copy of 'top'
-           * THROUGH 'above', which in turn means that none of all
-           * this is visible after all. So just free it and return 'top'.
-           */
+                 * THROUGH 'above', which in turn means that none of all
+                 * this is visible after all. So just free it and return 'top'.
+                 */
                 freeTile(below);
+                freeTile(tile);
                 return top ;
             }
             if (merge_exotic(below,tile,spec->layers[nlayers].mode) != XCF_OK) {
@@ -576,6 +581,7 @@ static struct Tile *
         }
         }
     }
+    freeTile(tile);
     return top ;
 }
 
