@@ -20,6 +20,9 @@ public:
     void setPaintOpSize(qreal value) override;
     qreal paintOpSize() const override;
 
+    void setPaintOpAngle(qreal value) override;
+    qreal paintOpAngle() const override;
+
     bool paintIncremental() override;
 
     QList<KisUniformPaintOpPropertySP> uniformProperties(KisPaintOpSettingsSP settings, QPointer<KisPaintOpPresetUpdateProxy> updateProxy) override;
