@@ -16,9 +16,8 @@ public:
     KisExperimentPaintOpSettings(KisResourcesInterfaceSP resourcesInterface);
     ~KisExperimentPaintOpSettings() override;
 
-    bool lodSizeThresholdSupported() const override;
     bool paintIncremental() override;
-    QPainterPath brushOutline(const KisPaintInformation &info, const OutlineMode &mode, qreal alignForZoom) override;
+    KisOptimizedBrushOutline brushOutline(const KisPaintInformation &info, const OutlineMode &mode, qreal alignForZoom) override;
 
     QList<KisUniformPaintOpPropertySP> uniformProperties(KisPaintOpSettingsSP settings, QPointer<KisPaintOpPresetUpdateProxy> updateProxy) override;
 
