@@ -7,13 +7,6 @@
 
 #include "kis_hatching_paintop_settings.h"
 
-#include <kis_paint_action_type_option.h>
-
-#include <QDomDocument>
-#include <QDomElement>
-
-const QString HATCHING_VERSION = "Hatching/Version";
-
 struct KisHatchingPaintOpSettings::Private
 {
     QList<KisUniformPaintOpPropertyWSP> uniformProperties;
@@ -24,7 +17,6 @@ KisHatchingPaintOpSettings::KisHatchingPaintOpSettings(KisResourcesInterfaceSP r
     : KisBrushBasedPaintOpSettings(resourcesInterface),
       m_d(new Private)
 {
-    setProperty(HATCHING_VERSION, "2");
 }
 
 KisHatchingPaintOpSettings::~KisHatchingPaintOpSettings()
@@ -85,21 +77,11 @@ void KisHatchingPaintOpSettings::initializeTwin(KisPaintOpSettingsSP settings) c
 
 }
 
-void KisHatchingPaintOpSettings::fromXML(const QDomElement& elt)
-{
-    setProperty(HATCHING_VERSION, "1"); // This make sure that fromXML will override HAIRY_VERSION with 2, or will default to 1
-    KisBrushBasedPaintOpSettings::fromXML(elt);
-    QVariant v;
-    if (!getProperty(HATCHING_VERSION, v) || v == "1") {
-        setProperty("Hatching/thickness", 2.0 * getDouble("Hatching/thickness"));
-    }
-    setProperty(HATCHING_VERSION, "2"); // make sure it's saved as version 2 next time
-}
 
 #include <brushengine/kis_slider_based_paintop_property.h>
 #include "kis_paintop_preset.h"
 #include "KisPaintOpPresetUpdateProxy.h"
-#include "kis_hatching_options.h"
+#include "KisHatchingOptionsData.h"
 
 
 QList<KisUniformPaintOpPropertySP> KisHatchingPaintOpSettings::uniformProperties(KisPaintOpSettingsSP settings, QPointer<KisPaintOpPresetUpdateProxy> updateProxy)
@@ -124,16 +106,16 @@ QList<KisUniformPaintOpPropertySP> KisHatchingPaintOpSettings::uniformProperties
 
             prop->setReadCallback(
                 [](KisUniformPaintOpProperty *prop) {
-                    HatchingOption option;
-                    option.readOptionSetting(prop->settings().data());
+                    KisHatchingOptionsData option;
+                    option.read(prop->settings().data());
                     prop->setValue(option.angle);
                 });
             prop->setWriteCallback(
                 [](KisUniformPaintOpProperty *prop) {
-                    HatchingOption option;
-                    option.readOptionSetting(prop->settings().data());
+                    KisHatchingOptionsData option;
+                    option.read(prop->settings().data());
                     option.angle = prop->value().toReal();
-                    option.writeOptionSetting(prop->settings().data());
+                    option.write(prop->settings().data());
                 });
 
             QObject::connect(updateProxy, SIGNAL(sigSettingsChanged()), prop, SLOT(requestReadValue()));
@@ -154,16 +136,16 @@ QList<KisUniformPaintOpPropertySP> KisHatchingPaintOpSettings::uniformProperties
 
             prop->setReadCallback(
                 [](KisUniformPaintOpProperty *prop) {
-                    HatchingOption option;
-                    option.readOptionSetting(prop->settings().data());
+                    KisHatchingOptionsData option;
+                    option.read(prop->settings().data());
                     prop->setValue(option.separation);
                 });
             prop->setWriteCallback(
                 [](KisUniformPaintOpProperty *prop) {
-                    HatchingOption option;
-                    option.readOptionSetting(prop->settings().data());
+                    KisHatchingOptionsData option;
+                    option.read(prop->settings().data());
                     option.separation = prop->value().toReal();
-                    option.writeOptionSetting(prop->settings().data());
+                    option.write(prop->settings().data());
                 });
 
             QObject::connect(updateProxy, SIGNAL(sigSettingsChanged()), prop, SLOT(requestReadValue()));
@@ -184,16 +166,16 @@ QList<KisUniformPaintOpPropertySP> KisHatchingPaintOpSettings::uniformProperties
 
             prop->setReadCallback(
                 [](KisUniformPaintOpProperty *prop) {
-                    HatchingOption option;
-                    option.readOptionSetting(prop->settings().data());
+                    KisHatchingOptionsData option;
+                    option.read(prop->settings().data());
                     prop->setValue(option.thickness);
                 });
             prop->setWriteCallback(
                 [](KisUniformPaintOpProperty *prop) {
-                    HatchingOption option;
-                    option.readOptionSetting(prop->settings().data());
+                    KisHatchingOptionsData option;
+                    option.read(prop->settings().data());
                     option.thickness = prop->value().toReal();
-                    option.writeOptionSetting(prop->settings().data());
+                    option.write(prop->settings().data());
                 });
 
             QObject::connect(updateProxy, SIGNAL(sigSettingsChanged()), prop, SLOT(requestReadValue()));
