@@ -10,17 +10,18 @@
 #include "kis_paint_information.h"
 #include "kis_paintop_utils.h"
 #include "kis_paintop_settings.h"
-#include "kis_airbrush_option_widget.h"
-#include "kis_pressure_spacing_option.h"
-#include "kis_pressure_rate_option.h"
+#include "KisAirbrushOptionData.h"
+#include "KisStandardOptions.h"
+#include "KisAirbrushOptionData.h"
+#include "KisSpacingOption.h"
 
 namespace KisPaintOpPluginUtils {
 
 /**
  * Similar to KisPaintOpUtils::effectiveSpacing, but some of the required parameters are obtained
  * from the provided configuration options. This function assumes a common configuration where
- * spacing and airbrush settings are configured through a KisPressureSpacingOption and
- * KisAirbrushOption. This type of configuration is used by several different paintops.
+ * spacing and airbrush settings are configured through a KisSpacingOption and
+ * KisAirbrushOptionData. This type of configuration is used by several different paintops.
  * @param dabWidth - The dab width.
  * @param dabHeight - The dab height.
  * @param isotropicSpacing - If @c true the spacing should be isotropic.
@@ -46,13 +47,13 @@ KisSpacingInformation effectiveSpacing(qreal dabWidth,
                                        bool autoSpacingActive,
                                        qreal autoSpacingCoeff,
                                        qreal lodScale,
-                                       const KisAirbrushOptionProperties *airbrushOption,
-                                       const KisPressureSpacingOption *spacingOption,
+                                       const KisAirbrushOptionData *airbrushOption,
+                                       const KisSpacingOption *spacingOption,
                                        const KisPaintInformation &pi)
 {
     // Extract required parameters.
     bool distanceSpacingEnabled = true;
-    if (airbrushOption && airbrushOption->enabled) {
+    if (airbrushOption && airbrushOption->isChecked) {
         distanceSpacingEnabled = !airbrushOption->ignoreSpacing;
     }
     qreal extraScale = 1.0;
@@ -69,7 +70,7 @@ KisSpacingInformation effectiveSpacing(qreal dabWidth,
 /**
  * Similar to KisPaintOpUtils::effectiveTiming, but some of the required parameters are obtained
  * from the provided configuration options. This function assumes a common configuration where
- * airbrush settings are configured through a KisAirbrushOption and KisPressureRateOption. This type
+ * airbrush settings are configured through a KisAirbrushOptionData and KisRateOption. This type
  * of configuration is used by several different paintops.
  * @param airbrushOption - The airbrushing option. Can be null for paintops that don't support
  *                         airbrushing.
@@ -78,16 +79,16 @@ KisSpacingInformation effectiveSpacing(qreal dabWidth,
  * @param pi - The paint information.
  * @see KisPaintInformation
  */
-KisTimingInformation effectiveTiming(const KisAirbrushOptionProperties *airbrushOption,
-                                     const KisPressureRateOption *rateOption,
+KisTimingInformation effectiveTiming(const KisAirbrushOptionData *airbrushOption,
+                                     const KisRateOption *rateOption,
                                      const KisPaintInformation &pi)
 {
     // Extract required parameters.
     bool timingEnabled = false;
     qreal timingInterval = LONG_TIME;
     if (airbrushOption) {
-        timingEnabled = airbrushOption->enabled;
-        timingInterval = airbrushOption->airbrushInterval;
+        timingEnabled = airbrushOption->isChecked;
+        timingInterval = 1000.0 / airbrushOption->airbrushRate;
     }
     qreal rateExtraScale = 1.0;
     if (rateOption && rateOption->isChecked()) {
