@@ -25,6 +25,9 @@ public:
     void setPaintOpSize(qreal value) override;
     qreal paintOpSize() const override;
 
+    void setPaintOpAngle(qreal value) override;
+    qreal paintOpAngle() const override;
+
     void setPaintOpOpacity(qreal value) override;
     qreal paintOpOpacity() override;
 
@@ -35,6 +38,9 @@ public:
     }
 
     bool paintIncremental() override;
+    void resetSettings(const QStringList &preserveProperties = QStringList()) override;
+
+    void onPropertyChanged() override;
 
 private:
     Q_DISABLE_COPY(KisMyPaintOpSettings)
