@@ -6,24 +6,26 @@
 
 #include "kis_particle_paintop_settings_widget.h"
 
-#include "kis_particleop_option.h"
+#include "KisParticleOpOptionWidget.h"
 #include "kis_particle_paintop_settings.h"
 
 #include <kis_paintop_settings_widget.h>
-#include <kis_curve_option_widget.h>
-#include <kis_paint_action_type_option.h>
-#include <kis_airbrush_option_widget.h>
-#include <kis_compositeop_option.h>
-#include <kis_pressure_rate_option.h>
+#include <KisPaintingModeOptionWidget.h>
+#include <KisPaintOpOptionWidgetUtils.h>
+#include <KisAirbrushOptionWidget.h>
+#include <KisCompositeOpOptionWidget.h>
+#include <KisStandardOptionData.h>
 
 KisParticlePaintOpSettingsWidget:: KisParticlePaintOpSettingsWidget(QWidget* parent)
     : KisPaintOpSettingsWidget(parent)
 {
-    addPaintOpOption(new KisParticleOpOption());
-    addPaintOpOption(new KisCompositeOpOption(true));
-    addPaintOpOption(new KisAirbrushOptionWidget(false, false));
-    addPaintOpOption(new KisCurveOptionWidget(new KisPressureRateOption(), i18n("0%"), i18n("100%")));
-    addPaintOpOption(new KisPaintActionTypeOption());
+    namespace kpowu = KisPaintOpOptionWidgetUtils;
+
+    addPaintOpOption(kpowu::createOptionWidgetWithLodLimitations<KisParticleOpOptionWidget>());
+    addPaintOpOption(kpowu::createOptionWidget<KisCompositeOpOptionWidget>());
+    addPaintOpOption(kpowu::createOptionWidget<KisAirbrushOptionWidget>(KisAirbrushOptionData(), false));
+    addPaintOpOption(kpowu::createRateOptionWidget());
+    addPaintOpOption(kpowu::createOptionWidget<KisPaintingModeOptionWidget>());
 }
 
 KisParticlePaintOpSettingsWidget::~ KisParticlePaintOpSettingsWidget()
