@@ -26,6 +26,7 @@
 #include <kis_selection_options.h>
 #include <kis_cursor.h>
 #include <kis_image.h>
+#include <kis_default_bounds.h>
 
 #include "canvas/kis_canvas2.h"
 #include "kis_painter.h"
@@ -34,6 +35,7 @@
 #include <brushengine/kis_paintop_registry.h>
 #include <kis_command_utils.h>
 #include <kis_selection_filters.h>
+#include <KisCursorOverrideLock.h>
 
 #include "kis_algebra_2d.h"
 
@@ -231,7 +233,7 @@ void KisToolSelectMagnetic::beginPrimaryAction(KoPointerEvent *event)
     } else {
         beginSelectInteraction();
         updateInitialAnchorBounds(temp.toPoint());
-        emit setButtonsEnabled(true);
+        Q_EMIT setButtonsEnabled(true);
     }
 
     m_lastAnchor = temp.toPoint();
@@ -488,7 +490,7 @@ void KisToolSelectMagnetic::finishSelectionAction()
     if (m_points.count() > 2 &&
         !helper.tryDeselectCurrentSelection(boundingViewRect, selectionAction()))
     {
-        QApplication::setOverrideCursor(KisCursor::waitCursor());
+        KisCursorOverrideLock cursorLock(KisCursor::waitCursor());
 
         const SelectionMode mode =
             helper.tryOverrideSelectionMode(kisCanvas->viewManager()->selection(),
@@ -574,7 +576,6 @@ void KisToolSelectMagnetic::finishSelectionAction()
             path->normalize();
             helper.addSelectionShape(path, selectionAction());
         }
-        QApplication::restoreOverrideCursor();
     }
 
     resetVariables();
