@@ -727,6 +727,6 @@ void KisPerspectiveTransformStrategy::Private::recalculateTransformations()
     // recalculate cached handles position
     recalculateTransformedHandles();
 
-    emit q->requestShowImageTooBig(imageTooBig);
-    emit q->requestImageRecalculation();
+    Q_EMIT q->requestShowImageTooBig(imageTooBig);
+    Q_EMIT q->requestImageRecalculation();
 }
