@@ -454,6 +454,14 @@ void KisToolTransform::endAlternateAction(KoPointerEvent *event, AlternateAction
 
 void KisToolTransform::mousePressEvent(KoPointerEvent *event)
 {
+    // When using touch drawing, we only ever receive move events after the
+    // finger has pressed down. This confuses the strategies greatly, since they
+    // expect to receive a hover to tell which anchor the user wants to
+    // manipulate or similar. So in this case, we send an artificial hover.
+    if (event->isTouchEvent() && this->mode() != KisTool::PAINT_MODE) {
+        currentStrategy()->hoverActionCommon(event);
+        setFunctionalCursor();
+    }
     KisTool::mousePressEvent(event);
 }
 
@@ -1067,30 +1075,6 @@ void KisToolTransform::slotTrackerChangedConfig(KisToolChangesTrackerDataSP stat
     updateOptionWidget();
 }
 
-QList<KisNodeSP> KisToolTransform::fetchNodesList(ToolTransformArgs::TransformMode mode, KisNodeSP root, bool isExternalSourcePresent)
-{
-    QList<KisNodeSP> result;
-
-    auto fetchFunc =
-        [&result, mode, root] (KisNodeSP node) {
-        if (node->isEditable(node == root) &&
-                (!node->inherits("KisShapeLayer") || mode == ToolTransformArgs::FREE_TRANSFORM) &&
-                !node->inherits("KisFileLayer") &&
-                (!node->inherits("KisTransformMask") || node == root)) {
-
-                result << node;
-            }
-    };
-
-    if (isExternalSourcePresent) {
-        fetchFunc(root);
-    } else {
-        KisLayerUtils::recursiveApplyNodes(root, fetchFunc);
-    }
-
-    return result;
-}
-
 QWidget* KisToolTransform::createOptionWidget()
 {
     if (!m_canvas) return 0;
