@@ -25,7 +25,7 @@
 #include "kis_recalculate_transform_mask_job.h"
 
 #include "kis_projection_leaf.h"
-#include "kis_modify_transform_mask_command.h"
+#include "commands_new/KisSimpleModifyTransformMaskCommand.h"
 #include "KisAnimAutoKey.h"
 
 #include "kis_sequential_iterator.h"
@@ -37,6 +37,7 @@
 #include "transform_transaction_properties.h"
 #include "krita_container_utils.h"
 #include "commands_new/kis_saved_commands.h"
+#include "commands_new/KisLazyCreateTransformMaskKeyframesCommand.h"
 #include "kis_command_ids.h"
 #include "KisRunnableStrokeJobUtils.h"
 #include "commands_new/KisHoldUIUpdatesCommand.h"
@@ -52,6 +53,7 @@
 #include "kis_raster_keyframe_channel.h"
 #include "kis_image_animation_interface.h"
 #include "KisAnimAutoKey.h"
+#include "krita_utils.h"
 
 
 struct InplaceTransformStrokeStrategy::Private
@@ -383,26 +385,27 @@ void InplaceTransformStrokeStrategy::initStrokeCallback()
         });
     }
 
-    if (KisAutoKey::activeMode() > KisAutoKey::NONE) {
-        KritaUtils::addJobSequential(extraInitJobs, [this]() {
-            // When dealing with animated transform mask layers, create keyframe and save the command for undo.
-            Q_FOREACH (KisNodeSP node, m_d->processedNodes) {
-                if (KisTransformMask* transformMask = dynamic_cast<KisTransformMask*>(node.data())) {
-                    QSharedPointer<KisInitializeTransformMaskKeyframesCommand> addKeyCommand(new KisInitializeTransformMaskKeyframesCommand(transformMask,
-                                                                                                                                            KisTransformMaskParamsInterfaceSP(
-                                                                                                                                                new KisTransformMaskAdapter(m_d->initialTransformArgs))));
-                    runAndSaveCommand( addKeyCommand, KisStrokeJobData::CONCURRENT, KisStrokeJobData::NORMAL);
-                } else if (node->hasEditablePaintDevice()){
-                    KUndo2Command *autoKeyframeCommand =
+    KritaUtils::addJobSequential(extraInitJobs, [this]() {
+        // When dealing with animated transform mask layers, create keyframe and save the command for undo.
+        // NOTE: for transform masks we create a keyframe no matter what the user
+        //       settigs are
+        Q_FOREACH (KisNodeSP node, m_d->processedNodes) {
+            if (KisTransformMask* transformMask = dynamic_cast<KisTransformMask*>(node.data())) {
+                if (KisLazyCreateTransformMaskKeyframesCommand::maskHasAnimation(transformMask)) {
+                    runAndSaveCommand(toQShared(new KisLazyCreateTransformMaskKeyframesCommand(transformMask)), KisStrokeJobData::BARRIER, KisStrokeJobData::NORMAL);
+                }
+            } else if (KisAutoKey::activeMode() > KisAutoKey::NONE &&
+                       node->hasEditablePaintDevice()){
+
+                KUndo2Command *autoKeyframeCommand =
                         KisAutoKey::tryAutoCreateDuplicatedFrame(node->paintDevice(),
                                                                  KisAutoKey::SupportsLod);
-                    if (autoKeyframeCommand) {
-                        runAndSaveCommand(toQShared(autoKeyframeCommand), KisStrokeJobData::BARRIER, KisStrokeJobData::NORMAL);
-                    }
+                if (autoKeyframeCommand) {
+                    runAndSaveCommand(toQShared(autoKeyframeCommand), KisStrokeJobData::BARRIER, KisStrokeJobData::NORMAL);
                 }
             }
-        });
-    }
+        }
+    });
 
     KritaUtils::addJobSequential(extraInitJobs, [this]() {
         /**
@@ -754,26 +757,11 @@ void InplaceTransformStrokeStrategy::transformNode(KisNodeSP node, const ToolTra
             transformMask->overrideStaticCacheDevice(dst);
         }
 
-
-        if (commandGroup == Transform) { // Set Keyframe Data.
-            ToolTransformArgs unscaled = ToolTransformArgs(config);
-
-            if (levelOfDetail > 0) {
-                unscaled.scale3dSrcAndDst(KisLodTransform::lodToInvScale(levelOfDetail));
-            }
-
-            KUndo2Command* cmd = new KisSetTransformMaskKeyframesCommand(transformMask,
-                                                          KisTransformMaskParamsInterfaceSP(
-                                                                new KisTransformMaskAdapter(unscaled)));
-            executeAndAddCommand(cmd, commandGroup, KisStrokeJobData::BARRIER);
-        }
-
-
         {
-            KUndo2Command *cmd = new KisModifyTransformMaskCommand(transformMask,
-                                                                   KisTransformMaskParamsInterfaceSP(
-                                                                       new KisTransformMaskAdapter(config)),
-                                                                   m_d->commandUpdatesBlockerCookie);
+            KUndo2Command *cmd = new KisSimpleModifyTransformMaskCommand(transformMask,
+                                                                         KisTransformMaskParamsInterfaceSP(
+                                                                             new KisTransformMaskAdapter(config)),
+                                                                         m_d->commandUpdatesBlockerCookie);
             executeAndAddCommand(cmd, commandGroup, KisStrokeJobData::CONCURRENT);
             addDirtyRect(node, oldDirtyRect | transformMask->extent(), levelOfDetail);
         }
@@ -903,7 +891,7 @@ void InplaceTransformStrokeStrategy::reapplyTransform(ToolTransformArgs args,
         }
 
         /**
-         * We also emit the updates manually, because KisUpdateCommandEx is
+         * We also Q_EMIT the updates manually, because KisUpdateCommandEx is
          * still blocked by m_d->commandUpdatesBlockerCookie (for easy undo
          * purposes)
          */
@@ -913,7 +901,8 @@ void InplaceTransformStrokeStrategy::reapplyTransform(ToolTransformArgs args,
             if (transformMask &&
                     ((levelOfDetail <= 0 && !transformMask->transformParams()->isAffine()) ||
                      (levelOfDetail <= 0 && m_d->previewLevelOfDetail > 0))) {
-                transformMask->threadSafeForceStaticImageUpdate();
+
+                transformMask->threadSafeForceStaticImageUpdate(it->second);
             } else {
                 m_d->updatesFacade->refreshGraphAsync(it->first, it->second);
             }
@@ -946,6 +935,19 @@ void InplaceTransformStrokeStrategy::finalizeStrokeImpl(QVector<KisStrokeJobData
     }
 }
 
+void InplaceTransformStrokeStrategy::repopulateUI(QVector<KisStrokeJobData *> &mutatedJobs, KisUpdatesFacade *updatesFacade, const QRect &dirtyRect)
+{
+    const QVector<QRect> finalDirtyRects =
+        KritaUtils::splitRectIntoPatchesTight(dirtyRect,
+                                              KritaUtils::optimalPatchSize());
+
+    Q_FOREACH (const QRect &rc, finalDirtyRects) {
+        KritaUtils::addJobConcurrent(mutatedJobs, [rc, updatesFacade] () {
+            updatesFacade->notifyUIUpdateCompleted(rc);
+        });
+    }
+}
+
 void InplaceTransformStrokeStrategy::finishAction(QVector<KisStrokeJobData *> &mutatedJobs)
 {
     /**
@@ -988,6 +990,15 @@ void InplaceTransformStrokeStrategy::finishAction(QVector<KisStrokeJobData *> &m
         }
 
         reapplyTransform(m_d->currentTransformArgs, mutatedJobs, 0, true);
+
+        /**
+         * We could have issues updates on lodN planes, which did not end
+         * up in the final lod0 update, so we should reupload lod0 data to
+         * the UI part manually.
+         */
+        KritaUtils::addJobBarrier(mutatedJobs, [this]() { Q_UNUSED(this) });
+        repopulateUI(mutatedJobs, m_d->updatesFacade, m_d->updatesFacade->bounds());
+
     } else {
         if (m_d->pendingUpdateArgs) {
             mutatedJobs << new BarrierUpdateData(true);
@@ -1034,16 +1045,33 @@ void InplaceTransformStrokeStrategy::cancelAction(QVector<KisStrokeJobData *> &m
     const bool isChangingTransformMask = !m_d->transformMaskCacheHash.isEmpty();
 
     if (m_d->initialTransformArgs.isIdentity()) {
+        KritaUtils::addJobSequential(mutatedJobs, [this]() {
+            Q_FOREACH (KisTransformMask *mask, m_d->transformMaskCacheHash.keys()) {
+                mask->overrideStaticCacheDevice(0);
+            }
+        });
+
+
         KritaUtils::addJobBarrier(mutatedJobs, [this]() {
             m_d->commandUpdatesBlockerCookie.reset();
             undoTransformCommands(0);
             undoAllCommands();
         });
+
+        if (m_d->previewLevelOfDetail > 0) {
+            /**
+             * We could have issues updates on lodN planes, which did not end
+             * up in the final lod0 update, so we should reupload lod0 data to
+             * the UI part manually.
+             */
+            KritaUtils::addJobBarrier(mutatedJobs, [this]() { Q_UNUSED(this) });
+            repopulateUI(mutatedJobs, m_d->updatesFacade, m_d->updatesFacade->bounds());
+        }
+
         finalizeStrokeImpl(mutatedJobs, false);
 
         KritaUtils::addJobSequential(mutatedJobs, [this]() {
             Q_FOREACH (KisTransformMask *mask, m_d->transformMaskCacheHash.keys()) {
-                mask->overrideStaticCacheDevice(0);
                 mask->threadSafeForceStaticImageUpdate();
             }
         });
@@ -1062,6 +1090,16 @@ void InplaceTransformStrokeStrategy::cancelAction(QVector<KisStrokeJobData *> &m
 
         reapplyTransform(m_d->initialTransformArgs, mutatedJobs, 0, true);
 
+        if (m_d->previewLevelOfDetail > 0) {
+            /**
+             * We could have issues updates on lodN planes, which did not end
+             * up in the final lod0 update, so we should reupload lod0 data to
+             * the UI part manually.
+             */
+            KritaUtils::addJobBarrier(mutatedJobs, [this]() { Q_UNUSED(this) });
+            repopulateUI(mutatedJobs, m_d->updatesFacade, m_d->updatesFacade->bounds());
+        }
+
         mutatedJobs << new UpdateTransformData(m_d->initialTransformArgs,
                                                UpdateTransformData::SELECTION);
 
